@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:Assistant.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: Assistant.py 18361 2011-10-23 03:13:50Z paul-franklin $
 
 #-------------------------------------------------------------------------
 #
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import os
 
 #-------------------------------------------------------------------------
@@ -170,6 +170,7 @@ class Assistant(gtk.Object, ManagedWindow.ManagedWindow):
             gtk.main_iteration()
 
     def destroy(self, *obj):
+        self.window.emit('delete-event', None)
         self.window.destroy()
 
     def do_get_property(self, prop):
@@ -321,10 +322,10 @@ if __name__ == "__main__":
 
     a = Assistant(complete)
     a.add_text_page('Getting started', 
-                    'Welcome to GRAMPS, the Genealogical Research '
+                    'Welcome to Gramps, the Genealogical Research '
                     'and Analysis Management Programming System.\n'
                     'Several options and information need to be gathered '
-                    'before GRAMPS is ready to be used. Any of this '
+                    'before Gramps is ready to be used. Any of this '
                     'information can be changed in the future in the '
                     'Preferences dialog under the Settings menu.')
 
