@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Bookmarks.py 15918 2010-09-20 23:58:16Z nick-h $
+# $Id: Bookmarks.py 18548 2011-12-04 17:09:17Z kulath $
 
 "Handle bookmarks for the gramps interface."
 
@@ -364,6 +365,18 @@ class SourceBookmarks(ListBookmarks) :
     def connect_signals(self):
         self.dbstate.db.connect('source-delete', self.remove_handles)
 
+class CitationBookmarks(ListBookmarks) :
+    "Handle the bookmarks interface for Gramps."
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
+        ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
+                               goto_handle)
+        
+    def make_label(self, handle):
+        return Utils.navigation_label(self.dbstate.db, 'Citation', handle)
+
+    def connect_signals(self):
+        self.dbstate.db.connect('citation-delete', self.remove_handles)
+
 class MediaBookmarks(ListBookmarks) :
     "Handle the bookmarks interface for Gramps."
     
