@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _DateDisplay.py 15010 2010-04-03 23:33:17Z dsblank $
+# $Id: _DateDisplay.py 17498 2011-05-14 20:30:36Z vassilii $
 
 """
 U.S English date display class. Should serve as the base class for all
@@ -211,14 +211,6 @@ class DateDisplay(object):
         else:
             return value
 
-    def text_display(self, date):
-        """
-        Similar to the display task, except that if the value is a text only
-        value, it is enclosed in quotes.
-        """
-        return date.get_text()
-        
-
     def _display_gregorian(self, date_val):
         year = self._slash_year(date_val[2], date_val[3])
         if self.format == 0:
