@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_sk.py 13442 2009-10-28 12:21:37Z pez4brian $
+# $Id: _Date_sk.py 15117 2010-04-14 16:22:48Z romjerome $
 
 """
 Slovak-specific classes for parsing and displaying dates.
@@ -104,18 +104,17 @@ class DateDisplaySK(DateDisplay):
     """
     Slovak language date display class. 
     """
-    # TODO: Translate these month strings:
-    long_months = ( u"", u"January", u"February", u"March", u"April", u"May", 
-                    u"June", u"July", u"August", u"September", u"October", 
-                    u"November", u"December" )
+    long_months = ( u"", u"január", u"február", u"marec", u"apríl", u"máj", 
+                    u"jún", u"júl", u"august", u"september", u"október", 
+                    u"november", u"december" )
     
-    short_months = ( u"", u"Jan", u"Feb", u"Mar", u"Apr", u"May", u"Jun", 
-                     u"Jul", u"Aug", u"Sep", u"Oct", u"Nov", u"Dec" )
+    short_months = ( u"", u"jan", u"feb", u"mar", u"apr", u"máj", u"jún", 
+                     u"júl", u"aug", u"sep", u"okt", u"nov", u"dec" )
     
     calendar = (
-        "", u" (juliánský)", u" (hebrejský)", 
-        u" (republikánsky)", u" (perzský)", u" (islamský)", 
-        u" (swedish)" 
+        "", u"juliánský", u"hebrejský", 
+        u"republikánsky", u"perzský", u"islamský", 
+        u"swedish" 
         )
 
     _mod_str = ("", u"pred ", u"po ", u"okolo ", "", "", "")
@@ -135,6 +134,7 @@ class DateDisplaySK(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -145,17 +145,20 @@ class DateDisplaySK(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return "%s%s %s %s %s%s" % (qual_str, u'od', d1, 
-                                        u'do', d2, self.calendar[cal])
+                                        u'do', d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return "%s%s %s %s %s%s" % (qual_str, u'medzi', 
-                                        d1, u'a', d2, self.calendar[cal])
+                                        d1, u'a', d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
+            scal = self.format_extras(cal, newyear)
             return "%s%s%s%s" % (qual_str, self._mod_str[mod],
-                                 text, self.calendar[cal])
+                                 text, scal)
 
 #-------------------------------------------------------------------------
 #
