@@ -4,6 +4,7 @@
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2008       Brian G. Matherly
 # Copyright (C) 2010       Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DisplayState.py 18655 2011-12-25 09:29:24Z m_d_n $
+# $Id: DisplayState.py 18654 2011-12-25 09:28:45Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -365,6 +366,7 @@ class DisplayState(gen.utils.Callback):
         'Event': _("No active event"),
         'Place': _("No active place"),
         'Source': _("No active source"),
+        'Citation': _("No active citation"),
         'Repository': _("No active repository"),
         'Media': _("No active media"),
         'Note': _("No active note"),
@@ -402,6 +404,18 @@ class DisplayState(gen.utils.Callback):
         # but this connection is still made!
         # self.dbstate.connect('database-changed', self.db_changed)
 
+    def screen_width(self):
+        """
+        Return the width of the current screen.
+        """
+        return self.window.get_screen().get_width()
+
+    def screen_height(self):
+        """
+        Return the height of the current screen.
+        """
+        return self.window.get_screen().get_height()
+
     def clear_history(self):
         """
         Clear all history objects.
