@@ -19,6 +19,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# $Id: ExportOptions.py 19593 2012-05-19 17:26:25Z dsblank $
+#
 
 """Provide the common export options for Exporters."""
 
@@ -418,14 +420,17 @@ class WriterOptionBox(object):
         gramps_id = self.person.get_gramps_id()
 
         des = GenericFilter()
+        # feature request 2356: avoid genitive form
         des.set_name(_("Descendants of %s") % name)
         des.add_rule(Rules.Person.IsDescendantOf([gramps_id, 1]))
         
         df = GenericFilter()
+        # feature request 2356: avoid genitive form
         df.set_name(_("Descendant Families of %s") % name)
         df.add_rule(Rules.Person.IsDescendantFamilyOf([gramps_id, 1]))
         
         ans = GenericFilter()
+        # feature request 2356: avoid genitive form
         ans.set_name(_("Ancestors of %s") % name)
         ans.add_rule(Rules.Person.IsAncestorOf([gramps_id, 1]))
         
@@ -511,10 +516,10 @@ class WriterOptionBox(object):
         if self.restrict_num > 0 and progress:
             progress.progress_cnt += 1
 
-        if not self.cfilter.is_empty() and progress:
+        if (self.cfilter != None and (not self.cfilter.is_empty())) and progress:
             progress.progress_cnt += 1
 
-        if not self.nfilter.is_empty() and progress:
+        if (self.nfilter != None and (not self.nfilter.is_empty())) and progress:
             progress.progress_cnt += 1
 
         if self.reference_num > 0 and progress:
@@ -575,7 +580,7 @@ class WriterOptionBox(object):
         # If the filter returned by cfilter is not empty, apply the 
         # FilterProxyDb (Person Filter)
         elif proxy_name == "person":
-            if not self.cfilter.is_empty():
+            if self.cfilter != None and not self.cfilter.is_empty():
                 if progress:
                     progress.reset(_("Applying selected person filter"))
                     progress.progress_cnt += 1
@@ -585,7 +590,7 @@ class WriterOptionBox(object):
 
         # Apply the Note Filter
         elif proxy_name == "note":
-            if not self.nfilter.is_empty():
+            if self.nfilter != None and not self.nfilter.is_empty():
                 if progress:
                     progress.reset(_("Applying selected note filter"))
                     progress.progress_cnt += 1
