@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 11605 2009-01-10 18:41:16Z dsblank $
+# $Id: __init__.py 16026 2010-10-23 09:49:59Z nick-h $
 
 """
 Package providing filter rules for GRAMPS.
@@ -27,7 +27,6 @@ Package providing filter rules for GRAMPS.
 
 from _AllNotes import AllNotes
 from _HasIdOf import HasIdOf
-from _HasMarkerOf import HasMarkerOf
 from _RegExpIdOf import RegExpIdOf
 from _MatchesRegexpOf import MatchesRegexpOf
 from _MatchesSubstringOf import MatchesSubstringOf
@@ -36,11 +35,11 @@ from _NotePrivate import NotePrivate
 from _MatchesFilter import MatchesFilter
 from _HasNote import HasNote
 from _ChangedSince import ChangedSince
+from _HasTag import HasTag
 
 editor_rule_list = [
     AllNotes,
     HasIdOf,
-    HasMarkerOf,
     RegExpIdOf,
     HasNote,
     MatchesRegexpOf,
@@ -49,4 +48,5 @@ editor_rule_list = [
     NotePrivate,
     MatchesFilter,
     ChangedSince,
+    HasTag,
 ]
