@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _FamilyWithIncompleteEvent.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _FamilyWithIncompleteEvent.py 15369 2010-05-09 13:43:50Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -48,11 +48,12 @@ class FamilyWithIncompleteEvent(Rule):
     def apply(self,db,person):
         for family_handle in person.get_family_handle_list():
             family = db.get_family_from_handle(family_handle)
-            for event_ref in family.get_event_ref_list():
-                if event_ref:
-                    event = db.get_event_from_handle(event_ref.ref)
-                    if not event.get_place_handle():
-                        return True
-                    if not event.get_date_object():
-                        return True
+            if family:
+                for event_ref in family.get_event_ref_list():
+                    if event_ref:
+                        event = db.get_event_from_handle(event_ref.ref)
+                        if not event.get_place_handle():
+                            return True
+                        if not event.get_date_object():
+                            return True
         return False
