@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasFamilyAttribute.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _HasFamilyAttribute.py 15369 2010-05-09 13:43:50Z dsblank $
 
 #-------------------------------------------------------------------------
 #
@@ -53,10 +53,13 @@ class HasFamilyAttribute(Rule):
             return False
         for f_id in person.get_family_handle_list():
             f = db.get_family_from_handle(f_id)
+            if not f:
+                continue
             for attr in f.get_attribute_list():
-                name_match = self.list[0] == attr.get_type()
-                value_match = \
-                        attr.get_value().upper().find(self.list[1].upper()) != -1
-                if name_match and value_match:
-                    return True
+                if attr:
+                    name_match = self.list[0] == attr.get_type()
+                    value_match = \
+                            attr.get_value().upper().find(self.list[1].upper()) != -1
+                    if name_match and value_match:
+                        return True
         return False
