@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsParentOfFilterMatch.py 15368 2010-05-09 13:42:33Z dsblank $
+# $Id: _IsParentOfFilterMatch.py 15855 2010-09-03 22:54:40Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -32,6 +32,7 @@ from gen.ggettext import gettext as _
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
+from Filters.Rules import Rule
 from _MatchesFilter import MatchesFilter
 
 #-------------------------------------------------------------------------
@@ -39,7 +40,7 @@ from _MatchesFilter import MatchesFilter
 # IsParentOfFilterMatch
 #
 #-------------------------------------------------------------------------
-class IsParentOfFilterMatch(MatchesFilter):
+class IsParentOfFilterMatch(Rule):
     """Rule that checks for a person that is a parent
     of someone matched by a filter"""
 
@@ -52,11 +53,11 @@ class IsParentOfFilterMatch(MatchesFilter):
         self.db = db
         self.map = set()
         filt = MatchesFilter(self.list)
-        filt.prepare(db)
+        filt.requestprepare(db)
         for person in db.iter_people():
             if filt.apply(db, person):
                 self.init_list(person)
-        filt.reset()
+        filt.requestreset()
 
     def reset(self):
         self.map.clear()
