@@ -3,6 +3,8 @@
 #
 # Copyright (C) 2002-2007  Donald N. Allingham
 # Copyright (C) 2007-2008   Brian G. Matherly
+# Copyright (C) 2011       Tim G L Lyons
+# Copyright (C) 2011       Doug Blank <doug.blank@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:__init__.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: __init__.py 18571 2011-12-11 04:04:28Z dsblank $
 
 """
 Package providing filter rules for GRAMPS.
@@ -33,6 +35,7 @@ from _HasAlternateName import HasAlternateName
 from _HasAssociation import HasAssociation
 from _HasAttribute import HasAttribute
 from _HasBirth import HasBirth
+from _HasCitation import HasCitation
 from _HasCommonAncestorWith import HasCommonAncestorWith
 from _HasCommonAncestorWithFilterMatch import HasCommonAncestorWithFilterMatch
 from _HasDeath import HasDeath
@@ -50,7 +53,7 @@ from _HasNote import HasNote
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
 from _HasNoteRegexp import HasNoteRegexp
 from _HasRelationship import HasRelationship
-from _HasSource import HasSource
+from _HasSourceCount import HasSourceCount
 from _HasSourceOf import HasSourceOf
 from _HasTag import HasTag
 from _HasTextMatchingRegexpOf import HasTextMatchingRegexpOf
@@ -95,6 +98,7 @@ from _NeverMarried import NeverMarried
 from _NoBirthdate import NoBirthdate
 from _NoDeathdate import NoDeathdate
 from _PeoplePrivate import PeoplePrivate
+from _PeoplePublic import PeoplePublic
 from _PersonWithIncompleteEvent import PersonWithIncompleteEvent
 from _ProbablyAlive import ProbablyAlive
 from _RelationshipPathBetween import RelationshipPathBetween
@@ -106,6 +110,7 @@ from _RegExpName import RegExpName
 from _MatchIdOf import MatchIdOf
 from _RegExpIdOf import RegExpIdOf
 from _ChangedSince import ChangedSince
+from _IsRelatedWith import IsRelatedWith
 
 #-------------------------------------------------------------------------
 #
@@ -131,12 +136,13 @@ editor_rule_list = [
     HasRelationship,
     HasDeath,
     HasBirth,
+    HasCitation, 
     HasEvent,
     HasFamilyEvent,
     HasAttribute,
     HasFamilyAttribute,
     HasTag,
-    HasSource,
+    HasSourceCount,
     HasSourceOf,
     HaveAltFamilies,
     HavePhotos,
@@ -150,6 +156,7 @@ editor_rule_list = [
     FamilyWithIncompleteEvent,
     ProbablyAlive,
     PeoplePrivate,
+    PeoplePublic,
     IsWitness,
     IsDescendantOf,
     IsDescendantFamilyOf,
@@ -183,5 +190,6 @@ editor_rule_list = [
     RegExpIdOf,
     Disconnected,
     ChangedSince,
+    IsRelatedWith,
 ]
 
