@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2002-2007  Donald N. Allingham
 # Copyright (C) 2007-2008  Brian G. Matherly
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,12 +20,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 17419 2011-05-05 17:44:45Z romjerome $
+# $Id: __init__.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
+from Filters.Rules._HasSourceBase import HasSourceBase as HasSource
+
 from _AllSources import AllSources
 from _HasGallery import HasGallery
 from _HasIdOf import HasIdOf
@@ -35,7 +38,6 @@ from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
 from _HasReferenceCountOf import HasReferenceCountOf
 from _SourcePrivate import SourcePrivate
 from _MatchesFilter import MatchesFilter
-from _HasSource import HasSource
 from _ChangedSince import ChangedSince
 from _HasRepository import HasRepository
 from _MatchesTitleSubstringOf import MatchesTitleSubstringOf
