@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2010       Raphael Ackermann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +19,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasGrampsId.py 10094 2008-02-22 10:50:06Z acraphae $
+# $Id: _HasGrampsId.py 15023 2010-04-04 11:07:29Z acraphae $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -40,12 +41,16 @@ from Filters.Rules import Rule
 #
 #-------------------------------------------------------------------------
 class HasGrampsId(Rule):
-    """Rule that checks for a person with a specific GRAMPS ID."""
+    """Rule that checks for an object with a specific GRAMPS ID."""
 
     labels      = [ _('ID:') ]
     name        = _('Object with <Id>')
-    description = _("Matches objects with a specified GRAMPS ID")
+    description = _("Matches objects with a specified Gramps ID")
     category    = _('General filters')
 
     def apply(self, db, obj):
-        return obj.gramps_id.find(self.list[0]) !=-1
+        """
+        apply the rule on the obj.
+        return true if the rule passes, false otherwise.
+        """
+        return obj.gramps_id == self.list[0]
