@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MatchesFilterBase.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _MatchesFilterBase.py 15855 2010-09-03 22:54:40Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -55,50 +55,36 @@ class MatchesFilterBase(Rule):
     category    = _('General filters')
 
     def prepare(self, db):
-        #if Filters.SystemFilters:
-            #for filt in Filters.SystemFilters.get_filters(self.namespace):
-                #if filt.get_name() == self.list[0]:
-                    #for rule in filt.flist:
-                        #rule.prepare(db)
         if Filters.CustomFilters:
-            for filt in Filters.CustomFilters.get_filters(self.namespace):
-                if filt.get_name() == self.list[0]:
-                    for rule in filt.flist:
-                        rule.prepare(db)
+            filters = Filters.CustomFilters.get_filters_dict(self.namespace)
+            if self.list[0] in filters:
+                filt = filters[self.list[0]]
+                for rule in filt.flist:
+                    rule.requestprepare(db)
+                    
 
     def reset(self):
-        #if Filters.SystemFilters:
-            #for filt in Filters.SystemFilters.get_filters(self.namespace):
-                #if filt.get_name() == self.list[0]:
-                    #for rule in filt.flist:
-                        #rule.reset()
         if Filters.CustomFilters:
-            for filt in Filters.CustomFilters.get_filters(self.namespace):
-                if filt.get_name() == self.list[0]:
-                    for rule in filt.flist:
-                        rule.reset()
+            filters = Filters.CustomFilters.get_filters_dict(self.namespace)
+            if self.list[0] in filters:
+                filt = filters[self.list[0]]
+                for rule in filt.flist:
+                    rule.requestreset()
 
     def apply(self, db, obj):
-        #if Filters.SystemFilters:
-            #for filt in Filters.SystemFilters.get_filters(self.namespace):
-                #if filt.get_name() == self.list[0]:
-                    #return filt.check(db, obj.handle)
         if Filters.CustomFilters:
-            for filt in Filters.CustomFilters.get_filters(self.namespace):
-                if filt.get_name() == self.list[0]:
-                    return filt.check(db, obj.handle)
+            filters = Filters.CustomFilters.get_filters_dict(self.namespace)
+            if self.list[0] in filters:
+                filt = filters[self.list[0]]
+                return filt.check(db, obj.handle)
         return False
     
     def find_filter(self):
         """
         Return the selected filter or None.
         """
-        #if Filters.SystemFilters:
-            #for filt in Filters.SystemFilters.get_filters(self.namespace):
-                #if filt.get_name() == self.list[0]:
-                    #return filt
         if Filters.CustomFilters:
-            for filt in Filters.CustomFilters.get_filters(self.namespace):
-                if filt.get_name() == self.list[0]:
-                    return filt
+            filters = Filters.CustomFilters.get_filters_dict(self.namespace)
+            if self.list[0] in filters:
+                return filters[self.list[0]]
         return None
