@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,19 +19,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 7147 2006-08-10 00:42:44Z rshura $
+# $Id: __init__.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Package providing sidebar filters for GRAMPS.
 """
 
-__author__ = "Don Allingham"
-
 from _SidebarFilter import SidebarFilter
 from _PersonSidebarFilter import PersonSidebarFilter
 from _FamilySidebarFilter import FamilySidebarFilter
 from _EventSidebarFilter import EventSidebarFilter
 from _SourceSidebarFilter import SourceSidebarFilter
+from _CitationSidebarFilter import CitationSidebarFilter
 from _PlaceSidebarFilter import PlaceSidebarFilter
 from _MediaSidebarFilter import MediaSidebarFilter
 from _RepoSidebarFilter import RepoSidebarFilter
+from _NoteSidebarFilter import NoteSidebarFilter
