@@ -1,3 +1,26 @@
+#
+# Gramps - a GTK+/GNOME based genealogy program
+#
+# Copyright (C) 2000-2007  Donald N. Allingham
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+# GrampsLogger/_ErrorView.py
+# $Id: _ErrorView.py 18345 2011-10-18 18:14:07Z paul-franklin $
+
 #-------------------------------------------------------------------------
 #
 # GNOME modules
@@ -10,7 +33,8 @@ import gtk
 # gramps modules
 #
 #-------------------------------------------------------------------------
-from TransUtils import sgettext as _
+import const
+from gen.ggettext import sgettext as _
 from _ErrorReportAssistant import ErrorReportAssistant
 import GrampsDisplay
 
@@ -19,7 +43,7 @@ import GrampsDisplay
 # Constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_FAQ'
+WIKI_HELP_PAGE = '%s_-_FAQ' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|General')
 
 class ErrorView(object):
@@ -45,17 +69,20 @@ class ErrorView(object):
             if response == gtk.RESPONSE_HELP:
                 self.help_clicked()
             elif response == gtk.RESPONSE_YES:
+                self.top.destroy()
                 ErrorReportAssistant(error_detail = self._error_detail,
-                                     rotate_handler = self._rotate_handler)
-        self.top.destroy()
+                                     rotate_handler = self._rotate_handler,
+                                     ownthread=True)
+            elif response == gtk.RESPONSE_CANCEL:
+                self.top.destroy()
 
     def help_clicked(self):
         """Display the relevant portion of GRAMPS manual"""
         
-        GrampsDisplay.help('faq', WIKI_HELP_PAGE, WIKI_HELP_SEC)
+        GrampsDisplay.help(WIKI_HELP_PAGE, WIKI_HELP_SEC)
 
     def draw_window(self):
-        title = "%s - GRAMPS" % _("Error Report")
+        title = "%s - Gramps" % _("Error Report")
         self.top = gtk.Dialog(title)
         #self.top.set_default_size(400,350)
         self.top.set_has_separator(False)
@@ -66,7 +93,7 @@ class ErrorView(object):
         image = gtk.Image()
         image.set_from_stock(gtk.STOCK_DIALOG_ERROR, gtk.ICON_SIZE_DIALOG)
         label = gtk.Label('<span size="larger" weight="bold">%s</span>'
-                          % _("GRAMPS has experienced an unexpected error"))
+                          % _("Gramps has experienced an unexpected error"))
         label.set_use_markup(True)
 
         hbox.pack_start(image,False)
@@ -75,8 +102,8 @@ class ErrorView(object):
         self.top.vbox.pack_start(hbox,False,False,5)
 
         instructions_label = gtk.Label(
-            _("Your data will be safe but it would be advisable to restart GRAMPS immediately. "\
-              "If you would like to report the problem to the GRAMPS team "\
+            _("Your data will be safe but it would be advisable to restart Gramps immediately. "\
+              "If you would like to report the problem to the Gramps team "\
               "please click Report and the Error Reporting Wizard will help you "\
               "to make a bug report."))
         instructions_label.set_line_wrap(True)
