@@ -1,3 +1,26 @@
+#
+# Gramps - a GTK+/GNOME based genealogy program
+#
+# Copyright (C) 2000-2007  Donald N. Allingham
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+# GrampsLogger/_RotateHandler.py
+# $Id: _RotateHandler.py 18345 2011-10-18 18:14:07Z paul-franklin $
+
 import logging
 
 class RotateHandler(logging.Handler):
@@ -28,8 +51,8 @@ class RotateHandler(logging.Handler):
         Return the buffer with the records in the correct order.
         """
 
-        return [record for record in self._buffer[self._index:] + self._buffer[:self._index]
-                if record is not None]
+        return filter(None,
+                self._buffer[self._index:] + self._buffer[:self._index])
 
     def get_formatted_log(self, remove_tail_duplicate=None):
         """
