@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ManagedWindow.py 15318 2010-05-04 11:57:12Z ldnp $
+# $Id: ManagedWindow.py 15990 2010-10-15 16:58:41Z dsblank $
 
 """
 Provide the managed window interface, which allows GRAMPS to track
@@ -355,7 +355,7 @@ class ManagedWindow(object):
         self.height_key = None
         self.__refs_for_deletion = []
             
-        if uistate.gwm.get_item_from_id(window_key):
+        if uistate and uistate.gwm.get_item_from_id(window_key):
             uistate.gwm.get_item_from_id(window_key).present()
             raise Errors.WindowActiveError('This window is already active')
         else:
@@ -363,7 +363,10 @@ class ManagedWindow(object):
             self.submenu_label = submenu_label
             self.menu_label = menu_label
             self.uistate = uistate
-            self.track = self.uistate.gwm.add_item(track, self)
+            if uistate:
+                self.track = self.uistate.gwm.add_item(track, self)
+            else:
+                self.track = []
             # Work out parent_window
             if len(self.track) > 1:
             # We don't belong to the lop level
@@ -383,7 +386,10 @@ class ManagedWindow(object):
                     parent_item_track).window
             else:
                 # On the top level: we use gramps top window
-                self.parent_window = self.uistate.window
+                if self.uistate:
+                    self.parent_window = self.uistate.window
+                else:
+                    self.parent_window = None
 
     def set_window(self, window, title, text, msg=None, isWindow=False):
         """
@@ -428,7 +434,7 @@ class ManagedWindow(object):
         if glade_file is None:
             raise TypeError, "ManagedWindow.define_glade: no glade file"
             glade_file = const.GLADE_FILE
-        self._gladeobj = Glade(glade_file, "", top_module)
+        self._gladeobj = Glade(glade_file, None, top_module)
         return self._gladeobj
 
     def get_widget(self, name):
