@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: mergerepository.py 18669 2011-12-31 18:47:05Z m_d_n $
 
 """
 Provide merge capabilities for repositories.
@@ -136,11 +136,13 @@ class MergeRepositories(ManagedWindow.ManagedWindow):
         if use_handle1:
             phoenix = self.rp1
             titanic = self.rp2
-            unselect_path = (1,)
         else:
             phoenix = self.rp2
             titanic = self.rp1
-            unselect_path = (0,)
+            # Add second handle to history so that when merge is complete, 
+            # phoenix is the selected row.
+            self.uistate.viewmanager.active_page.get_history().push(
+                    phoenix.get_handle())
 
         if self.get_widget("name_btn1").get_active() ^ use_handle1:
             phoenix.set_name(titanic.get_name())
@@ -151,9 +153,6 @@ class MergeRepositories(ManagedWindow.ManagedWindow):
 
         query = MergeRepoQuery(self.dbstate, phoenix, titanic)
         query.execute()
-        if self.uistate.viewmanager.active_page.selection:
-            self.uistate.viewmanager.active_page.selection.unselect_path(
-                    unselect_path)
         self.uistate.set_busy_cursor(False)
         self.close()
 
