@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modiy
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ScratchPad.py 18633 2011-12-19 14:33:27Z m_d_n $
+# $Id: ScratchPad.py 19338 2012-04-15 20:42:40Z gburto01 $
 
 #------------------------------------------------------------------------
 #
@@ -87,6 +88,7 @@ for (name, file) in (
     ('name', 'geo-show-person.png'),
     ('repository', 'gramps-repository.png'),
     ('source', 'gramps-source.png'),
+    ('citation', 'gramps-citation.png'),
     ('text', 'gramps-font.png'),
     ('url', 'gramps-geo.png'),
     ):
@@ -102,8 +104,9 @@ def map2class(target):
     d = {"person-link": ScratchPersonLink,
          "family-link": ScratchFamilyLink,
          'personref': ScratchPersonRef,
+         'childref': ScratchChildRef,
          'source-link': ScratchSourceLink,
-         'srcref': ScratchSourceRef,
+         'citation-link': ScratchCitation,
          'repo-link': ScratchRepositoryLink,
          'pevent': ScratchEvent,
          'eventref': ScratchEventRef,
@@ -118,6 +121,7 @@ def obj2class(target):
     d= {"Person": ScratchPersonLink,
         "Family": ScratchFamilyLink,
         'Source': ScratchSourceLink,
+        'Citation': ScratchCitation,
         'Repository': ScratchRepositoryLink,
         'Event': ScratchEvent,
         'Media': ScratchMediaObj,
@@ -130,6 +134,7 @@ def obj2target(target):
     d = {"Person": 'person-link',
          "Family": 'family-link',
          'Source': 'source-link',
+         'Citation': 'citation-link',
          'Repository': 'repo-link',
          'Event': 'pevent',
          'Media': 'mediaobj',
@@ -285,6 +290,9 @@ class ScratchAddress(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchAddress, self).__init__(dbstate, obj)
         self._type  = _("Address")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = DateHandler.get_date(self._obj)
             self._value = "%s %s %s %s" % (self._obj.get_street(),
@@ -302,6 +310,9 @@ class ScratchLocation(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchLocation, self).__init__(dbstate, obj)
         self._type  = _("Location")
+        self.refresh()
+
+    def refresh(self):
         self._value = "%s %s %s" % (self._obj.get_city(),
                                     self._obj.get_state(),
                                     self._obj.get_country(),
@@ -317,6 +328,9 @@ class ScratchEvent(ScratchHandleWrapper):
         super(ScratchEvent, self).__init__(dbstate, obj)
         self._type  = _("Event")
         self._objclass = 'Event'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             value = self._db.get_event_from_handle(self._handle)
             if value:
@@ -341,6 +355,9 @@ class ScratchPlace(ScratchHandleWrapper):
         super(ScratchPlace, self).__init__(dbstate, obj)
         self._type  = _("Place")
         self._objclass = 'Place'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             value = self._db.get_place_from_handle(self._handle)
             if value:
@@ -365,6 +382,9 @@ class ScratchNote(ScratchHandleWrapper):
         super(ScratchNote, self).__init__(dbstate, obj)
         self._type  = _("Note")
         self._objclass = 'Note'
+        self.refresh()
+
+    def refresh(self):
         value = self._db.get_note_from_handle(self._handle)
         if value:
             self._title = value.get_gramps_id()
@@ -394,6 +414,9 @@ class ScratchFamilyEvent(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchFamilyEvent, self).__init__(dbstate, obj)
         self._type  = _("Family Event")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = str(self._obj.get_type())
             self._value = self._obj.get_description()
@@ -407,6 +430,9 @@ class ScratchUrl(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchUrl, self).__init__(dbstate, obj)
         self._type  = _("Url")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = self._obj.get_path()
             self._value = self._obj.get_description()
@@ -420,6 +446,9 @@ class ScratchAttribute(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchAttribute, self).__init__(dbstate, obj)
         self._type  = _("Attribute")
+        self.refresh()
+
+    def refresh(self):
         self._title = str(self._obj.get_type())
         self._value = self._obj.get_value()
 
@@ -432,28 +461,35 @@ class ScratchFamilyAttribute(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchFamilyAttribute, self).__init__(dbstate, obj)
         self._type  = _("Family Attribute")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = str(self._obj.get_type())
             self._value = self._obj.get_value()
 
-class ScratchSourceRef(ScratchObjWrapper):
+class ScratchCitation(ScratchHandleWrapper):
 
-    DROP_TARGETS = [DdTargets.SOURCEREF]
-    DRAG_TARGET  = DdTargets.SOURCEREF
-    ICON         = LINK_PIC
+    DROP_TARGETS = [DdTargets.CITATION_LINK]
+    DRAG_TARGET  = DdTargets.CITATION_LINK
+    ICON         = ICONS["citation"]
 
     def __init__(self, dbstate, obj):
-        super(ScratchSourceRef, self).__init__(dbstate, obj)
-        self._type  = _("Source ref")
-        if self._obj:
-            base = self._db.get_source_from_handle(self._obj.get_reference_handle())
-            if base:
-                self._title = base.get_title()
+        super(ScratchCitation, self).__init__(dbstate, obj)
+        self._type  = _("Citation")
+        self._objclass = 'Citation'
+        self.refresh()
+
+    def refresh(self):
+        if self._handle:
+            citation = self._db.get_citation_from_handle(self._handle)
+            if citation:
+                self._title = citation.get_gramps_id()
                 notelist = map(self._db.get_note_from_handle, 
-                               self._obj.get_note_list())
+                               citation.get_note_list())
                 srctxtlist = [note for note in notelist 
-                               if note.get_type() == gen.lib.NoteType.SOURCE_TEXT]
-                page = self._obj.get_page()
+                        if note.get_type() == gen.lib.NoteType.SOURCE_TEXT]
+                page = citation.get_page()
                 if not page:
                     page = _('not available|NA')
                 text = ""
@@ -469,6 +505,14 @@ class ScratchSourceRef(ScratchObjWrapper):
                                     'sourcetext' : text,
                                     }
 
+    def is_valid(self):
+        data = pickle.loads(self._obj)
+        handle = data[2]
+        obj = self._db.get_citation_from_handle(handle)
+        if obj:
+            return True
+        return False
+
 class ScratchRepoRef(ScratchObjWrapper):
 
     DROP_TARGETS = [DdTargets.REPOREF]
@@ -478,6 +522,9 @@ class ScratchRepoRef(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchRepoRef, self).__init__(dbstate, obj)
         self._type  = _("Repository ref")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             base = self._db.get_repository_from_handle(self._obj.ref)
             if base:
@@ -493,6 +540,9 @@ class ScratchEventRef(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchEventRef, self).__init__(dbstate, obj)
         self._type  = _("Event ref")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             base = self._db.get_event_from_handle(self._obj.ref)
             if base:
@@ -508,6 +558,9 @@ class ScratchName(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchName, self).__init__(dbstate, obj)
         self._type  = _("Name")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = str(self._obj.get_type())
             self._value = self._obj.get_name()
@@ -521,6 +574,9 @@ class ScratchSurname(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchSurname, self).__init__(dbstate, obj)
         self._type  = _("Surname")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             self._title = self._obj.get_surname()
             self._value = self._obj.get_surname()
@@ -534,9 +590,12 @@ class ScratchText(ScratchWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchText, self).__init__(dbstate, obj)
         self._type  = _("Text")
+        self._pickle = self._obj
+        self.refresh()
+
+    def refresh(self):
         self._title = _("Text")
         self._value = self._obj
-        self._pickle = self._obj
 
 class ScratchMediaObj(ScratchHandleWrapper):
 
@@ -548,6 +607,9 @@ class ScratchMediaObj(ScratchHandleWrapper):
         super(ScratchMediaObj, self).__init__(dbstate, obj)
         self._type  = _("Media")
         self._objclass = 'Media'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             obj = self._db.get_object_from_handle(self._handle)
             if obj:
@@ -571,6 +633,9 @@ class ScratchMediaRef(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchMediaRef, self).__init__(dbstate, obj)
         self._type  = _("Media ref")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             base = self._db.get_object_from_handle(self._obj.get_reference_handle())
             if base:
@@ -586,12 +651,36 @@ class ScratchPersonRef(ScratchObjWrapper):
     def __init__(self, dbstate, obj):
         super(ScratchPersonRef, self).__init__(dbstate, obj)
         self._type  = _("Person ref")
+        self.refresh()
+
+    def refresh(self):
         if self._obj:
             person = self._db.get_person_from_handle(self._obj.get_reference_handle())
             if person:
                 self._title = self._obj.get_relation()
                 self._value = person.get_primary_name().get_name()
 
+class ScratchChildRef(ScratchObjWrapper):
+
+    DROP_TARGETS = [DdTargets.CHILDREF]
+    DRAG_TARGET  = DdTargets.CHILDREF
+    ICON         = LINK_PIC
+
+    def __init__(self, dbstate, obj):
+        super(ScratchChildRef, self).__init__(dbstate, obj)
+        self._type  = _("Child ref")
+        self.refresh()
+
+    def refresh(self):
+        if self._obj:
+            person = self._db.get_person_from_handle(self._obj.get_reference_handle())
+            if person:
+                frel = str(self._obj.get_father_relation())
+                mrel = str(self._obj.get_mother_relation())
+                self._title = _('%(frel)s %(mrel)s') % {'frel': frel, 
+                                                        'mrel': mrel}
+                self._value = person.get_primary_name().get_name()
+
 class ScratchPersonLink(ScratchHandleWrapper):
 
     DROP_TARGETS = [DdTargets.PERSON_LINK]
@@ -602,6 +691,9 @@ class ScratchPersonLink(ScratchHandleWrapper):
         super(ScratchPersonLink, self).__init__(dbstate, obj)
         self._type  = _("Person")
         self._objclass = 'Person'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             person = self._db.get_person_from_handle(self._handle)
             if person:
@@ -624,10 +716,13 @@ class ScratchFamilyLink(ScratchHandleWrapper):
     ICON         = ICONS["family"]
 
     def __init__(self, dbstate, obj):
-        from Simple import SimpleAccess
         super(ScratchFamilyLink, self).__init__(dbstate, obj)
         self._type  = _("Family")
         self._objclass = 'Family'
+        self.refresh()
+
+    def refresh(self):
+        from Simple import SimpleAccess
         if self._handle:
             family = self._db.get_family_from_handle(self._handle)
             if family:
@@ -653,6 +748,9 @@ class ScratchSourceLink(ScratchHandleWrapper):
         super(ScratchSourceLink, self).__init__(dbstate, obj)
         self._type  = _("Source")
         self._objclass = 'Source'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             source = self._db.get_source_from_handle(self._handle)
             if source:
@@ -677,6 +775,9 @@ class ScratchRepositoryLink(ScratchHandleWrapper):
         super(ScratchRepositoryLink, self).__init__(dbstate, obj)
         self._type  = _("Repository")
         self._objclass = 'Repository'
+        self.refresh()
+
+    def refresh(self):
         if self._handle:
             source = self._db.get_repository_from_handle(self._handle)
             if source:
@@ -883,12 +984,14 @@ class ScratchPadListView(object):
             )
 
         for signal in db_signals:
-            self._db.connect(signal,self.remove_invalid_objects)
+            self._db.connect(signal,self.refresh_objects)
 
         self._db.connect('person-delete', 
                          gen_del_obj(self.delete_object, 'person-link'))
         self._db.connect('person-delete', 
                          gen_del_obj(self.delete_object_ref, 'personref'))
+        self._db.connect('person-delete', 
+                         gen_del_obj(self.delete_object_ref, 'childref'))
         self._db.connect('source-delete',
                          gen_del_obj(self.delete_object, 'source-link'))
         self._db.connect('source-delete',
@@ -909,15 +1012,18 @@ class ScratchPadListView(object):
                          gen_del_obj(self.delete_object, 'note-link'))
         # family-delete not needed, cannot be dragged!
 
-        self.remove_invalid_objects()
+        self.refresh_objects()
 
-    def remove_invalid_objects(self,dummy=None):
+    def refresh_objects(self,dummy=None):
         model = self._widget.get_model()
 
         if model:
             for o in model:
                 if not o[1].is_valid():
                     model.remove(o.iter)
+                else:
+                    o[1].refresh()
+                    o[4] = o[1].get_value() # Force listview to update
 
     def delete_object(self, handle_list, link_type):
         model = self._widget.get_model()
@@ -947,7 +1053,6 @@ class ScratchPadListView(object):
         self.register_wrapper_class(ScratchEvent)
         self.register_wrapper_class(ScratchPlace)
         self.register_wrapper_class(ScratchEventRef)
-        self.register_wrapper_class(ScratchSourceRef)
         self.register_wrapper_class(ScratchRepoRef)
         self.register_wrapper_class(ScratchFamilyEvent)
         self.register_wrapper_class(ScratchUrl)
@@ -958,12 +1063,14 @@ class ScratchPadListView(object):
         self.register_wrapper_class(ScratchMediaObj)
         self.register_wrapper_class(ScratchMediaRef)
         self.register_wrapper_class(ScratchSourceLink)
+        self.register_wrapper_class(ScratchCitation)
         self.register_wrapper_class(ScratchPersonLink)
         self.register_wrapper_class(ScratchFamilyLink)
         self.register_wrapper_class(ScratchDropList)
         self.register_wrapper_class(ScratchDropRawList)
         self.register_wrapper_class(ScratchDropHandleList)
         self.register_wrapper_class(ScratchPersonRef)
+        self.register_wrapper_class(ScratchChildRef)
         self.register_wrapper_class(ScratchText)
         self.register_wrapper_class(ScratchNote)
         
@@ -1228,7 +1335,7 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         
         #Database might have changed, objects might have been removed,
         #we need to reevaluate if all data is valid
-        self.object_list.remove_invalid_objects()
+        self.object_list.refresh_objects()
         
         self.top.connect_signals({
             "on_close_scratchpad" : self.close,
