@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2007  Donald N. Allingham
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +19,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# Simple/_SimpleAccess.py
+# $Id: _SimpleAccess.py 18584 2011-12-12 13:09:44Z dsblank $
+#
 
 """
 Provide a simplified database access interface to the GRAMPS database.
@@ -846,6 +850,20 @@ class SimpleAccess(object):
             return source.get_title()
         return u''
 
+    def page(self, citation):
+        """
+        Return the page of the citation.
+
+        @param citation: Source object
+        @type citation: L{gen.lib.Citation}
+        @return: title of the citation
+        @rtype: unicode
+        """
+        assert(isinstance(citation, (gen.lib.Citation, NoneType)))
+        if citation:
+            return citation.get_page()
+        return u''
+
     def author(self, source):
         """
         Return the author of the source.
@@ -905,6 +923,9 @@ class SimpleAccess(object):
                     return "%s: %s [%s]" % (_(object_class), 
                                             self.title(obj), 
                                             self.gid(obj))
+                elif isinstance(obj, gen.lib.Citation):
+                    return "%s: [%s]" % (_(object_class), 
+                                            self.gid(obj))
                 elif isinstance(obj, gen.lib.Place):
                     return "%s: %s [%s]" % (_(object_class), 
                                             place_name(self.dbase, 
@@ -947,14 +968,16 @@ class SimpleAccess(object):
             return "%s and %s" % (mother_text, father_text)
         elif isinstance(obj, gen.lib.MediaObject):
             return obj.desc
+        elif isinstance(obj, gen.lib.Citation):
+            return obj.gramps_id
         elif isinstance(obj, gen.lib.Source):
             return self.title(obj)
         elif isinstance(obj, gen.lib.Place):
             return place_name(self.dbase, obj.handle)
         elif isinstance(obj, gen.lib.Repository):
-            return obj.type
+            return obj.gramps_id
         elif isinstance(obj, gen.lib.Note):
-            return obj.type
+            return obj.gramps_id
         elif obj is None:
             return ""
         else:
