@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2008  Donald N. Allingham
 # Copyright (C) 2009  Douglas S. Blank
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +19,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# Simple/_SimpleTable.py
+# $Id: _SimpleTable.py 18584 2011-12-12 13:09:44Z dsblank $
+#
 
 """
 Provide a simplified table creation interface
@@ -152,7 +156,7 @@ class SimpleTable(object):
                 if (objclass == 'Filter' and 
                     handle[0] in ['Person', 'Family', 'Place', 'Event',
                                   'Repository', 'Note', 'MediaObject',
-                                  'Source']):
+                                  'Citation', 'Source']):
                     menu_item = gtk.MenuItem(_("See data not in Filter"))
                     menu_item.connect("activate", 
                       lambda widget: self.show_not_in_filter(handle[0]))
@@ -174,7 +178,7 @@ class SimpleTable(object):
         """
         Handle events on tables. obj is a treeview
         """
-        from gui.editors import (EditPerson, EditEvent, EditFamily, EditSource,
+        from gui.editors import (EditPerson, EditEvent, EditFamily, EditCitation, EditSource,
                                  EditPlace, EditRepository, EditNote, EditMedia)
         selection = obj.get_selection()
         store, paths = selection.get_selected_rows()
@@ -215,6 +219,15 @@ class SimpleTable(object):
                         return True # handled event
                     except Errors.WindowActiveError:
                         pass
+            elif objclass == 'Citation':
+                ref = self.access.dbase.get_citation_from_handle(handle)
+                if ref:
+                    try:
+                        EditCitation(self.simpledoc.doc.dbstate, 
+                                     self.simpledoc.doc.uistate, [], ref)
+                        return True # handled event
+                    except Errors.WindowActiveError:
+                        pass
             elif objclass == 'Source':
                 ref = self.access.dbase.get_source_from_handle(handle)
                 if ref:
@@ -345,6 +358,10 @@ class SimpleTable(object):
                 retval.append(self.access.describe(item))
                 if (self.__link_col == col or link is None):
                     link = ('Family', item.handle)
+            elif isinstance(item, gen.lib.Citation): 
+                retval.append(self.access.describe(item))
+                if (self.__link_col == col or link is None):
+                    link = ('Citation', item.handle)
             elif isinstance(item, gen.lib.Source): 
                 retval.append(self.access.describe(item))
                 if (self.__link_col == col or link is None):
