@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2009       Gary Burton
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Utils.py 17860 2011-06-28 23:07:09Z jralls $
+# $Id: Utils.py 19327 2012-04-14 12:19:00Z m_d_n $
 
 """
 Non GUI/GTK related utility functions
@@ -52,7 +53,7 @@ from GrampsLocale import codeset
 from Date import Date
 import DateHandler
 
-from const import TEMP_DIR, USER_HOME, GRAMPS_UUID
+from const import TEMP_DIR, USER_HOME, GRAMPS_UUID, IMAGE_DIR
 import constfunc
 from gen.ggettext import sgettext as _
 
@@ -88,11 +89,11 @@ def format_gender( type):
     return gender.get(type[0], _("Invalid"))
 
 confidence = {
-    gen.lib.SourceRef.CONF_VERY_HIGH : _("Very High"), 
-    gen.lib.SourceRef.CONF_HIGH      : _("High"), 
-    gen.lib.SourceRef.CONF_NORMAL    : _("Normal"), 
-    gen.lib.SourceRef.CONF_LOW       : _("Low"), 
-    gen.lib.SourceRef.CONF_VERY_LOW  : _("Very Low"), 
+    gen.lib.Citation.CONF_VERY_HIGH : _("Very High"), 
+    gen.lib.Citation.CONF_HIGH      : _("High"), 
+    gen.lib.Citation.CONF_NORMAL    : _("Normal"), 
+    gen.lib.Citation.CONF_LOW       : _("Low"), 
+    gen.lib.Citation.CONF_VERY_LOW  : _("Very Low"), 
    }
 
 family_rel_descriptions = {
@@ -123,7 +124,12 @@ def history_broken():
 data_recover_msg = _('The data can only be recovered by Undo operation '
             'or by quitting with abandoning changes.')
 
-def fix_encoding(value):
+def fix_encoding(value, errors='strict'):
+    # The errors argument specifies the response when the input string can't be
+    # converted according to the encoding's rules. Legal values for this
+    # argument are 'strict' (raise a UnicodeDecodeError exception), 'replace'
+    # (add U+FFFD, 'REPLACEMENT CHARACTER'), or 'ignore' (just leave the
+    # character out of the Unicode result).
     if not isinstance(value, unicode):
         try:
             return unicode(value)
@@ -135,7 +141,7 @@ def fix_encoding(value):
                     codeset = locale.getpreferredencoding()
             except:
                 codeset = "UTF-8"
-            return unicode(value, codeset)
+            return unicode(value, codeset, errors)
     else:
         return value
 
@@ -275,7 +281,7 @@ def encodingdefs():
     pass
 
 if constfunc.win():
-    # python encoding is ascii, but C functions need to recieve the 
+    # python encoding is ascii, but C functions need to receive the 
     # windows codeset, so convert over to it
     conv_utf8_tosrtkey = lambda x: locale.strxfrm(x.decode("utf-8").encode(
                                                         codeset))
@@ -286,7 +292,7 @@ if constfunc.win():
                                                                     codeset))
     conv_unicode_tosrtkey_ongtk = lambda x: locale.strxfrm(x.encode(codeset,'replace'))
 else:
-    # on unix C functions need to recieve utf-8. Default conversion would
+    # on unix C functions need to receive utf-8. Default conversion would
     # use ascii, so it is needed to be explicit about the resulting encoding 
     conv_utf8_tosrtkey = lambda x: locale.strxfrm(x)
     conv_unicode_tosrtkey = lambda x: locale.strxfrm(x.encode("utf-8"))
@@ -342,7 +348,7 @@ def find_folder( filename):
     except:
         pass
     
-    # Build list of elternate encodings
+    # Build list of alternate encodings
     try:
         encodings = [sys.getfilesystemencoding(), 
                      locale.getpreferredencoding(), 
@@ -370,7 +376,7 @@ def get_unicode_path_from_file_chooser(path):
     :rtype:      unicode
     :returns:    The Unicode version of path.
     """
-    # make omly unicode of path of type 'str'
+    # make only unicode of path of type 'str'
     if not (isinstance(path,  str)):
         return path
 
@@ -397,12 +403,12 @@ def get_unicode_path_from_env_var(path):
     :rtype:      unicode
     :returns:    The Unicode version of path.
     """
-    # make omly unicode of path of type 'str'
+    # make only unicode of path of type 'str'
     if not (isinstance(path,  str)):
         return path
 
     if constfunc.win():
-        # In Windows path/filename returned from a emvironment variable is in filesystemencoding
+        # In Windows path/filename returned from a environment variable is in filesystemencoding
         try:
             new_path = unicode(path, sys.getfilesystemencoding())
             return new_path
@@ -889,7 +895,7 @@ def probably_alive(person, db,
     """
     Return true if the person may be alive on current_date.
 
-    This works by a process of emlimination. If we can't find a good
+    This works by a process of elimination. If we can't find a good
     reason to believe that someone is dead then we assume they must
     be alive.
 
@@ -951,7 +957,7 @@ def probably_alive_range(person, db,
 def get_referents(handle, db, primary_objects):
     """ Find objects that refer to an object.
     
-    This function is the base for other get_<object>_referents finctions.
+    This function is the base for other get_<object>_referents functions.
     
     """
     # Use one pass through the reference map to grab all the references
@@ -972,11 +978,78 @@ def get_source_referents(source_handle, db):
     This function finds all primary objects that refer (directly or through
     secondary child-objects) to a given source handle in a given database.
     
+    Only Citations can refer to sources, so that is all we need to check
+    """
+    _primaries = ('Citation',)
+    
+    return (get_referents(source_handle, db, _primaries))
+
+def get_citation_referents(citation_handle, db):
+    """ Find objects that refer the citation.
+
+    This function finds all primary objects that refer (directly or through
+    secondary child-objects) to a given citation handle in a given database.
+    
     """
     _primaries = ('Person', 'Family', 'Event', 'Place', 
                   'Source', 'MediaObject', 'Repository')
     
-    return (get_referents(source_handle, db, _primaries))
+    return (get_referents(citation_handle, db, _primaries))
+
+def get_source_and_citation_referents(source_handle, db):
+    """ 
+    Find all citations that refer to the sources, and recursively, all objects
+    that refer to the sources.
+
+    This function finds all primary objects that refer (directly or through
+    secondary child-objects) to a given source handle in a given database.
+    
+    Objects -> Citations -> Source
+    e.g.
+    Media object M1  -> Citation C1 -> Source S1
+    Media object M2  -> Citation C1 -> Source S1
+    Person object P1 -> Citation C2 -> Source S1
+    
+    The returned structure is rather ugly, but provides all the information in
+    a way that is consistent with the other Util functions.
+    (
+    tuple of objects that refer to the source - only first element is present
+        ([C1, C2],),
+    list of citations with objects that refer to them
+        [
+            (C1, 
+                tuple of reference lists
+                  P,  F,  E,  Pl, S,  M,        R
+                ([], [], [], [], [], [M1, M2]. [])
+            )
+            (C2, 
+                tuple of reference lists
+                  P,    F,  E,  Pl, S,  M,  R
+                ([P1], [], [], [], [], []. [])
+            )
+        ]
+    )
+#47738: DEBUG: citationtreeview.py: line 428: source referents [(['bfe59e90dbb555d0d87'],)]
+#47743: DEBUG: citationtreeview.py: line 432: citation bfe59e90dbb555d0d87
+#47825: DEBUG: citationtreeview.py: line 435: citation_referents_list [[('bfe59e90dbb555d0d87', ([], [], ['ba77932bf0b2d59eccb'], [], [], [], []))]]
+#47827: DEBUG: citationtreeview.py: line 440: the_lists [((['bfe59e90dbb555d0d87'],), [('bfe59e90dbb555d0d87', ([], [], ['ba77932bf0b2d59eccb'], [], [], [], []))])]
+    
+    """
+    the_lists = get_source_referents(source_handle, db)
+    LOG.debug('source referents %s' % [the_lists])
+    # now, for each citation, get the objects that refer to that citation
+    citation_referents_list = []
+    for citation in the_lists[0]:
+        LOG.debug('citation %s' % citation)
+        refs = get_citation_referents(citation, db)
+        citation_referents_list += [(citation, refs)]
+    LOG.debug('citation_referents_list %s' % [citation_referents_list])    
+        
+    (citation_list) = the_lists
+    the_lists = (citation_list, citation_referents_list)
+
+    LOG.debug('the_lists %s' % [the_lists])
+    return the_lists 
 
 def get_media_referents(media_handle, db):
     """ Find objects that refer the media object.
@@ -985,7 +1058,7 @@ def get_media_referents(media_handle, db):
     to a given media handle in a given database.
     
     """
-    _primaries = ('Person', 'Family', 'Event', 'Place', 'Source')
+    _primaries = ('Person', 'Family', 'Event', 'Place', 'Source', 'Citation')
     
     return (get_referents(media_handle, db, _primaries))
 
@@ -997,7 +1070,7 @@ def get_note_referents(note_handle, db):
     
     """
     _primaries = ('Person', 'Family', 'Event', 'Place', 
-                  'Source', 'MediaObject', 'Repository')
+                  'Source', 'Citation', 'MediaObject', 'Repository')
     
     return (get_referents(note_handle, db, _primaries))
 
@@ -1296,13 +1369,13 @@ def update_constants():
 # Function to return the name of the main participant of an event
 #
 #-------------------------------------------------------------------------
-
-def get_participant_from_event(db, event_handle):
+def get_participant_from_event(db, event_handle, all_=False):
     """
     Obtain the first primary or family participant to an event we find in the 
     database. Note that an event can have more than one primary or 
     family participant, only one is returned, adding ellipses if there are
-    more. 
+    more. If the all_ parameter is true a comma-space separated string with
+    the names of all primary participants is returned and no ellipses is used.
     """
     participant = ""
     ellipses = False
@@ -1319,7 +1392,10 @@ def get_participant_from_event(db, event_handle):
             if event_handle == event_ref.ref and \
                     event_ref.get_role().is_primary():
                 if participant:
-                    ellipses = True
+                    if all_:
+                        participant += ', %s' % name_displayer.display(person)
+                    else:
+                        ellipses = True
                 else:
                     participant =  name_displayer.display(person)
                 break
@@ -1334,7 +1410,10 @@ def get_participant_from_event(db, event_handle):
             if event_handle == event_ref.ref and \
                     event_ref.get_role().is_family():
                 if participant:
-                    ellipses = True
+                    if all_:
+                        participant += ', %s' % family_name(family, db)
+                    else:
+                        ellipses = True
                 else:
                     participant = family_name(family, db)
                 break
@@ -1435,7 +1514,15 @@ def navigation_label(db, nav_type, handle):
     elif nav_type == 'Event':
         obj = db.get_event_from_handle(handle)
         if obj:
-            who = get_participant_from_event(db, handle)
+            try:
+                who = get_participant_from_event(db, handle)
+            except:
+                # get_participants_from_event fails when called during a magic
+                # batch transaction because find_backlink_handles tries to
+                # access the reference_map_referenced_map which doesn't exist
+                # under those circumstances. Since setting the navigation_label
+                # is inessential, just accept this and go on.
+                who = ''
             desc = obj.get_description()
             label = obj.get_type()
             if desc:
@@ -1450,11 +1537,18 @@ def navigation_label(db, nav_type, handle):
         obj = db.get_source_from_handle(handle)
         if obj:
             label = obj.get_title()
+    elif nav_type == 'Citation':
+        obj = db.get_citation_from_handle(handle)
+        if obj:
+            label = obj.get_page()
+            src = db.get_source_from_handle(obj.get_reference_handle())
+            if src:
+                label = src.get_title() + " "  + label
     elif nav_type == 'Repository':
         obj = db.get_repository_from_handle(handle)
         if obj:
             label = obj.get_name()
-    elif nav_type == 'Media':
+    elif nav_type == 'Media' or nav_type == 'MediaObject':
         obj = db.get_object_from_handle(handle)
         if obj:
             label = obj.get_description()
@@ -1487,3 +1581,154 @@ def format_time(secs):
     t = time.localtime(secs)
     d = Date(t.tm_year, t.tm_mon, t.tm_mday)
     return DateHandler.displayer.display(d) + time.strftime(' %X', t)
+
+#-------------------------------------------------------------------------
+#
+# make_unknown
+#
+#-------------------------------------------------------------------------
+def make_unknown(class_arg, explanation, class_func, commit_func, transaction,
+                 **argv):
+    """
+    Make a primary object and set some property so that it qualifies as
+    "Unknown".
+
+    Some object types need extra parameters:
+    Family: db, Event: type (optional),
+    Citation: methods to create/store source.
+
+    Some theoretical underpinning
+    This function exploits the fact that all import methods basically do the
+    same thing: Create an object of the right type, fill it with some
+    attributes, store it in the database. This function does the same, so
+    the observation is why not use the creation and storage methods that the 
+    import routines use themselves, that makes nice reuse of code. To do this
+    formally correct we would need to specify a interface (in the OOP sence)
+    which the import methods would need to implement. For now, that is deemed
+    too restrictive and here we just slip through because of the similarity in
+    code of both GEDCOM and XML import methods.
+
+    :param class_arg: The argument the class_func needs, typically a kind of id.
+    :type class_arg: unspecified
+    :param explanation: Handle of a note that explains the origin of primary obj
+    :type explanation: str
+    :param class_func: Method to create primary object.
+    :type class_func: method
+    :param commit_func: Method to store primary object in db.
+    :type commit_func: method
+    :param transactino: Database transaction handle
+    :type transaction: str
+    :param argv: Possible additional parameters
+    :type param: unspecified
+    :returns: List of newly created objects.
+    :rtype: list
+    """
+    retval = []
+    obj = class_func(class_arg)
+    if isinstance(obj, gen.lib.Person):
+        surname = gen.lib.Surname()
+        surname.set_surname('Unknown')
+        name = gen.lib.Name()
+        name.add_surname(surname)
+        name.set_type(gen.lib.NameType.UNKNOWN)
+        obj.set_primary_name(name)
+    elif isinstance(obj, gen.lib.Family):
+        obj.set_relationship(gen.lib.FamilyRelType.UNKNOWN)
+        handle = obj.handle
+        if getattr(argv['db'].transaction, 'no_magic', False):
+            backlinks = argv['db'].find_backlink_handles(
+                    handle, [gen.lib.Person.__name__])
+            for dummy, person_handle in backlinks:
+                person = argv['db'].get_person_from_handle(person_handle)
+                add_personref_to_family(obj, person)
+        else:
+            for person in argv['db'].iter_people():
+                if person._has_handle_reference('Family', handle):
+                    add_personref_to_family(obj, person)
+    elif isinstance(obj, gen.lib.Event):
+        if 'type' in argv:
+            obj.set_type(argv['type'])
+        else:
+            obj.set_type(gen.lib.EventType.UNKNOWN)
+    elif isinstance(obj, gen.lib.Place):
+        obj.set_title(_('Unknown'))
+    elif isinstance(obj, gen.lib.Source):
+        obj.set_title(_('Unknown'))
+    elif isinstance(obj, gen.lib.Citation):
+        #TODO create a new source for every citation?
+        obj2 = argv['source_class_func'](argv['source_class_arg'])
+        obj2.set_title(_('Unknown'))
+        obj2.add_note(explanation)
+        argv['source_commit_func'](obj2, transaction, time.time())
+        retval.append(obj2)
+        obj.set_reference_handle(obj2.handle)
+    elif isinstance(obj, gen.lib.Repository):
+        obj.set_name(_('Unknown'))
+        obj.set_type(gen.lib.RepositoryType.UNKNOWN)
+    elif isinstance(obj, gen.lib.MediaObject):
+        obj.set_path(os.path.join(IMAGE_DIR, "image-missing.png"))
+        obj.set_mime_type('image/png')
+        obj.set_description(_('Unknown'))
+    elif isinstance(obj, gen.lib.Note):
+        obj.set_type(gen.lib.NoteType.UNKNOWN);
+        text = _('Unknown, created to replace a missing note object.')
+        link_start = text.index(',') + 2
+        link_end = len(text) - 1
+        tag = gen.lib.StyledTextTag(gen.lib.StyledTextTagType.LINK,
+                'gramps://Note/handle/%s' % explanation,
+                [(link_start, link_end)])
+        obj.set_styledtext(gen.lib.StyledText(text, [tag]))
+    elif isinstance(obj, gen.lib.Tag):
+        if not hasattr(make_unknown, 'count'):
+            make_unknown.count = 1 #primitive static variable
+        obj.set_name(_("Unknown, was missing %s (%d)") %
+                (time.strftime('%x %X', time.localtime()),
+                make_unknown.count))
+        make_unknown.count += 1
+    else:
+        raise TypeError("Object if of unsupported type")
+
+    if hasattr(obj, 'add_note'):
+        obj.add_note(explanation)
+    commit_func(obj, transaction, time.time())
+    retval.append(obj)
+    return retval
+
+def create_explanation_note(dbase):
+    """
+    When creating objects to fill missing primary objects in imported files,
+    those objects of type "Unknown" need a explanatory note. This funcion
+    provides such a note for import methods.
+    """
+    note = gen.lib.Note( _('Objects referenced by this note '
+                                    'were missing in a file imported on %s.') %
+                                    time.strftime('%x %X', time.localtime()))
+    note.set_handle(create_id())
+    note.set_gramps_id(dbase.find_next_note_gramps_id())
+    # Use defaults for privacy, format and type.
+    return note
+
+def add_personref_to_family(family, person):
+    """
+    Given a family and person, set the parent/child references in the family,
+    that match the person.
+    """
+    handle = family.handle
+    person_handle = person.handle
+    if handle in person.get_family_handle_list():
+        if ((person.get_gender() == gen.lib.Person.FEMALE) and
+                (family.get_mother_handle() is None)):
+            family.set_mother_handle(person_handle)
+        else:
+            # This includes cases of gen.lib.Person.UNKNOWN
+            if family.get_father_handle() is None:
+                family.set_father_handle(person_handle)
+            else:
+                family.set_mother_handle(person_handle)
+    if handle in person.get_parent_family_handle_list():
+        childref = gen.lib.ChildRef()
+        childref.set_reference_handle(person_handle)
+        childref.set_mother_relation(gen.lib.ChildRefType.UNKNOWN)
+        childref.set_father_relation(gen.lib.ChildRefType.UNKNOWN)
+        family.add_child_ref(childref)
+
