@@ -3,10 +3,12 @@
 #
 # Copyright (C) 2000-2006  Donald N. Allingham, A. Roitman
 # Copyright (C) 2007-2009  B. Malengier
-# Copyright (C) 2008 Lukasz Rymarczyk
-# Copyright (C) 2008 Raphael Ackermann
-# Copyright (C) 2008 Brian G. Matherly
-# Copyright (C) 2010 Jakim Friant
+# Copyright (C) 2008       Lukasz Rymarczyk
+# Copyright (C) 2008       Raphael Ackermann
+# Copyright (C) 2008       Brian G. Matherly
+# Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2012       Doug Blank
+# Copyright (C) 2012       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +25,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: arghandler.py 17690 2011-06-06 02:02:13Z pez4brian $
+# $Id: arghandler.py 18845 2012-02-10 18:38:27Z paul-franklin $
 
 """
 Module responsible for handling the command line arguments for GRAMPS.
@@ -62,8 +64,8 @@ def _split_options(options_str):
     Split the options for the action.
     
     Rules:
-        * Entries in the list of options are separated by commas without spaces
-          between entries
+        * Entries in the list of options are separated by commas without
+          spaces between entries
         * List values must be inclosed in brackets ("[" and "]")
         * Entries within a list value are separated by commas
         * Text values (as a value or as entries in a list) do not have to be
@@ -168,7 +170,7 @@ class ArgHandler(object):
         self.imports = []
         self.exports = []
 
-        self.open = self.__handle_open_option(parser.open)
+        self.open = self.__handle_open_option(parser.open, parser.create)
         self.sanitize_args(parser.imports, parser.exports)
     
     def __error(self, msg1, msg2=None):
@@ -178,7 +180,7 @@ class ArgHandler(object):
         if self.errorfunc:
             self.errorfunc(msg1)
         else:
-            # Need to convert to system file encoding  before printing
+            # Need to convert to system file encoding before printing
             # For non latin characters in path/file/user names
             print >> sys.stderr, msg1.encode(sys.getfilesystemencoding())
             if msg2 is not None:
@@ -196,10 +198,11 @@ class ArgHandler(object):
         for (value, family_tree_format) in exportlist:
             self.__handle_export_option(value, family_tree_format)
 
-    def __handle_open_option(self, value):
+    def __handle_open_option(self, value, create):
         """
-        Handle the "-O" or "--open" option.
-        Only Family trees or a dir with a family tree can be opened.                  
+        Handle the "-O" or "--open" and "-C" or "--create" options.
+        Only Family trees or a dir with a family tree can be opened.
+        If create is True, then create the tree if it doesn't exist.
         """
         if value is None:
             return None
@@ -211,11 +214,19 @@ class ArgHandler(object):
             # Check if it is good.
             if not self.check_db(db_path, self.force_unlock):
                 sys.exit(0)
+            if create:
+                self.__error( _("Error: Family tree '%s' already exists.\n"
+                                "The '-C' option cannot be used.") % value)
+                sys.exit(0)
+            return db_path
+        elif create:
+            # create the tree here, and continue
+            db_path, title = self.dbman.create_new_db_cli(title=value)
             return db_path
         else:
             self.__error( _('Error: Input family tree "%s" does not exist.\n'
-                    "If GEDCOM, Gramps-xml or grdb, use the -i option to "
-                    "import into a family tree instead.") % value)
+                            "If GEDCOM, Gramps-xml or grdb, use the -i option "
+                            "to import into a family tree instead.") % value)
             sys.exit(0)
 
     def __handle_import_option(self, value, family_tree_format):
@@ -248,9 +259,9 @@ class ArgHandler(object):
             self.imports.append((fname, family_tree_format))
         else:
             self.__error(_('Error: Unrecognized type: "%(format)s" for '
-                    'import file: %(filename)s') \
-                  % {'format' : family_tree_format, 
-                     'filename' : fname})
+                           'import file: %(filename)s') % 
+                           {'format' : family_tree_format, 
+                            'filename' : fname})
             sys.exit(0)
             
     def __handle_export_option(self, value, family_tree_format):
@@ -260,7 +271,7 @@ class ArgHandler(object):
         """
         if self.gui:
             return
-        # Need to covert path/filename to unicode before openingh
+        # Need to convert path/filename to unicode before opening
         # For non latin characters in Windows path/file/user names
         value = Utils.get_unicode_path_from_env_var(value)
         fname = value
@@ -270,13 +281,17 @@ class ArgHandler(object):
             fullpath = os.path.abspath(os.path.expanduser(fname))
             if os.path.exists(fullpath):
                 self.__error(_("WARNING: Output file already exists!\n"
-                        "WARNING: It will be overwritten:\n   %(name)s") % \
-                        {'name' : fullpath})
+                               "WARNING: It will be overwritten:\n   %s") % 
+                               fullpath)
                 answer = None
                 while not answer:
-                    answer = raw_input(_('OK to overwrite? (yes/no) ') \
-                                        .encode(sys.getfilesystemencoding()))
-                if answer.upper() in ('Y', 'YES', _('YES').upper()):
+                    try:
+                        ans = raw_input(_('OK to overwrite? (yes/no) ') \
+                                         .encode(sys.getfilesystemencoding()))
+                    except EOFError:
+                        print
+                        sys.exit(0)
+                if ans.upper() in ('Y', 'YES', _('YES').upper()):
                     self.__error( _("Will overwrite the existing file: %s") 
                                     % fullpath)
                 else:
@@ -332,9 +347,9 @@ class ArgHandler(object):
         method to handle the arguments that can be given for a GUI session.
         Returns the filename of the family tree that should be opened if 
         user just passed a famtree or a filename
-            1/no options: a family tree can be given, if so, this name is tested
-                        and returned. If a filename, it is imported in a new db
-                        and name of new db returned
+            1/no options: a family tree can be given, if so, this name is
+                        tested and returned. If a filename, it is imported
+                        in a new db and name of new db returned
             2/an open and/or import option can have been given, if so, this 
                 is handled, and None is returned
             
@@ -384,16 +399,20 @@ class ArgHandler(object):
         """
 
         if self.list:
-            print 'List of known family trees in your database path\n'
-            for name, dirname in sorted(self.dbman.family_tree_list(), key=lambda pair: pair[0].lower()):
-                print "%s with name \"%s\"" % (dirname, name.encode(sys.getfilesystemencoding()))
+            print _('List of known family trees in your database path\n')
+            for name, dirname in sorted(self.dbman.family_tree_list(),
+                                        key=lambda pair: pair[0].lower()):
+                print _("%(full_DB_path)s with name \"%(f_t_name)s\"") % \
+                        {'full_DB_path' : dirname,
+                         'f_t_name' : name.encode(sys.getfilesystemencoding())}
             sys.exit(0)
             
         if self.list_more:
-            print 'Gramps Family Trees:'
+            print _('Gramps Family Trees:')
             summary_list = self.dbman.family_tree_summary()
-            for summary in sorted(summary_list, key=lambda summary: summary["Family tree"].lower()):
-                print "Family Tree \"%s\":" % summary["Family tree"]
+            for summary in sorted(summary_list,
+                                  key=lambda sum: sum["Family tree"].lower()):
+                print _("Family Tree \"%s\":") % summary["Family tree"]
                 for item in sorted(summary):
                     if item != "Family tree":
                         print "   %s: %s" % (item, summary[item])
@@ -402,27 +421,30 @@ class ArgHandler(object):
         self.__open_action()
         self.__import_action()
             
-        for (action, options_str) in self.actions:
-            print >> sys.stderr, "Performing action: %s." % action
-            if options_str:
-                print >> sys.stderr, "Using options string: %s" % options_str
-            self.cl_action(action, options_str)
+        for (action, op_string) in self.actions:
+            print >> sys.stderr, _("Performing action: %s.") % action
+            if op_string:
+                print >> sys.stderr, _("Using options string: %s") % op_string
+            self.cl_action(action, op_string)
 
         for expt in self.exports:
             # Need to convert path/filename to str before printing
             # For non latin characters in Windows path/file/user names
             fn = expt[0].encode(sys.getfilesystemencoding())
             fmt = str(expt[1])
-            print >> sys.stderr, "Exporting: file %s, format %s." % (fn, fmt)
+            print >> sys.stderr, _("Exporting: file %(filename)s, "
+                                   "format %(format)s.") % \
+                                   {'filename' : fn,
+                                    'format' : fmt}
             self.cl_export(expt[0], expt[1])
 
         if cleanup:
             self.cleanup()
-            print >> sys.stderr, "Exiting."
+            print >> sys.stderr, _("Exiting.")
             sys.exit(0)
 
     def cleanup(self):
-        print >> sys.stderr, "Cleaning up."
+        print >> sys.stderr, _("Cleaning up.")
         # remove files in import db subdir after use
         self.dbstate.db.close()
         if self.imp_db_path:
@@ -430,12 +452,12 @@ class ArgHandler(object):
 
     def __import_action(self):
         """
-        Take action for all given to import files. Note: Family trees are not
-            supported.
-        If a family tree is open, the import happens on top of it. If not open, 
-        a new family tree is created, and the import done. If this is CLI, 
-        the created tree is deleted at the end (as some action will have 
-        happened that is now finished), if this is GUI, it is opened.
+        Take action for all given import files. Note: Family trees are
+            not supported.
+        If a family tree is open, the import happens on top of it. If not
+        open, a new family tree is created, and the import done. If this
+        is CLI, the created tree is deleted at the end (as some action will
+        have happened that is now finished), if this is GUI, it is opened.
         """
         if self.imports:
             self.cl = bool(self.exports or self.actions or self.cl)
@@ -452,16 +474,19 @@ class ArgHandler(object):
                 
                 try:
                     self.sm.open_activate(self.imp_db_path)
-                    print >> sys.stderr, "Created empty family tree successfully"
+                    msg = _("Created empty family tree successfully")
+                    print >> sys.stderr, msg
                 except:
-                    print >> sys.stderr, "Error opening the file." 
-                    print >> sys.stderr, "Exiting..." 
+                    print >> sys.stderr, _("Error opening the file.")
+                    print >> sys.stderr, _("Exiting...")
                     sys.exit(0)
 
             for imp in self.imports:
                 fn = imp[0].encode(sys.getfilesystemencoding())
                 fmt = str(imp[1])
-                print >> sys.stderr, "Importing: file %s, format %s." % (fn, fmt)
+                msg = _("Importing: file %(filename)s, format %(format)s.") % \
+                        {'filename' : fn, 'format' : fmt}
+                print >> sys.stderr, msg
                 self.cl_import(imp[0], imp[1])
 
     def __open_action(self):
@@ -477,10 +502,10 @@ class ArgHandler(object):
             # we load this file for use
             try:
                 self.sm.open_activate(self.open)
-                print >> sys.stderr, "Opened successfully!"
+                print >> sys.stderr, _("Opened successfully!")
             except:
-                print >> sys.stderr, "Error opening the file." 
-                print >> sys.stderr, "Exiting..." 
+                print >> sys.stderr, _("Error opening the file.")
+                print >> sys.stderr, _("Exiting...")
                 sys.exit(0)
 
     def check_db(self, dbpath, force_unlock = False):
@@ -506,7 +531,8 @@ class ArgHandler(object):
     #-------------------------------------------------------------------------
     def cl_import(self, filename, family_tree_format):
         """
-        Command-line import routine. Try to import filename using the family_tree_format.
+        Command-line import routine.
+        Try to import filename using the family_tree_format.
         """
         pmgr = BasePluginManager.get_instance()
         for plugin in pmgr.get_import_plugins():
@@ -551,7 +577,7 @@ class ArgHandler(object):
                 options_str_dict = _split_options(options_str)
             except:
                 options_str_dict = {}
-                print >> sys.stderr, "Ignoring invalid options string."
+                print >> sys.stderr, _("Ignoring invalid options string.")
 
             name = options_str_dict.pop('name', None)
             _cl_list = pmgr.get_reg_reports(gui=False)
@@ -574,13 +600,15 @@ class ArgHandler(object):
                                       options_str_dict)
                         return
                 # name exists, but is not in the list of valid report names
-                msg = "Unknown report name."
+                msg = _("Unknown report name.")
             else:
-                msg = "Report name not given. Please use one of [-p|--options] name=reportname."
+                msg = _("Report name not given. "
+                        "Please use one of %(donottranslate)s=reportname") % \
+                        {'donottranslate' : '[-p|--options] name'}
             
-            print >> sys.stderr, "%s\n Available names are:" % msg
+            print >> sys.stderr, _("%s\n Available names are:") % msg
             for pdata in sorted(_cl_list, key= lambda pdata: pdata.id.lower()):
-                # Print cli report name ([item[0]) and GUI report name (item[4])
+                # Print cli report name ([item[0]), GUI report name (item[4])
                 if len(pdata.id) <= 25:
                     print >> sys.stderr, \
                         "   %s%s- %s" % ( pdata.id, " " * (26 - len(pdata.id)),
@@ -596,7 +624,7 @@ class ArgHandler(object):
                                            chunk in options_str.split(',') ] )
             except:
                 options_str_dict = {}
-                print >> sys.stderr, "Ignoring invalid options string."
+                print >> sys.stderr, _("Ignoring invalid options string.")
 
             name = options_str_dict.pop('name', None)
             _cli_tool_list = pmgr.get_reg_tools(gui=False)
@@ -613,13 +641,16 @@ class ArgHandler(object):
                         tool.cli_tool(self.dbstate, name, category, tool_class,
                                       options_class, options_str_dict)
                         return
-                msg = "Unknown tool name."
+                msg = _("Unknown tool name.")
             else:
-                msg = "Tool name not given. Please use one of [-p|--options] name=toolname."
+                msg = _("Tool name not given. "
+                        "Please use one of %(donottranslate)s=toolname.") % \
+                        {'donottranslate' : '[-p|--options] name'}
             
-            print >> sys.stderr, "%s\n Available names are:" % msg
-            for pdata in sorted(_cli_tool_list, key=lambda pdata: pdata.id.lower()):
-                # Print cli report name ([item[0]) and GUI report name (item[4])
+            print >> sys.stderr, _("%s\n Available names are:") % msg
+            for pdata in sorted(_cli_tool_list,
+                                key=lambda pdata: pdata.id.lower()):
+                # Print cli report name ([item[0]), GUI report name (item[4])
                 if len(pdata.id) <= 25:
                     print >> sys.stderr, \
                         "   %s%s- %s" % ( pdata.id, " " * (26 - len(pdata.id)),
@@ -628,5 +659,5 @@ class ArgHandler(object):
                     print >> sys.stderr, "   %s\t- %s" % (pdata.id,
                                  pdata.name.encode(sys.getfilesystemencoding()))
         else:
-            print >> sys.stderr, "Unknown action: %s." % action
+            print >> sys.stderr, _("Unknown action: %s.") % action
             sys.exit(0)
