@@ -4,9 +4,11 @@
 #
 # Copyright (C) 2000-2006  Donald N. Allingham, A. Roitman
 # Copyright (C) 2007-2009  B. Malengier
-# Copyright (C) 2008 Lukasz Rymarczyk
-# Copyright (C) 2008 Raphael Ackermann
-# Copyright (C) 2008 Brian G. Matherly
+# Copyright (C) 2008       Lukasz Rymarczyk
+# Copyright (C) 2008       Raphael Ackermann
+# Copyright (C) 2008       Brian G. Matherly
+# Copyright (C) 2012       Doug Blank
+# Copyright (C) 2012       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +25,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: argparser.py 16818 2011-03-13 09:00:16Z ldnp $
+# $Id: argparser.py 18845 2012-02-10 18:38:27Z paul-franklin $
 
 """
 Module responsible for handling the command line arguments for GRAMPS.
@@ -60,6 +62,7 @@ Help options
 
 Application options
   -O, --open=FAMILY_TREE                 Open family tree
+  -C, --create=FAMILY_TREE               Create on open if new family tree
   -i, --import=FILENAME                  Import file
   -e, --export=FILENAME                  Export file
   -f, --format=FORMAT                    Specify family tree format
@@ -131,15 +134,15 @@ class ArgParser(object):
     Possible: 
         1/ FAMTREE : Just the family tree (name or database dir)
         2/ -O, --open=FAMTREE, Open of a family tree
-        3/ -i, --import=FILE, Import a family tree of any format understood by an 
-                 importer, optionally provide- f to indicate format
-        4/ -e, --export=FILE, export a family tree in required format, optionally 
-                 provide -f to indicate format
+        3/ -i, --import=FILE, Import a family tree of any format understood 
+                 by an importer, optionally provide -f to indicate format
+        4/ -e, --export=FILE, export a family tree in required format,
+                 optionally provide -f to indicate format
         5/ -f, --format=FORMAT : format after a -i or -e option
         6/ -a, --action: An action (possible: 'report', 'tool')
         7/ -p, --options=OPTIONS_STRING : specify options
-        8/ -u, --force-unlock: A locked database can be unlocked by giving this
-                argument when opening it
+        8/ -u, --force-unlock: A locked database can be unlocked by giving
+                 this argument when opening it
     
     If the filename (no flags) is specified, the interactive session is 
     launched using data from filename. 
@@ -174,6 +177,7 @@ class ArgParser(object):
         self.help = False
         self.usage = False
         self.force_unlock = False
+        self.create = None
         self.runqml = False
 
         self.errors = []
@@ -191,18 +195,18 @@ class ArgParser(object):
         Possible: 
         1/ Just the family tree (name or database dir)
         2/ -O, --open:   Open of a family tree
-        3/ -i, --import: Import a family tree of any format understood by an importer, 
-                 optionally provide-f to indicate format
-        4/ -e, --export: export a family tree in required format, optionally provide
-                 -f to indicate format
+        3/ -i, --import: Import a family tree of any format understood by
+                 an importer, optionally provide -f to indicate format
+        4/ -e, --export: export a family tree in required format, optionally
+                 provide -f to indicate format
         5/ -f, --format=FORMAT : format after a -i or -e option
         6/ -a, --action: An action (possible: 'report', 'tool')
         7/ -p, --options=OPTIONS_STRING : specify options
-        8/ -u, --force-unlock: A locked database can be unlocked by giving this
-                 argument when opening it
+        8/ -u, --force-unlock: A locked database can be unlocked by giving
+                 this argument when opening it
         9/ -s  --show : Show config settings
-        10/ -c --config=config.setting:value : Set config.setting and start Gramps
-                 without :value, the actual config.setting is shown
+        10/ -c --config=config.setting:value : Set config.setting and start
+                 Gramps without :value, the actual config.setting is shown
                             
         """
         try:
@@ -252,6 +256,8 @@ class ArgParser(object):
             option, value = options[opt_ix]
             if option in ( '-O', '--open'):
                 self.open = value
+            elif option in ( '-C', '--create'):
+                self.create = value
             elif option in ( '-i', '--import'):
                 family_tree_format = None
                 if opt_ix < len(options) - 1 \
@@ -339,16 +345,17 @@ class ArgParser(object):
         if len(options) > 0 and self.open is None and self.imports == [] \
                 and not (self.list or self.list_more or self.help or self.runqml):
             # Extract and convert to unicode the arguments in the list.
-            # The % operator replaces the list elements with repr() of the list elemements
-            # which is OK for latin characters, but not for non latin characters in list elements
+            # The % operator replaces the list elements with repr() of
+            # the list elements, which is OK for latin characters
+            # but not for non-latin characters in list elements
             cliargs = "[ "
             for arg in range(len(self.args) - 1):
                 cliargs += Utils.get_unicode_path_from_env_var(self.args[arg + 1]) + " "
             cliargs += "]"
-            self.errors += [(_('Error parsing the arguments'), 
-                        _("Error parsing the arguments: %s \n" 
-                        "To use in the command-line mode," \
-                "supply at least one input file to process.") % cliargs)]
+            self.errors += [(_('Error parsing the arguments'),
+                             _("Error parsing the arguments: %s \n"
+                               "To use in the command-line mode, supply at "
+                               "least one input file to process.") % cliargs)]
         if need_to_quit:
             sys.exit(0)
 
@@ -375,6 +382,12 @@ class ArgParser(object):
             if (self.exports or self.actions):
                 # have both data and what to do with it => no GUI
                 return False
+            elif self.create:
+                if self.open: # create an empty DB, open a GUI to fill it
+                    return True
+                else: # create a DB, then do the import, with no GUI
+                    self.open = self.create
+                    return False
             else:
                 # data given, but no action/export => GUI
                 return True
