@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: clidbman.py 16631 2011-02-16 18:38:01Z m_d_n $
+# $Id: clidbman.py 18915 2012-02-17 16:51:40Z romjerome $
 
 """
 Provide the management of databases from CLI. This includes opening, renaming,
@@ -35,6 +35,9 @@ creating, and deleting of databases.
 import os
 import sys
 import time
+import urllib2
+import urlparse
+import tempfile
 from gen.ggettext import gettext as _
 #-------------------------------------------------------------------------
 #
@@ -286,6 +289,24 @@ class CLIDbManager(object):
                  or (None, None) if no import was performed.
         """
         pmgr = BasePluginManager.get_instance()
+        # Allow URL names here; make temp file if necessary
+        url = urlparse.urlparse(filename)
+        if url.scheme != "":
+            if url.scheme == "file":
+                filename = urllib2.url2pathname(filename[7:])
+            else:
+                url_fp = urllib2.urlopen(filename) # open URL
+                # make a temp local file:
+                ext = os.path.splitext(url.path)[1]
+                fd, filename = tempfile.mkstemp(suffix=ext)
+                temp_fp = os.fdopen(fd, "w")
+                # read from URL:
+                data = url_fp.read()
+                # write locally:
+                temp_fp.write(data)
+                url_fp.close()
+                temp_fp.close()
+
         (name, ext) = os.path.splitext(os.path.basename(filename))
         format = ext[1:].lower()
 
@@ -441,6 +462,7 @@ def find_locker_name(dirpath):
         # Otherwise problems with non ASCII characters in
         # username in Windows
         username = unicode(username, sys.getfilesystemencoding())
+        # feature request 2356: avoid genitive form
         last = _("Locked by %s") % username
         ifile.close()
     except (OSError, IOError):
