@@ -25,7 +25,7 @@
 #
 # cli.plug.__init__
 #
-# $Id: __init__.py 17806 2011-06-19 02:46:33Z pez4brian $
+# $Id: __init__.py 18848 2012-02-10 19:57:57Z nick-h $
 
 
 #-------------------------------------------------------------------------
@@ -62,6 +62,7 @@ from gen.plug.report._paper import paper_sizes
 import const
 import DbState
 from cli.grampscli import CLIManager
+import cli.user
 
 #------------------------------------------------------------------------
 #
@@ -87,14 +88,14 @@ def _convert_str_to_match_type(str_val, type_val):
         if str_val.isdigit():
             return int(str_val)
         else:
-            print "%s is not an integer number" % str_val
+            print "'%s' is not an integer number" % str_val
             return 0
         
     elif ret_type == float:
         try:
             return float(str_val)
         except ValueError:
-            print "%s is not a decimal number" % str_val
+            print "'%s' is not a decimal number" % str_val
             return 0.0
         
     elif ret_type == bool:
@@ -103,13 +104,13 @@ def _convert_str_to_match_type(str_val, type_val):
         elif str_val == str(False):
             return False
         else:
-            print "%s is not a boolean-- try 'True' or 'False'" % str_val
+            print "'%s' is not a boolean-- try 'True' or 'False'" % str_val
             return False
     
     elif ret_type == list:
         ret_val = []
         if not ( str_val.startswith("[") and str_val.endswith("]") ):
-            print "%s is not a list-- try: [%s]" % (str_val, str_val)
+            print "'%s' is not a list-- try: [%s]" % (str_val, str_val)
             return ret_val
         
         entry = ""
@@ -146,7 +147,6 @@ def _validate_options(options, dbase):
     dbase: the database the options will be applied to
     """
     if not hasattr(options, "menu"):
-        print 'no menu'
         return
     menu = options.menu
     
@@ -165,7 +165,7 @@ def _validate_options(options, dbase):
                         phandle = None
                     person = dbase.get_person_from_handle(phandle)
                     if not person:
-                        print "ERROR: Please specify a person"
+                        print _("ERROR: Please specify a person")
             if person:
                 option.set_value(person.get_gramps_id())
             
@@ -189,7 +189,7 @@ def _validate_options(options, dbase):
                     family = dbase.get_family_from_handle(family_handle)
                     option.set_value(family.get_gramps_id())
                 else:
-                    print "ERROR: Please specify a family"
+                    print _("ERROR: Please specify a family")
 
 #------------------------------------------------------------------------
 #
@@ -322,6 +322,15 @@ class CommandLineReport(object):
         """
         Initialize the options that are defined by each report.
         """
+
+        if self.category == CATEGORY_BOOK: # a Book Report has no "menu"
+            for key in self.option_class.options_dict:
+                self.options_dict[key] = self.option_class.options_dict[key]
+                self.options_help[key] = \
+                    self.option_class.options_help[key][:3]
+            # a Book Report can't have HTML output so "css" is meaningless
+            self.options_dict.pop('css')
+
         if not hasattr(self.option_class, "menu"):
             return
         menu = self.option_class.menu
@@ -391,18 +400,22 @@ class CommandLineReport(object):
             elif isinstance(option, Option):
                 self.options_help[name].append(option.get_help())
             else:
-                print "Unknown option: ", option
-                print "   Valid options are:", ", ".join(self.options_dict.keys())
-                print "   Use 'show=option' to see description and acceptable values"
+                print _("Unknown option: %s") % option
+                print _("   Valid options are:"), ", ".join(
+                                                     self.options_dict.keys())
+                print (_("   Use '%(donottranslate)s' to see description "
+                         "and acceptable values") %
+                       {'donottranslate' : "show=option"})
                 
     def parse_options(self):
         """
         Load the options that the user has entered.
         """
         if not hasattr(self.option_class, "menu"):
-            return
-        menu = self.option_class.menu
-        menu_opt_names = menu.get_all_option_names()
+            menu = None
+        else:
+            menu = self.option_class.menu
+            menu_opt_names = menu.get_all_option_names()
         for opt in self.options_str_dict:
             if opt in self.options_dict:
                 self.options_dict[opt] = \
@@ -412,18 +425,22 @@ class CommandLineReport(object):
                 self.option_class.handler.options_dict[opt] = \
                                                         self.options_dict[opt]
                                                         
-                if opt in menu_opt_names:
+                if menu and opt in menu_opt_names:
                     option = menu.get_option_by_name(opt)
                     option.set_value(self.options_dict[opt])
                 
             else:
-                print "Ignoring unknown option: %s" % opt
-                print "   Valid options are:", ", ".join(self.options_dict.keys())
-                print "   Use 'show=option' to see description and acceptable values"
+                print _("Ignoring unknown option: %s") % opt
+                print _("   Valid options are:"), ", ".join(
+                                                     self.options_dict.keys())
+                print (_("   Use '%(donottranslate)s' to see description "
+                         "and acceptable values") %
+                       {'donottranslate' : "show=option"})
         
         self.option_class.handler.output = self.options_dict['of']
 
         self.css_filename = None
+        _chosen_format = None
         if self.category == CATEGORY_TEXT:
             for plugin in self.__textdoc_plugins:
                 if plugin.get_extension() == self.options_dict['off']:
@@ -432,6 +449,7 @@ class CommandLineReport(object):
             if self.format is None:
                 # Pick the first one as the default.
                 self.format = self.__textdoc_plugins[0].get_basedoc()
+                _chosen_format = self.__textdoc_plugins[0].get_extension()
         elif self.category == CATEGORY_DRAW:
             for plugin in self.__drawdoc_plugins:
                 if plugin.get_extension() == self.options_dict['off']:
@@ -439,6 +457,7 @@ class CommandLineReport(object):
             if self.format is None:
                 # Pick the first one as the default.
                 self.format = self.__drawdoc_plugins[0].get_basedoc()
+                _chosen_format = self.__drawdoc_plugins[0].get_extension()
         elif self.category == CATEGORY_BOOK:
             for plugin in self.__bookdoc_plugins:
                 if plugin.get_extension() == self.options_dict['off']:
@@ -446,6 +465,7 @@ class CommandLineReport(object):
             if self.format is None:
                 # Pick the first one as the default.
                 self.format = self.__bookdoc_plugins[0].get_basedoc()
+                _chosen_format = self.__bookdoc_plugins[0].get_extension()
         elif self.category == CATEGORY_GRAPHVIZ:
             for graph_format in graphdoc.FORMATS:
                 if graph_format['ext'] == self.options_dict['off']:
@@ -454,8 +474,17 @@ class CommandLineReport(object):
             if self.format is None:
                 # Pick the first one as the default.
                 self.format = graphdoc.FORMATS[0]["class"]
+                _chosen_format = graphdoc.FORMATS[0]["ext"]
         else:
             self.format = None
+        if _chosen_format and self.options_str_dict.has_key('off'):
+            print (_("Ignoring '%(notranslate1)s=%(notranslate2)s' "
+                     "and using '%(notranslate1)s=%(notranslate3)s'.") %
+                   {'notranslate1' : "off",
+                    'notranslate2' : self.options_dict['off'],
+                    'notranslate3' : _chosen_format})
+            print (_("Use '%(notranslate)s' to see valid values.") %
+                   {'notranslate' : "show=off"})
 
         for paper in paper_sizes:
             if paper.get_name() == self.options_dict['papers']:
@@ -488,27 +517,29 @@ class CommandLineReport(object):
         if not self.show:
             return
         elif self.show == 'all':
-            print "   Available options:"
+            print _("   Available options:")
             for key in sorted(self.options_dict.keys()):
                 if key in self.options_help:
                     opt = self.options_help[key]
-                # Make the output nicer to read, assume that tab has 8 spaces
+                    # Make the output nicer to read, assume a tab has 8 spaces
                     tabs = '\t\t' if len(key) < 10 else '\t'
                     optmsg = "      %s%s%s (%s)" % (key, tabs, opt[1], opt[0])
                     print optmsg.encode(sys.getfilesystemencoding())
                 else:
                     optmsg = " %s" % key
                     print optmsg.encode(sys.getfilesystemencoding())
-            print "   Use 'show=option' to see description and acceptable values"
+            print (_("   Use '%(donottranslate)s' to see description "
+                     "and acceptable values") %
+                   {'donottranslate' : "show=option"})
         elif self.show in self.options_help:
             opt = self.options_help[self.show]
             tabs = '\t\t' if len(self.show) < 10 else '\t'
-            print '   %s%s%s%s' % (self.show, tabs, opt[0], opt[1])
-            print "   Available values are:"
+            print '   %s%s%s (%s)' % (self.show, tabs, opt[1], opt[0])
+            print _("   Available values are:")
             vals = opt[2]
             if isinstance(vals, (list, tuple)):
                 for val in vals:
-                    optmsg = " %s" % val
+                    optmsg = "      %s" % val
                     print optmsg.encode(sys.getfilesystemencoding())
             else:
                 optmsg = "      %s" % opt[2]
@@ -516,8 +547,9 @@ class CommandLineReport(object):
 
         else:
             #there was a show option given, but the option is invalid
-            print ("option %s not valid. Use 'show=all' to see all valid "  
-                  "options." % self.show)
+            print (_("option '%(optionname)s' not valid. "
+                     "Use '%(donottranslate)s' to see all valid options.") %
+                   {'optionname' : self.show, 'donottranslate' : "show=all"})
 
 #------------------------------------------------------------------------
 #
@@ -550,7 +582,7 @@ def cl_report(database, name, category, report_class, options_class,
         if clr.css_filename is not None and \
            hasattr(clr.option_class.handler.doc, 'set_css_filename'):
             clr.option_class.handler.doc.set_css_filename(clr.css_filename)
-        MyReport = report_class(database, clr.option_class)
+        MyReport = report_class(database, clr.option_class, cli.user.User())
         MyReport.doc.init()
         MyReport.begin_report()
         MyReport.write_report()
@@ -560,6 +592,8 @@ def cl_report(database, name, category, report_class, options_class,
         (m1, m2) = msg.messages()
         print err_msg
         print m1
+        if m2:
+            print m2
     except:
         if len(log.handlers) > 0:
             log.error(err_msg, exc_info=True)
@@ -595,7 +629,7 @@ def run_report(db, name, **options_str_dict):
     """
     dbstate = DbState.DbState()
     climanager = CLIManager(dbstate, False) # don't load db
-    climanager.do_reg_plugins()
+    climanager.do_reg_plugins(dbstate, None)
     pmgr = BasePluginManager.get_instance()
     cl_list = pmgr.get_reg_reports()
     clr = None
