@@ -5,6 +5,7 @@
 # Copyright (C) 2005-2007  Donald N. Allingham
 # Copyright (C) 2008-2009  Gary Burton 
 # Copyright (C) 2009       Doug Blank <doug.blank@gmail.com>
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: config.py 17607 2011-05-28 15:50:31Z bmcage $
+# $Id: config.py 19265 2012-04-07 19:01:53Z nick-h $
 
 """
 This package implements access to GRAMPS configuration.
@@ -127,8 +128,8 @@ register('behavior.addmedia-relative-path', False)
 register('behavior.autoload', False)
 register('behavior.avg-generation-gap', 20)
 register('behavior.betawarn', False)
-register('behavior.check-for-updates', 2)
-register('behavior.check-for-update-types', ["update", "new"])
+register('behavior.check-for-updates', 0)
+register('behavior.check-for-update-types', ["new"])
 register('behavior.last-check-for-updates', "1970/01/01")
 register('behavior.previously-seen-updates', [])
 register('behavior.do-not-show-previously-seen-updates', True)
@@ -177,13 +178,19 @@ register('interface.attribute-height', 350)
 register('interface.attribute-width', 600)
 register('interface.child-ref-height', 450)
 register('interface.child-ref-width', 600)
+register('interface.citation-height', 450)
+register('interface.citation-sel-height', 450)
+register('interface.citation-sel-width', 600)
+register('interface.citation-width', 600)
 register('interface.clipboard-height', 300)
 register('interface.clipboard-width', 300)
 register('interface.dont-ask', False)
 register('interface.view-categories',
          ["Gramplets", "People", "Relationships", "Families", 
           "Ancestry", "Events", "Places", "Geography", "Sources",
-          "Repositories", "Media", "Notes"])
+          "Citations", "Repositories", "Media", "Notes"])
+register('interface.edit-filter-width', 500)
+register('interface.edit-filter-height', 420)
 register('interface.edit-rule-width', 600)
 register('interface.edit-rule-height', 450)
 register('interface.event-height', 450)
@@ -197,6 +204,8 @@ register('interface.family-sel-height', 450)
 register('interface.family-sel-width', 600)
 register('interface.family-width', 700)
 register('interface.filter', False)
+register('interface.filter-editor-width', 400)
+register('interface.filter-editor-height', 350)
 register('interface.fullscreen', False)
 register('interface.height', 500)
 register('interface.lds-height', 450)
@@ -266,6 +275,7 @@ register('paths.quick-backup-filename',
 
 register('preferences.date-format', 0)
 register('preferences.calendar-format-report', 0)
+register('preferences.cprefix', 'C%04d')
 register('preferences.default-source', False)
 register('preferences.eprefix', 'E%04d')
 register('preferences.family-warn', True)
@@ -293,6 +303,7 @@ register('preferences.use-last-view', True)
 register('preferences.last-view', '')
 register('preferences.last-views', [])
 register('preferences.use-bsddb3', False)
+register('preferences.family-relation-type', 3) # UNKNOWN
 
 register('researcher.researcher-addr', '')
 register('researcher.researcher-locality', '')
