@@ -3,6 +3,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2012       Doug Blank
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in 18717 2012-01-07 07:47:07Z romjerome $
+# $Id: const.py.in 18845 2012-02-10 18:38:27Z paul-franklin $
 
 """
 Provides constants for other modules
@@ -41,11 +42,11 @@ from gen.ggettext import sgettext as _
 #
 #-------------------------------------------------------------------------
 PROGRAM_NAME   = "Gramps"
-if "3.3.2-1" == "@" + "VERSIONSTRING" + "@":
-    VERSION        = "3.3.2"
+if "3.4.0-1" == "@" + "VERSIONSTRING" + "@":
+    VERSION        = "3.4.0"
 else:
-    VERSION        = "3.3.2-1"
-VERSION_TUPLE  = (3, 3, 2)
+    VERSION        = "3.4.0-1"
+VERSION_TUPLE  = (3, 4, 0)
 
 #-------------------------------------------------------------------------
 #
@@ -56,11 +57,11 @@ URL_HOMEPAGE    = "http://gramps-project.org/"
 URL_MAILINGLIST = "http://sourceforge.net/mail/?group_id=25770"
 URL_BUGTRACKER  = "http://bugs.gramps-project.org/bug_report_advanced_page.php"
 URL_WIKISTRING  = "http://gramps-project.org/wiki/index.php?title="
-URL_MANUAL_PAGE = "Gramps_3.3_Wiki_Manual"
+URL_MANUAL_PAGE = "Gramps_3.4_Wiki_Manual"
 WIKI_FAQ = "FAQ"
-WIKI_KEYBINDINGS = "Gramps_3.3_Wiki_Manual_-_Keybindings"
-WIKI_EXTRAPLUGINS= "3.3_Addons"
-WIKI_EXTRAPLUGINS_RAWDATA = "Plugins3.3&action=raw"
+WIKI_KEYBINDINGS = "Gramps_3.4_Wiki_Manual_-_Keybindings"
+WIKI_EXTRAPLUGINS= "3.4_Addons"
+WIKI_EXTRAPLUGINS_RAWDATA = "Plugins3.4&action=raw"
 
 #-------------------------------------------------------------------------
 #
@@ -178,7 +179,7 @@ RULE_GLADE     = os.path.join(GLADE_DIR, "rule.glade")
 
 PLUGINS_DIR      = os.path.join(ROOT_DIR, "plugins")
 DATA_DIR         = os.path.join(ROOT_DIR, "data")
-WEB_DIR          = os.path.join(ROOT_DIR, 'web')
+WEB_DIR          = os.path.join(ROOT_DIR, 'webapp')
 #SYSTEM_FILTERS  = os.path.join(DATA_DIR, "system_filters.xml")
 TIP_DATA         = os.path.join(DATA_DIR, "tips.xml")
 WEBSTUFF_DIR     = os.path.join(PLUGINS_DIR, "webstuff")
@@ -245,6 +246,7 @@ NO_GIVEN         = "(%s)" % _("none")
 POPT_TABLE = [
     ("config",  'c',  str, None, 0, "Set config setting(s) and start Gramps",  ""),
     ("open",    'O', str, None, 0, "Open family tree",  "FAMILY_TREE"), 
+    ("create",  'C', str, None, 0, "Create or Open family tree",  "FAMILY_TREE"), 
     ("import",  'i', str, None, 0, "Import file",       "FILENAME"), 
     ("export",  'e', str, None, 0, "Export file",       "FILENAME"),
     ("format",  'f', str, None, 0, 'Specify format',    "FORMAT"), 
@@ -286,6 +288,7 @@ LONGOPTS = [
     "oaf-ior-fd=", 
     "oaf-private",
     "open=",
+    "create=",
     "options=",
     "screen=",
     "show", 
@@ -298,6 +301,6 @@ LONGOPTS = [
     "qml",
 ]
 
-SHORTOPTS = "O:i:e:f:a:p:d:c:lLhuv?s"
+SHORTOPTS = "O:C:i:e:f:a:p:d:c:lLhuv?s"
 
 GRAMPS_UUID =  uuid.UUID('516cd010-5a41-470f-99f8-eb22f1098ad6')
