@@ -17,5 +17,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# gen/__init__.py
+# $Id: __init__.py 18361 2011-10-23 03:13:50Z paul-franklin $
+#
 
-__all__ = [ "proxy", "db", "lib", "utils", "plug" ]
+"""
+The gen module provides packages that are common to all gramps 
+interfaces (gui, cli and web).
+"""
+
+__all__ = [ "db", "display", "lib", "mime", "plug", "proxy", "utils" ]
