@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2010       Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: base.py 18021 2011-08-09 20:35:04Z m_d_n $
+# $Id: base.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Base class for the GRAMPS databases. All database interfaces should inherit
@@ -611,6 +612,12 @@ class DbReadBase(object):
         """
         raise NotImplementedError
 
+    def get_raw_citation_data(self, handle):
+        """
+        Return raw (serialized and pickled) Citation object from handle
+        """
+        raise NotImplementedError
+
     def get_raw_tag_data(self, handle):
         """
         Return raw (serialized and pickled) Tag object from handle
@@ -736,6 +743,44 @@ class DbReadBase(object):
         """
         raise NotImplementedError
 
+    def get_citation_bookmarks(self):
+        """
+        Return the list of Citation handles in the bookmarks.
+        """
+        raise NotImplementedError
+
+    def get_citation_cursor(self):
+        """
+        Return a reference to a cursor over Citation objects
+        """
+        raise NotImplementedError
+
+    def get_citation_from_gramps_id(self, val):
+        """
+        Find a Citation in the database from the passed gramps' ID.
+        
+        If no such Citation exists, None is returned.
+        Needs to be overridden by the derived class.
+        """
+        raise NotImplementedError
+
+    def get_citation_from_handle(self, handle):
+        """
+        Find a Citation in the database from the passed gramps' ID.
+        
+        If no such Citation exists, None is returned.
+        """
+        raise NotImplementedError
+
+    def get_citation_handles(self, sort_handles=False):
+        """
+        Return a list of database handles, one handle for each Citation in
+        the database.
+        
+        If sort_handles is True, the list is sorted by Citation title.
+        """
+        raise NotImplementedError
+
     def get_surname_list(self):
         """
         Return the list of locale-sorted surnames contained in the database.
@@ -1057,7 +1102,8 @@ class DbReadBase(object):
         """
         raise NotImplementedError
 
-    def set_prefixes(self, person, media, family, source, place, event, repository, note):
+    def set_prefixes(self, person, media, family, source, place, event,
+                     repository, note):
         """
         Set the prefixes for the gramps ids for all gramps objects
         """
@@ -1133,7 +1179,7 @@ class DbReadBase(object):
         """
         raise NotImplementedError
 
-class DbWriteBase(object):
+class DbWriteBase(DbReadBase):
     """
     GRAMPS database object. This object is a base class for all
     database interfaces.  All methods raise NotImplementedError
@@ -1147,6 +1193,7 @@ class DbWriteBase(object):
         A new DbWriteBase class should never be directly created. Only classes 
         derived from this class should be created.
         """
+        DbReadBase.__init__(self)
 
     def add_event(self, event, transaction, set_gid=True):
         """
@@ -1598,7 +1645,8 @@ class DbWriteBase(object):
     
         # loop through the family list 
         for family_handle in person.get_family_handle_list():
-            if not family_handle: continue
+            if not family_handle:
+                continue
     
             family = self.get_family_from_handle(family_handle)
     
@@ -1607,7 +1655,8 @@ class DbWriteBase(object):
             else:
                 family.set_mother_handle(None)
     
-            if not family.get_father_handle() and not family.get_mother_handle() and \
+            if not family.get_father_handle() and \
+                    not family.get_mother_handle() and \
                     not family.get_child_ref_list():
                 self.remove_family_relationships(family_handle, trans)
             else:
@@ -1631,9 +1680,9 @@ class DbWriteBase(object):
             self.find_backlink_handles(handle,['Person'])]
         
         for phandle in person_list:
-            p = self.get_person_from_handle(phandle)
-            p.remove_handle_references('Person', [handle])
-            self.commit_person(p, trans)
+            prsn = self.get_person_from_handle(phandle)
+            prsn.remove_handle_references('Person', [handle])
+            self.commit_person(prsn, trans)
         self.remove_person(handle, trans)
     
     def remove_family_relationships(self, family_handle, trans=None):
