@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: attrtype.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: attrtype.py 16178 2010-11-11 14:55:36Z romjerome $
 
 """
 Provide the different Attribute Types for GRAMPS.
@@ -54,6 +54,7 @@ class AttributeType(GrampsType):
     FATHER_AGE  = 11
     MOTHER_AGE  = 12
     WITNESS     = 13
+    TIME        = 14
 
     _CUSTOM = CUSTOM
     _DEFAULT = ID
@@ -74,6 +75,7 @@ class AttributeType(GrampsType):
         (FATHER_AGE  , _("Father's Age"), "Father Age"),
         (MOTHER_AGE  , _("Mother's Age"), "Mother Age"),
         (WITNESS     , _("Witness"), "Witness"),
+        (TIME        , _("Time"), "Time"),
         ]
 
     def __init__(self, value=None):
