@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: familyreltype.py 10811 2008-06-16 15:01:46Z gbritton $
+# $Id: familyreltype.py 18687 2012-01-02 15:12:18Z dsblank $
 
 """
 Provide the different family reference types.
@@ -27,7 +27,7 @@ Provide the different family reference types.
 # Python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -35,6 +35,7 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 from gen.lib.grampstype import GrampsType
+import config
 
 class FamilyRelType(GrampsType):
 
@@ -57,5 +58,5 @@ class FamilyRelType(GrampsType):
 
     def __init__(self, value=None):
         if value is None:
-            value = self.UNKNOWN
+            value = config.get("preferences.family-relation-type")
         GrampsType.__init__(self, value)
