@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2010       Michiel D. Nauta
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: notebase.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: notebase.py 15645 2010-07-22 02:16:32Z dsblank $
 
 """
 NoteBase class for GRAMPS.
@@ -41,14 +42,10 @@ class NoteBase(object):
         """
         Create a new NoteBase, copying from source if not None.
         
-        @param source: Object used to initialize the new object
-        @type source: NoteBase
+        :param source: Object used to initialize the new object
+        :type source: NoteBase
         """
-        
-        if source:
-            self.note_list = [handle for handle in source.note_list]
-        else:
-            self.note_list = []
+        self.note_list = list(source.note_list) if source else []
 
     def serialize(self):
         """
@@ -60,17 +57,17 @@ class NoteBase(object):
         """
         Convert a serialized tuple of data to an object.
         """
-        self.note_list = [handle for handle in data]
+        self.note_list = list(data)
 
     def add_note(self, handle):
         """
-        Add the L{Note} handle to the list of note handles.
+        Add the :class:`~gen.lib.note.Note` handle to the list of note handles.
 
-        @param handle: L{Note} handle to add the list of notes
-        @type handle: str
+        :param handle: :class:`~gen.lib.note.Note` handle to add the list of notes
+        :type handle: str
 
-        @return: True if handle was added, False if it already was in the list
-        @rtype: bool
+        :returns: True if handle was added, False if it already was in the list
+        :rtype: bool
         """
         if handle in self.note_list:
             return False
@@ -83,8 +80,8 @@ class NoteBase(object):
         Remove the specified handle from the list of note handles, and all
         secondary child objects.
 
-        @param handle: L{Note} handle to remove from the list of notes
-        @type handle: str
+        :param handle: :class:`~gen.lib.note.Note` handle to remove from the list of notes
+        :type handle: str
         """
         if handle in self.note_list:
             self.note_list.remove(handle)
@@ -99,38 +96,96 @@ class NoteBase(object):
         with notes, should return here a list of child objects which are 
         NoteBase
 
-        @return: Returns the list of child secondary child objects that may 
+        :returns: Returns the list of child secondary child objects that may 
                 refer notes.
-        @rtype: list
+        :rtype: list
         """
         return []
 
     def get_note_list(self):
         """
-        Return the list of L{Note} handles associated with the object.
+        Return the list of :class:`~gen.lib.note.Note` handles associated with the object.
 
-        @return: The list of L{Note} handles
-        @rtype: list
+        :returns: The list of :class:`~gen.lib.note.Note` handles
+        :rtype: list
         """
         return self.note_list
 
+    def has_note_reference(self, note_handle):
+        """
+        Return True if the object or any of its child objects has reference 
+        to this note handle.
+
+        :param note_handle: The note handle to be checked.
+        :type note_handle: str
+        :returns: Returns whether the object or any of its child objects has
+                  reference to this note handle.
+        :rtype: bool
+        """
+        for note_ref in self.note_list:
+            if note_ref == note_handle:
+                return True
+
+        for item in self.get_note_child_list():
+            if item.has_note_reference(note_handle):
+                return True
+
+        return False
+
     def set_note_list(self, note_list):
         """
-        Assign the passed list to be object's list of L{Note} handles.
+        Assign the passed list to be object's list of :class:`~gen.lib.note.Note` handles.
 
-        @param note_list: List of L{Note} handles to be set on the object
-        @type note_list: list
+        :param note_list: List of :class:`~gen.lib.note.Note` handles to be set on the object
+        :type note_list: list
         """
         self.note_list = note_list
 
+    def _merge_note_list(self, acquisition):
+        """
+        Merge the list of notes from acquisition with our own.
+
+        :param acquisition: The note list of this object will be merged with
+            the current note list.
+        :rtype acquisition: NoteBase
+        """
+        for addendum in acquisition.note_list:
+            self.add_note(addendum)
+
     def get_referenced_note_handles(self):
         """
         Return the list of (classname, handle) tuples for all referenced notes.
         
-        This method should be used to get the L{Note} portion of the list
+        This method should be used to get the :class:`~gen.lib.note.Note` portion of the list
         by objects that store note lists.
         
-        @return: List of (classname, handle) tuples for referenced objects.
-        @rtype: list
+        :returns: List of (classname, handle) tuples for referenced objects.
+        :rtype: list
         """
         return [('Note', handle) for handle in self.note_list]
+
+    def replace_note_references(self, old_handle, new_handle):
+        """
+        Replace references to note handles in the list of this object and
+        all child objects and merge equivalent entries.
+
+        :param old_handle: The note handle to be replaced.
+        :type old_handle: str
+        :param new_handle: The note handle to replace the old one with.
+        :type new_handle: str
+        """
+        refs_list = self.note_list[:]
+        new_ref = None
+        if new_handle in self.note_list:
+            new_ref = new_handle
+        n_replace = refs_list.count(old_handle)
+        for ix_replace in xrange(n_replace):
+            idx = refs_list.index(old_handle)
+            if new_ref:
+                self.note_list.pop(idx)
+                refs_list.pop(idx)
+            else:
+                self.note_list[idx] = new_handle
+
+        for item in self.get_note_child_list():
+            item.replace_note_references(old_handle, new_handle)
