@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007 Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: primaryobj.py 16025 2010-10-22 23:22:33Z nick-h $
+# $Id: primaryobj.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Basic Primary Object class for GRAMPS.
@@ -31,7 +32,7 @@ Basic Primary Object class for GRAMPS.
 #-------------------------------------------------------------------------
 from gen.lib.tableobj import TableObject
 from gen.lib.privacybase import PrivacyBase
-from gen.lib.srcbase import SourceBase
+from gen.lib.citationbase import CitationBase
 from gen.lib.mediabase import MediaBase
 
 #-------------------------------------------------------------------------
@@ -130,15 +131,6 @@ class BasicPrimaryObject(TableObject, PrivacyBase):
         """
         pass
 
-    def has_source_reference(self, handle):
-        """
-        Indicate if the object has a source references. 
-        
-        In the base class, no such references exist. Derived classes should 
-        override this if they provide source references.
-        """
-        return False
-
     def has_media_reference(self, handle):
         """
         Indicate if the object has a media references. 
@@ -148,7 +140,7 @@ class BasicPrimaryObject(TableObject, PrivacyBase):
         """
         return False
 
-    def remove_source_references(self, handle_list):
+    def remove_citation_references(self, handle_list):
         """
         Remove the specified source references from the object. 
         
@@ -166,7 +158,7 @@ class BasicPrimaryObject(TableObject, PrivacyBase):
         """
         pass
 
-    def replace_source_references(self, old_handle, new_handle):
+    def replace_citation_references(self, old_handle, new_handle):
         pass
 
     def replace_media_references(self, old_handle, new_handle):
@@ -214,8 +206,8 @@ class PrimaryObject(BasicPrimaryObject):
           of this object type.
         :rtype: bool
         """
-        if classname == 'Source' and isinstance(self, SourceBase):
-            return self.has_source_reference(handle)
+        if classname == 'Citation' and isinstance(self, CitationBase):
+            return self.has_citation_reference(handle)
         elif classname == 'MediaObject' and isinstance(self, MediaBase):
             return self.has_media_reference(handle)
         else:
@@ -230,8 +222,8 @@ class PrimaryObject(BasicPrimaryObject):
         :param handle_list: The list of handles to be removed.
         :type handle_list: str
         """
-        if classname == 'Source' and isinstance(self, SourceBase):
-            self.remove_source_references(handle_list)
+        if classname == 'Citation' and isinstance(self, CitationBase):
+            self.remove_citation_references(handle_list)
         elif classname == 'MediaObject' and isinstance(self, MediaBase):
             self.remove_media_references(handle_list)
         else:
@@ -248,8 +240,8 @@ class PrimaryObject(BasicPrimaryObject):
         :param new_handle: The handle to replace the old one with.
         :type new_handle: str
         """
-        if classname == 'Source' and isinstance(self, SourceBase):
-            self.replace_source_references(old_handle, new_handle)
+        if classname == 'Citation' and isinstance(self, CitationBase):
+            self.replace_citation_references(old_handle, new_handle)
         elif classname == 'MediaObject' and isinstance(self, MediaBase):
             self.replace_media_references(old_handle, new_handle)
         else:
