@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2005  Donald N. Allingham
+# Copyright (C) 2010       Michiel D. Nauta
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: privacybase.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: privacybase.py 15645 2010-07-22 02:16:32Z dsblank $
 
 """
 PrivacyBase Object class for GRAMPS.
@@ -41,8 +42,8 @@ class PrivacyBase(object):
         If the source is not None, then object is initialized from values of 
         the source object.
 
-        @param source: Object used to initialize the new object
-        @type source: PrivacyBase
+        :param source: Object used to initialize the new object
+        :type source: PrivacyBase
         """
         
         if source:
@@ -67,9 +68,9 @@ class PrivacyBase(object):
         """
         Set or clears the privacy flag of the data.
 
-        @param val: value to assign to the privacy flag. True indicates that 
+        :param val: value to assign to the privacy flag. True indicates that 
             the record is private, False indicates that it is public.
-        @type val: bool
+        :type val: bool
         """
         self.private = val
 
@@ -77,7 +78,16 @@ class PrivacyBase(object):
         """
         Return the privacy level of the data. 
 
-        @returns: True indicates that the record is private
-        @rtype: bool
+        :returns: True indicates that the record is private
+        :rtype: bool
         """
         return self.private
+
+    def _merge_privacy(self, other):
+        """
+        Merge the privacy level of this object with that of other.
+
+        :returns: Privacy of merged objects.
+        :rtype: bool
+        """
+        self.private = self.private or other.private
