@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2010       Michiel D. Nauta
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: reporef.py 12704 2009-06-24 21:56:07Z bmcage $
+# $Id: reporef.py 16825 2011-03-15 21:52:08Z m_d_n $
 
 """
 Repository Reference class for GRAMPS
@@ -34,6 +35,7 @@ from gen.lib.privacybase import PrivacyBase
 from gen.lib.notebase import NoteBase
 from gen.lib.refbase import RefBase
 from gen.lib.srcmediatype import SourceMediaType
+from gen.lib.const import IDENTICAL, EQUAL, DIFFERENT
 
 #-------------------------------------------------------------------------
 #
@@ -51,7 +53,7 @@ class RepoRef(SecondaryObject, PrivacyBase, NoteBase, RefBase):
         RefBase.__init__(self, source)
         if source:
             self.call_number = source.call_number
-            self.media_type = source.media_type
+            self.media_type = SourceMediaType(source.media_type)
         else:
             self.call_number = ""
             self.media_type = SourceMediaType()
@@ -101,6 +103,36 @@ class RepoRef(SecondaryObject, PrivacyBase, NoteBase, RefBase):
             ret += [('Repository', self.ref)]
         return ret
 
+    def is_equivalent(self, other):
+        """
+        Return if this repository reference is equivalent, that is agrees in
+        reference, call number and medium, to other.
+
+        :param other: The repository reference to compare this one to.
+        :rtype other: RepoRef
+        :returns: Constant indicating degree of equivalence.
+        :rtype: int
+        """
+        if self.ref != other.ref or \
+            self.get_text_data_list() != other.get_text_data_list():
+            return DIFFERENT
+        else:
+            if self.is_equal(other):
+                return IDENTICAL
+            else:
+                return EQUAL
+
+    def merge(self, acquisition):
+        """
+        Merge the content of acquisition into this repository reference.
+
+        :param acquisition: The repository reference to merge with the present
+            repository reference.
+        :rtype acquisition: RepoRef
+        """
+        self._merge_privacy(acquisition)
+        self._merge_note_list(acquisition)
+
     def set_call_number(self, number):
         self.call_number = number
 
