@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2010       Michiel D. Nauta
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: src.py 16425 2011-01-21 16:27:54Z gbritton $
+# $Id: src.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Source object for GRAMPS.
@@ -81,6 +82,7 @@ class Source(MediaBase, NoteBase, PrimaryObject):
         NoteBase.unserialize(self, note_list)
         MediaBase.unserialize(self, media_list)
         self.reporef_list = [RepoRef().unserialize(item) for item in reporef_list]
+        return self
         
     def _has_handle_reference(self, classname, handle):
         """
@@ -150,12 +152,12 @@ class Source(MediaBase, NoteBase, PrimaryObject):
         """
         return self.media_list + self.reporef_list
 
-    def get_sourcref_child_list(self):
+    def get_citation_child_list(self):
         """
-        Return the list of child secondary objects that may refer sources.
+        Return the list of child secondary objects that may refer citations.
 
         :returns: Returns the list of child secondary child objects that may 
-                refer sources.
+                refer citations.
         :rtype: list
         """
         return self.media_list
@@ -178,7 +180,7 @@ class Source(MediaBase, NoteBase, PrimaryObject):
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
-        return self.media_list + self.reporef_list
+        return self.get_citation_child_list() + self.reporef_list
 
     def get_referenced_handles(self):
         """
@@ -190,47 +192,6 @@ class Source(MediaBase, NoteBase, PrimaryObject):
         """
         return self.get_referenced_note_handles()
 
-    def has_source_reference(self, src_handle) :
-        """
-        Return True if any of the child objects has reference to this source 
-        handle.
-
-        :param src_handle: The source handle to be checked.
-        :type src_handle: str
-        :returns: Returns whether any of it's child objects has reference to 
-                this source handle.
-        :rtype: bool
-        """
-        for item in self.get_sourcref_child_list():
-            if item.has_source_reference(src_handle):
-                return True
-
-        return False
-
-    def remove_source_references(self, src_handle_list):
-        """
-        Remove references to all source handles in the list in all child 
-        objects.
-
-        :param src_handle_list: The list of source handles to be removed.
-        :type src_handle_list: list
-        """
-        for item in self.get_sourcref_child_list():
-            item.remove_source_references(src_handle_list)
-
-    def replace_source_references(self, old_handle, new_handle):
-        """
-        Replace references to source_handles in the list in this object and
-        all child objects and merge equivalent entries.
-
-        :param old_handle: The source handle to be replaced.
-        :type old_handle: str
-        :param new_handle: The source handle to replace the old one with.
-        :type new_handle: str
-        """
-        for item in self.get_sourcref_child_list():
-            item.replace_source_references(old_handle, new_handle)
-
     def merge(self, acquisition):
         """
         Merge the content of acquisition into this source.
