@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: srcmediatype.py 10397 2008-03-25 22:55:58Z zfoldvar $
+# $Id: srcmediatype.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 """
 SourceMedia types.
@@ -28,7 +28,7 @@ SourceMedia types.
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
