@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: urlbase.py 14191 2010-02-02 13:56:15Z gbritton $
+# $Id: urlbase.py 15645 2010-07-22 02:16:32Z dsblank $
 
 """
 UrlBase class for GRAMPS.
@@ -30,6 +30,7 @@ UrlBase class for GRAMPS.
 #
 #-------------------------------------------------------------------------
 from gen.lib.url import Url
+from gen.lib.const import IDENTICAL, EQUAL
 
 #-------------------------------------------------------------------------
 #
@@ -83,6 +84,26 @@ class UrlBase(object):
         """
         self.urls = url_list
 
+    def _merge_url_list(self, acquisition):
+        """
+        Merge the list of urls from acquisition with our own.
+
+        :param acquisition: The url list of this object will be merged with
+            the current url list.
+        :rtype acquisition: UrlBase
+        """
+        url_list = self.urls[:]
+        for addendum in acquisition.get_url_list():
+            for url in url_list:
+                equi = url.is_equivalent(addendum)
+                if equi == IDENTICAL:
+                    break
+                elif equi == EQUAL:
+                    url.merge(addendum)
+                    break
+            else:
+                self.urls.append(addendum)
+
     def add_url(self, url):
         """
         Add a :class:`~gen.lib.url.Url` instance to the object's list of :class:`~gen.lib.url.Url` instances.
