@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2008  Brian G. Matherly
 # Copyright (C) 2010  Jakim Friant
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +19,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# $Id: __init__.py 18548 2011-12-04 17:09:17Z kulath $
+
 """
 The "plug" package for handling plugins in Gramps.
 """
@@ -31,6 +34,7 @@ from _pluginreg import (PluginData, PluginRegister, REPORT, TOOL,
             CATEGORY_QR_FAMILY, CATEGORY_QR_EVENT, CATEGORY_QR_SOURCE,
             CATEGORY_QR_PLACE, CATEGORY_QR_REPOSITORY, CATEGORY_QR_NOTE,
             CATEGORY_QR_DATE, PTYPE_STR, CATEGORY_QR_MEDIA,
+            CATEGORY_QR_CITATION, CATEGORY_QR_SOURCE_OR_CITATION,
             START, END, make_environment,
             )
 from _manager import BasePluginManager
@@ -39,7 +43,8 @@ from _export import ExportPlugin
 from _docgenplugin import DocGenPlugin
 from _gramplet import Gramplet
 from utils import *
-from gen.plug._options import Options, OptionListCollection, OptionList, OptionHandler
+from _options import (Options, OptionListCollection, OptionList,
+                      OptionHandler, MenuOptions)
 
 __all__ = [ "docbackend", "docgen", "menu", Plugin, PluginData,
             PluginRegister, BasePluginManager, 
@@ -51,4 +56,5 @@ __all__ = [ "docbackend", "docgen", "menu", Plugin, PluginData,
             CATEGORY_QR_FAMILY, CATEGORY_QR_EVENT, CATEGORY_QR_SOURCE,
             CATEGORY_QR_PLACE, CATEGORY_QR_REPOSITORY, CATEGORY_QR_NOTE,
             CATEGORY_QR_DATE, PTYPE_STR, CATEGORY_QR_MEDIA,
+            CATEGORY_QR_CITATION, CATEGORY_QR_SOURCE_OR_CITATION,
             START, END, make_environment]
