@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2009       Benny Malengier
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _pluginreg.py 17198 2011-04-22 01:45:19Z dsblank $
+# $Id: _pluginreg.py 18848 2012-02-10 19:57:57Z nick-h $
 
 """
 This module provides the base class for plugin registration. 
@@ -116,6 +117,8 @@ CATEGORY_QR_REPOSITORY = 5
 CATEGORY_QR_NOTE       = 6
 CATEGORY_QR_DATE       = 7
 CATEGORY_QR_MEDIA      = 8
+CATEGORY_QR_CITATION   = 9
+CATEGORY_QR_SOURCE_OR_CITATION = 10
 
 # Modes for generating reports
 REPORT_MODE_GUI = 1    # Standalone report using GUI
@@ -352,6 +355,7 @@ class PluginData(object):
         self._icons = []
         self._icondir = None
         self._depends_on = []
+        self._include_in_listing = True
         #derived var
         self.mod_name = None
         #RELCALC attr
@@ -538,6 +542,14 @@ class PluginData(object):
             raise ValueError, 'Plugin must have depends_on as a list'
         self._depends_on = depends
 
+    def _get_include_in_listing(self):
+        return self._include_in_listing
+
+    def _set_include_in_listing(self, include):
+        if not isinstance(include, bool):
+            raise ValueError, 'Plugin must have include_in_listing as a bool'
+        self._include_in_listing = include
+
     id = property(_get_id, _set_id)
     name = property(_get_name, _set_name)
     name_accell = property(_get_name_accell, _set_name_accell)
@@ -556,6 +568,7 @@ class PluginData(object):
     icons = property(_get_icons, _set_icons)
     icondir = property(_get_icondir, _set_icondir)
     depends_on = property(_get_depends_on, _set_depends_on)
+    include_in_listing = property(_get_include_in_listing, _set_include_in_listing)
     
     def statustext(self):
         return STATUSTEXT[self.status]
@@ -999,6 +1012,8 @@ def make_environment(**kwargs):
         'CATEGORY_QR_FAMILY': CATEGORY_QR_FAMILY,
         'CATEGORY_QR_EVENT': CATEGORY_QR_EVENT,
         'CATEGORY_QR_SOURCE': CATEGORY_QR_SOURCE,
+        'CATEGORY_QR_CITATION': CATEGORY_QR_CITATION,
+        'CATEGORY_QR_SOURCE_OR_CITATION': CATEGORY_QR_SOURCE_OR_CITATION,
         'CATEGORY_QR_PLACE': CATEGORY_QR_PLACE,
         'CATEGORY_QR_MEDIA': CATEGORY_QR_MEDIA,
         'CATEGORY_QR_REPOSITORY': CATEGORY_QR_REPOSITORY,
