@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2009 B. Malengier
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 15911 2010-09-17 12:08:38Z bmcage $
+# $Id: __init__.py 18848 2012-02-10 19:57:57Z nick-h $
 
 """
 The docgen package providing the API the document generating plugins can use.
@@ -34,6 +35,7 @@ from paragraphstyle import ParagraphStyle, PARA_ALIGN_CENTER, PARA_ALIGN_LEFT,\
 from tablestyle import TableStyle, TableCellStyle
 from stylesheet import StyleSheetList, StyleSheet, SheetParser
 from graphicstyle import GraphicsStyle, SOLID, DASHED, DOTTED
-from textdoc import TextDoc, IndexMark,INDEX_TYPE_ALP, INDEX_TYPE_TOC
+from textdoc import TextDoc, IndexMark,INDEX_TYPE_ALP, INDEX_TYPE_TOC,\
+    URL_PATTERN, LOCAL_HYPERLINK, LOCAL_TARGET
 from drawdoc import DrawDoc
 from graphdoc import GVDoc
