@@ -4,6 +4,7 @@
 # Copyright (C) 2004-2007  Donald N. Allingham
 # Copyright (C) 2008,2011  Gary Burton
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _ReportOptions.py 13346 2009-10-08 01:12:51Z dsblank $
+# $Id: _options.py 18886 2012-02-14 23:11:49Z nick-h $
 
 # Written by Alex Roitman
 
@@ -53,12 +54,14 @@ except:
 #
 # gramps modules
 #
+# (do not import anything from 'gui' as this is in 'gen')
+#
 #-------------------------------------------------------------------------
 import const
 import config
 from gen.plug.docgen import PAPER_PORTRAIT
 from gen.plug import _options
-from gui.plug import GuiMenuOptions
+from gen.plug import MenuOptions
 
 #-------------------------------------------------------------------------
 #
@@ -413,33 +416,35 @@ class OptionListCollection(_options.OptionListCollection):
         f.write('</last-common>\n')
 
     def write_module_common(self, f, option_list):
-        if option_list.get_style_name() \
-               and option_list.get_style_name() != self.default_style_name:
-            f.write('  <style name="%s"/>\n' % escxml(option_list.get_style_name()) )
-        if option_list.get_paper_metric() \
-               and option_list.get_paper_metric() != self.default_paper_metric:
-            f.write('  <metric value="%d"/>\n' % option_list.get_paper_metric() )
-        if option_list.get_custom_paper_size() \
-                and option_list.get_custom_paper_size() != self.default_custom_paper_size:
-            size = self.get_last_custom_paper_size()
-            f.write('  <size value="%f %f"/>\n' % (size[0], size[1]) )
-        if option_list.get_paper_name() \
-               and option_list.get_paper_name() != self.default_paper_name:
-            f.write('  <paper name="%s"/>\n' % escxml(option_list.get_paper_name()) )
-        if option_list.get_css_filename() \
-               and option_list.get_css_filename() != self.default_css_filename:
-            f.write('  <css name="%s"/>\n' % escxml(option_list.get_css_filename()))
-        if option_list.get_format_name() \
-               and option_list.get_format_name() != self.default_format_name:
-            f.write('  <format name="%s"/>\n' % escxml(option_list.get_format_name()) )
-        if option_list.get_orientation() \
-               and option_list.get_orientation() != self.default_orientation:
-            f.write('  <orientation value="%d"/>\n' % option_list.get_orientation() )
-        if option_list.get_margins() \
-               and option_list.get_margins() != self.default_margins:
-            margins = option_list.get_margins()
-            for pos in range(len(margins)): 
-                f.write('  <margin number="%s" value="%f"/>\n' % (pos, margins[pos]))
+        if option_list.get_format_name():
+            f.write('  <format name="%s"/>\n' %
+                        escxml(option_list.get_format_name()) )
+            if option_list.get_format_name() == 'html':
+                if option_list.get_css_filename():
+                    f.write('  <css name="%s"/>\n' %
+                                escxml(option_list.get_css_filename()))
+            else: # not HTML format, therefore it's paper
+                if option_list.get_paper_name():
+                    f.write('  <paper name="%s"/>\n' %
+                                escxml(option_list.get_paper_name()) )
+                if option_list.get_orientation() is not None: # 0 is legal
+                    f.write('  <orientation value="%d"/>\n' %
+                                option_list.get_orientation() )
+                if option_list.get_paper_metric() is not None: # 0 is legal
+                    f.write('  <metric value="%d"/>\n' %
+                                option_list.get_paper_metric() )
+                if option_list.get_custom_paper_size():
+                    size = self.get_last_custom_paper_size()
+                    f.write('  <size value="%f %f"/>\n' % (size[0], size[1]) )
+                if option_list.get_margins():
+                    margins = option_list.get_margins()
+                    for pos in range(len(margins)): 
+                        f.write('  <margin number="%s" value="%f"/>\n' %
+                                    (pos, margins[pos]))
+
+        if option_list.get_style_name():
+            f.write('  <style name="%s"/>\n' %
+                        escxml(option_list.get_style_name()) )
 
     def parse(self):
         """
@@ -596,7 +601,7 @@ class OptionHandler(_options.OptionHandler):
     def set_common_options(self):
         if self.saved_option_list.get_style_name():
             self.style_name = self.saved_option_list.get_style_name()
-        if self.saved_option_list.get_orientation():
+        if self.saved_option_list.get_orientation() is not None: # 0 is legal
             self.orientation = self.saved_option_list.get_orientation()
         if self.saved_option_list.get_custom_paper_size():
             self.custom_paper_size = self.saved_option_list.get_custom_paper_size()
@@ -604,13 +609,30 @@ class OptionHandler(_options.OptionHandler):
             self.margins = self.saved_option_list.get_margins()
         if self.saved_option_list.get_css_filename():
             self.css_filename = self.saved_option_list.get_css_filename()
-        if self.saved_option_list.get_paper_metric():
+        if self.saved_option_list.get_paper_metric() is not None: # 0 is legal
             self.paper_metric = self.saved_option_list.get_paper_metric()
         if self.saved_option_list.get_paper_name():
             self.paper_name = self.saved_option_list.get_paper_name()
         if self.saved_option_list.get_format_name():
             self.format_name = self.saved_option_list.get_format_name()
 
+    def save_options(self):
+        """
+        Saves options to file.
+        
+        """
+
+        # First we save options from options_dict
+        for option_name, option_data in self.options_dict.iteritems():
+            self.saved_option_list.set_option(option_name,
+                                              self.options_dict[option_name])
+
+        # Handle common options
+        self.save_common_options()
+
+        # Finally, save the whole collection into file
+        self.option_list_collection.save()
+
     def save_common_options(self):
         # First we save common options
         self.saved_option_list.set_style_name(self.style_name)
@@ -750,10 +772,12 @@ class ReportOptions(_options.Options):
                     FTA-    FTM Style Ancestral report
                     FTD-    FTM Style Descendant report
                     IDS-    Individual Complete Report
+                    IDX-    Alphabetical Index
                     IVS-    Individual Summary Report
                     PLC-    Place Report
-                    SBT-    Simple Boot Title
+                    SBT-    Simple Book Title
                     TLG-    Timeline Graph
+                    TOC-    Table Of Contents
         """
         pass
 
@@ -789,44 +813,26 @@ class ReportOptions(_options.Options):
         """
         self.handler.output = val
 
-    def init_selection(self, dbstate, uistate):
-        """
-        Initialize selection options for GUI.
-        """
-        pass
-
-    def save_selection(self):
-        """
-        Move selection options to handler.
-        """
-        pass
-
-    def build_selection(self):
-        """
-        Move selection options to handler.
-        """
-        pass
-
 #-------------------------------------------------------------------------
 #
 # MenuReportOptions
 #
 #-------------------------------------------------------------------------
-class MenuReportOptions(GuiMenuOptions, ReportOptions):
+class MenuReportOptions(MenuOptions, ReportOptions):
     """
 
     The MenuReportOptions class implements the ReportOptions
     functionality in a generic way so that the user does not need to
-    be concerned with the graphical representation of the options.
+    be concerned with the actual representation of the options.
     
     The user should inherit the MenuReportOptions class and override the 
     add_menu_options function. The user can add options to the menu and the 
-    MenuReportOptions class will worry about setting up the GUI.
+    MenuReportOptions class will worry about setting up the UI.
 
     """
     def __init__(self, name, dbase):
         ReportOptions.__init__(self, name, dbase)
-        GuiMenuOptions.__init__(self)
+        MenuOptions.__init__(self)
         
     def load_previous_values(self):
         ReportOptions.load_previous_values(self)
