@@ -4,6 +4,8 @@
 # Copyright (C) 2007  Brian G. Matherly
 # Copyright (C) 2010  Peter Landgren
 # Copyright (C) 2010  Jakim Friant
+# Copyright (C) 2011  Adam Stein <adam@csh.rit.edu>
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,13 +21,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _Endnotes.py 15169 2010-04-16 20:59:10Z bmcage $
+# $Id: endnotes.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Provide utilities for printing endnotes in text reports.
 """
 from gen.plug.docgen import FontStyle, ParagraphStyle, FONT_SANS_SERIF
-from gen.lib import NoteType, SourceRef
+from gen.lib import NoteType, Citation
 from gen.ggettext import gettext as _
 from Utils import confidence
 from DateHandler import displayer
@@ -75,30 +77,31 @@ def add_endnote_styles(style_sheet):
     para.set_description(_('The basic style used for the endnotes reference notes display.'))
     style_sheet.add_paragraph_style("Endnotes-Ref-Notes", para)
 
-def cite_source(bibliography, obj):
+def cite_source(bibliography, database, obj):
     """
     Cite any sources for the object and add them to the bibliography.
     
     @param bibliography: The bibliography to contain the citations.
     @type bibliography: L{Bibliography}
     @param obj: An object with source references.
-    @type obj: L{gen.lib.srcbase}
+    @type obj: L{gen.lib.CitationBase}
     """
     txt = ""
-    slist = obj.get_source_references()
+    slist = obj.get_citation_list()
     if slist:
         first = 1
         for ref in slist:
             if not first:
                 txt += ', '
             first = 0
-            (cindex, key) = bibliography.add_reference(ref)
+            citation = database.get_citation_from_handle(ref)
+            (cindex, key) = bibliography.add_reference(citation)
             txt += "%d" % (cindex + 1)
             if key is not None:
                 txt += key
     return txt
 
-def write_endnotes(bibliography, database, doc, printnotes=False):
+def write_endnotes(bibliography, database, doc, printnotes=False, links=False):
     """
     Write all the entries in the bibliography as endnotes.
     
@@ -111,6 +114,8 @@ def write_endnotes(bibliography, database, doc, printnotes=False):
     @param printnotes: Indicate if the notes attached to a source must be
             written too.
     @type printnotes: bool
+    @param links: Indicate if URL links should be makde 'clickable'.
+    @type links: bool
     """
     if bibliography.get_citation_count() == 0:
         return
@@ -118,7 +123,7 @@ def write_endnotes(bibliography, database, doc, printnotes=False):
     doc.start_paragraph('Endnotes-Header')
     doc.write_text(_('Endnotes'))
     doc.end_paragraph()
-
+    
     cindex = 0
     for citation in bibliography.get_citation_list():
         cindex += 1
@@ -126,19 +131,19 @@ def write_endnotes(bibliography, database, doc, printnotes=False):
         first = True
         
         doc.start_paragraph('Endnotes-Source', "%d." % cindex)
-        doc.write_text(_format_source_text(source))
+        doc.write_text(_format_source_text(source), links=links)
         doc.end_paragraph()
         
         if printnotes:
-            _print_notes(source, database, doc, 'Endnotes-Source-Notes')
- 
+            _print_notes(source, database, doc, 'Endnotes-Source-Notes', links)
+
         for key, ref in citation.get_ref_list():
             doc.start_paragraph('Endnotes-Ref', "%s:" % key)
-            doc.write_text(_format_ref_test(ref, key))
+            doc.write_text(_format_ref_text(ref, key), links=links)
             doc.end_paragraph()
 
             if printnotes:
-                _print_notes(ref, database, doc, 'Endnotes-Ref-Notes')
+                _print_notes(ref, database, doc, 'Endnotes-Ref-Notes', links)
 
 def _format_source_text(source):
     if not source: return ""
@@ -165,7 +170,7 @@ def _format_source_text(source):
         
     return src_txt
 
-def _format_ref_test(ref, key):
+def _format_ref_text(ref, key):
     if not ref: return ""
     
     ref_txt = ""
@@ -178,22 +183,22 @@ def _format_ref_test(ref, key):
         if ref.get_page():
             ref_txt = "%s - %s" % (ref.get_page(), displayer.display(date))
         else:
-            ref_txt = displayer.display(date)
+            ref_txt =  displayer.display(date)
     else:
         ref_txt = ref.get_page()
         
     # Print only confidence level if it is not Normal
-    if ref.get_confidence_level() != SourceRef.CONF_NORMAL:
+    if ref.get_confidence_level() != Citation.CONF_NORMAL:
         ref_txt += " [" + confidence[ref.get_confidence_level()] + "]"
     
     return ref_txt
 
-def _print_notes(obj, db, doc, style):
+def _print_notes(obj, db, doc, style, links):
     note_list = obj.get_note_list()
     ind = 1
     for notehandle in note_list: 
         note = db.get_note_from_handle(notehandle)
-        doc.write_styled_note(note.get_styledtext(), 
-                              note.get_format(), style,
-                              contains_html = note.get_type() == NoteType.HTML_CODE)
+        contains_html = note.get_type() == NoteType.HTML_CODE
+        doc.write_styled_note(note.get_styledtext(), note.get_format(), style,
+                              contains_html=contains_html, links=links)
         ind += 1
