@@ -2,7 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2008  Gary Burton
+# Copyright (C) 2008, 2012  Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +18,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# gen/proxy/__init__.py
+# $Id: __init__.py 18781 2012-01-27 21:03:57Z gburto01 $
+#
 
 __all__ = [ "filter", "living", "private", "proxybase", "referenced" ]
 
 from filter import FilterProxyDb
 from living import LivingProxyDb
 from private import PrivateProxyDb
-from referenced import ReferencedProxyDb
 from referencedbyselection import ReferencedBySelectionProxyDb
