@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007       Brian G. Matherly
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: proxybase.py 17538 2011-05-19 20:38:03Z m_d_n $
+# $Id: proxybase.py 18569 2011-12-11 03:57:38Z dsblank $
 
 """
 Proxy class for the GRAMPS databases. Filter out all data marked private.
@@ -52,7 +53,7 @@ class ProxyDbBase(DbReadBase):
 
     def __init__(self, db):
         """
-        Create a new PrivateProxyDb instance. 
+        Create a new ProxyDb instance. 
         """
         self.db = self.basedb = db
         while isinstance(self.basedb, ProxyDbBase):
@@ -95,6 +96,7 @@ class ProxyDbBase(DbReadBase):
     include_family = \
     include_event = \
     include_source = \
+    include_citation = \
     include_place = \
     include_media_object = \
     include_repository = \
@@ -102,6 +104,46 @@ class ProxyDbBase(DbReadBase):
     include_tag = \
         None
         
+    def get_person_cursor(self):
+        for handle in self.get_person_handles():
+            yield handle, self.basedb.person_map[handle]
+
+    def get_family_cursor(self):
+        for handle in self.get_family_handles():
+            yield handle, self.basedb.family_map[handle]
+
+    def get_event_cursor(self):
+        for handle in self.get_event_handles():
+            yield handle, self.basedb.event_map[handle]
+
+    def get_source_cursor(self):
+        for handle in self.get_source_handles():
+            yield handle, self.basedb.source_map[handle]
+
+    def get_citation_cursor(self):
+        for handle in self.get_citation_handles():
+            yield handle, self.basedb.citation_map[handle]
+
+    def get_place_cursor(self):
+        for handle in self.get_place_handles():
+            yield handle, self.basedb.place_map[handle]
+
+    def get_media_cursor(self):
+        for handle in self.get_media_object_handles():
+            yield handle, self.basedb.media_map[handle]
+
+    def get_repository_cursor(self):
+        for handle in self.get_repository_handles():
+            yield handle, self.basedb.repository_map[handle]
+
+    def get_note_cursor(self):
+        for handle in self.get_note_handles():
+            yield handle, self.basedb.note_map[handle]
+
+    def get_tag_cursor(self):
+        for handle in self.get_tag_handles():
+            yield handle, self.basedb.tag_map[handle]
+
     def get_person_handles(self, sort_handles=False):
         """
         Return a list of database handles, one handle for each Person in
@@ -142,6 +184,16 @@ class ProxyDbBase(DbReadBase):
         else:
             return []
         
+    def get_citation_handles(self, sort_handles=False):
+        """
+        Return a list of database handles, one handle for each Citation in
+        the database. 
+        """
+        if self.db.is_open:
+            return list(self.iter_citation_handles())
+        else:
+            return []
+        
     def get_place_handles(self, sort_handles=False):
         """
         Return a list of database handles, one handle for each Place in
@@ -228,6 +280,13 @@ class ProxyDbBase(DbReadBase):
         """
         return ifilter(self.include_source, self.db.iter_source_handles())       
 
+    def iter_citation_handles(self):
+        """
+        Return an iterator over database handles, one handle for each Citation 
+        in the database.
+        """
+        return ifilter(self.include_citation, self.db.iter_citation_handles())       
+
     def iter_place_handles(self):
         """
         Return an iterator over database handles, one handle for each Place in
@@ -299,6 +358,12 @@ class ProxyDbBase(DbReadBase):
         """
         return self.__iter_object(self.include_source, self.db.iter_sources)       
         
+    def iter_citations(self):
+        """
+        Return an iterator over Citation objects in the database
+        """
+        return self.__iter_object(self.include_citation, self.db.iter_citations)       
+        
     def iter_media_objects(self):
         """
         Return an iterator over Media objects in the database
@@ -390,6 +455,14 @@ class ProxyDbBase(DbReadBase):
         return self.gfilter(self.include_source,
                             self.db.get_source_from_handle(handle))
 
+    def get_citation_from_handle(self, handle):
+        """
+        Finds a Citation in the database from the passed gramps handle.
+        If no such Citation exists, None is returned.
+        """
+        return self.gfilter(self.include_citation,
+                            self.db.get_citation_from_handle(handle))
+
     def get_place_from_handle(self, handle):
         """
         Finds a Place in the database from the passed gramps handle.
@@ -470,6 +543,14 @@ class ProxyDbBase(DbReadBase):
         return self.gfilter(self.include_source,
                 self.db.get_source_from_gramps_id(val))
 
+    def get_citation_from_gramps_id(self, val):
+        """
+        Finds a Citation in the database from the passed gramps' ID.
+        If no such Citation exists, None is returned.
+        """
+        return self.gfilter(self.include_citation,
+                self.db.get_citation_from_gramps_id(val))
+
     def get_object_from_gramps_id(self, val):
         """
         Finds a MediaObject in the database from the passed gramps' ID.
@@ -550,6 +631,12 @@ class ProxyDbBase(DbReadBase):
         """
         return self.db.get_number_of_sources()
 
+    def get_number_of_citations(self):
+        """
+        Return the number of Citations currently in the database.
+        """
+        return self.db.get_number_of_citations()
+
     def get_number_of_media_objects(self):
         """
         Return the number of media objects currently in the database.
@@ -666,6 +753,9 @@ class ProxyDbBase(DbReadBase):
     def get_raw_source_data(self, handle):
         return self.db.get_raw_source_data(handle)
 
+    def get_raw_citation_data(self, handle):
+        return self.db.get_raw_citation_data(handle)
+
     def get_raw_repository_data(self, handle):
         return self.db.get_raw_repository_data(handle)
 
@@ -703,6 +793,13 @@ class ProxyDbBase(DbReadBase):
         return self.gfilter(self.include_source,
                 self.db.get_source_from_handle(handle)) is not None
 
+    def has_citation_handle(self, handle):
+        """
+        returns True if the handle exists in the current Citation database.
+        """
+        return self.gfilter(self.include_citation,
+                self.db.get_citation_from_handle(handle)) is not None
+
     def has_place_handle(self, handle):
         """
         returns True if the handle exists in the current Place database.
