@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: configmanager.py 14424 2010-02-21 12:59:34Z dsblank $
+# $Id: configmanager.py 16089 2010-10-31 07:33:17Z bmcage $
 
 """
 This package implements access to GRAMPS configuration.
@@ -38,14 +38,18 @@ import ConfigParser
 import errno
 import copy
 
-try:
-    from ast import literal_eval as safe_eval
-except:
-    # PYTHON2.5 COMPATIBILITY: no ast present
-    # not as safe as literal_eval, but works for python2.5:
-    def safe_eval(exp):
+def safe_eval(exp):
         # restrict eval to empty environment
         return eval(exp, {})
+##try:
+##    from ast import literal_eval as safe_eval
+##    # this leaks memory !!
+##except:
+##    # PYTHON2.5 COMPATIBILITY: no ast present
+##    # not as safe as literal_eval, but works for python2.5:
+##    def safe_eval(exp):
+##        # restrict eval to empty environment
+##        return eval(exp, {})
 
 #---------------------------------------------------------------
 #
