@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: configure.py 17663 2011-06-02 10:00:45Z romjerome $
+# $Id: configure.py 18714 2012-01-06 23:36:51Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -453,13 +453,15 @@ class GrampsPreferences(ConfigureDialog):
                        self.update_idformat_entry)
         self.add_entry(table, _('Source'), 3, 'preferences.sprefix',
                        self.update_idformat_entry)
-        self.add_entry(table, _('Media Object'), 4, 'preferences.oprefix',
+        self.add_entry(table, _('Citation'), 4, 'preferences.cprefix',
                        self.update_idformat_entry)
-        self.add_entry(table, _('Event'), 5, 'preferences.eprefix',
+        self.add_entry(table, _('Media Object'), 5, 'preferences.oprefix',
                        self.update_idformat_entry)
-        self.add_entry(table, _('Repository'), 6, 'preferences.rprefix',
+        self.add_entry(table, _('Event'), 6, 'preferences.eprefix',
                        self.update_idformat_entry)
-        self.add_entry(table, _('Note'), 7, 'preferences.nprefix',
+        self.add_entry(table, _('Repository'), 7, 'preferences.rprefix',
+                       self.update_idformat_entry)
+        self.add_entry(table, _('Note'), 8, 'preferences.nprefix',
                        self.update_idformat_entry)
         return _('ID Formats'), table
 
@@ -900,6 +902,19 @@ class GrampsPreferences(ConfigureDialog):
         table.attach(obox, 1, 3, row, row+1, yoptions=0)
         row += 1
         
+        # Default Family Relationship
+        obox = gtk.combo_box_new_text()
+        formats = gen.lib.FamilyRelType().get_standard_names()
+        map(obox.append_text, formats)
+        obox.set_active(config.get('preferences.family-relation-type'))
+        obox.connect('changed', 
+                     lambda obj: config.set('preferences.family-relation-type',
+                                            obj.get_active()))
+        lwidget = BasicLabel("%s: " % _('Default family relationship'))
+        table.attach(lwidget, 0, 1, row, row+1, yoptions=0)
+        table.attach(obox, 1, 3, row, row+1, yoptions=0)
+        row += 1
+
         #height multiple surname table 
         self.add_pos_int_entry(table, 
                 _('Height multiple surname box (pixels)'),
@@ -1143,6 +1158,7 @@ class GrampsPreferences(ConfigureDialog):
             config.get('preferences.oprefix'),
             config.get('preferences.fprefix'),
             config.get('preferences.sprefix'),
+            config.get('preferences.cprefix'),
             config.get('preferences.pprefix'),
             config.get('preferences.eprefix'),
             config.get('preferences.rprefix'),
