@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 16035 2010-10-24 14:43:47Z bmcage $
+# $Id: __init__.py 18548 2011-12-04 17:09:17Z kulath $
 
     
 #-------------------------------------------------------------------------
@@ -50,6 +51,8 @@ from mediabackreflist import MediaBackRefList
 from nameembedlist import NameEmbedList
 from notebackreflist import NoteBackRefList
 from notetab import NoteTab
+from citationbackreflist import CitationBackRefList
+from citationembedlist import CitationEmbedList
 from personeventembedlist import PersonEventEmbedList
 from personrefembedlist import PersonRefEmbedList
 from personbackreflist import PersonBackRefList
@@ -57,5 +60,4 @@ from placebackreflist import PlaceBackRefList
 from repoembedlist import RepoEmbedList
 from surnametab import SurnameTab
 from sourcebackreflist import SourceBackRefList
-from sourceembedlist import SourceEmbedList
 from webembedlist import WebEmbedList
