@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gallerytab.py 18627 2011-12-18 10:07:22Z m_d_n $
+# $Id: gallerytab.py 18696 2012-01-03 21:00:13Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -185,21 +185,18 @@ class GalleryTab(ButtonTab, DbGUIElement):
         """
         # create the model used with the icon view
         self._build_icon_model()
-        
+
         # pixels to pad the image
         padding = 6
-
+        
         # build the icon view
         self.iconlist.set_pixbuf_column(0)
         self.iconlist.set_item_width(int(const.THUMBSCALE) + padding * 2)
         # set custom text cell renderer for better control
         text_renderer = gtk.CellRendererText()
-        #text_renderer.set_property('xalign', 0.0)
-        #text_renderer.set_property('yalign', 0.0)
         text_renderer.set_property('wrap-mode', pango.WRAP_WORD_CHAR)
         text_renderer.set_property('wrap-width', const.THUMBSCALE)
         text_renderer.set_property('alignment', pango.ALIGN_CENTER)
-
         self.iconlist.pack_end(text_renderer)
         self.iconlist.set_attributes(text_renderer, text=1)
         
@@ -282,10 +279,18 @@ class GalleryTab(ButtonTab, DbGUIElement):
 
     def add_callback(self, media_ref, media):
         media_ref.ref = media.handle
-        self.get_data().append(media_ref)
+        data = self.get_data()
+        data.append(media_ref)
         self.callman.register_handles({'media': [media.handle]})
         self.changed = True
         self.rebuild()
+        model = self.iconlist.get_model()
+        if model:
+            itr_last = model.iter_nth_child(None, len(data) - 1)
+            if itr_last:
+                path = model.get_path(itr_last)
+                gobject.idle_add(self.iconlist.scroll_to_path, path, False,
+                                                                     0.0, 0.0)
 
     def __blocked_text(self):
         """
@@ -520,7 +525,6 @@ class GalleryTab(ButtonTab, DbGUIElement):
     def _handle_drag(self, row, obj):
         self.get_data().insert(row, obj)
         self.changed = True
-        self.rebuild()
 
     def _move(self, row_from, row_to, obj):
         dlist = self.get_data()
@@ -531,7 +535,6 @@ class GalleryTab(ButtonTab, DbGUIElement):
             del dlist[row_from]
             dlist.insert(row_to, obj)
         self.changed = True
-        self.rebuild()
 
     def find_index(self, obj):
         """
