@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: notemodel.py 15607 2010-06-30 07:36:11Z ldnp $
+# $Id: notemodel.py 15597 2010-06-28 07:43:41Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -39,7 +39,7 @@ class NoteModel(gtk.ListStore):
         self.db = db
         for handle in note_list:
             note = self.db.get_note_from_handle(handle)
-            text = note.get().replace(u'\n', u' ')
+            text = note.get().replace('\n', ' ')
             if len(text) > 80:
                 text = text[:80]+"..."
             self.append(row=[
