@@ -5,6 +5,7 @@
 # Copyright (C) 2009       Gary Burton
 # Copyright (C) 2009       Benny Malengier
 # Copyright (C) 2010       Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editnote.py 16680 2011-02-20 10:52:06Z bmcage $
+# $Id: editnote.py 19362 2012-04-19 18:39:25Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -346,7 +347,7 @@ class DeleteNoteQuery(object):
             self.db.disable_signals()
         
             (person_list, family_list, event_list, place_list, source_list,
-             media_list, repo_list) = self.the_lists
+             citation_list, media_list, repo_list) = self.the_lists
 
             note_handle = self.note.get_handle()
 
@@ -375,6 +376,11 @@ class DeleteNoteQuery(object):
                 source.remove_note(note_handle)
                 self.db.commit_source(source, trans)
 
+            for handle in citation_list:
+                citation = self.db.get_citation_from_handle(handle)
+                citation.remove_note(note_handle)
+                self.db.commit_citation(citation, trans)
+
             for handle in media_list:
                 media = self.db.get_object_from_handle(handle)
                 media.remove_note(note_handle)
