@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:_FilterEditor.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: filtereditor.py 19265 2012-04-07 19:01:53Z nick-h $
 
 """
 Custom Filter Editor tool.
@@ -85,6 +86,7 @@ _TITLES = {
             'MediaObject' : _('Media Object Filters'),
             'Repository' : _('Repository Filters'),
             'Note' : _('Note Filters'),
+            'Citation' : _('Citation Filters'),
 }
 
 _name2typeclass = {
@@ -293,6 +295,7 @@ class MyID(gtk.HBox):
         'MediaObject'  : _('Media Object'),
         'Repository' : _('Repository'),
         'Note'   : _('Note'),
+        'Citation' : _('Citation'),
         }
     
     def __init__(self, dbstate, uistate, track, namespace='Person'):
@@ -345,6 +348,9 @@ class MyID(gtk.HBox):
         elif self.namespace == 'Source':
             source = self.db.get_source_from_gramps_id(gramps_id)
             name = source.get_title()
+        elif self.namespace == 'Citation':
+            citation = self.db.get_citation_from_gramps_id(gramps_id)
+            name = citation.get_page()
         elif self.namespace == 'MediaObject':
             obj = self.db.get_object_from_gramps_id(gramps_id)
             name = obj.get_path()
@@ -461,6 +467,8 @@ class EditRule(ManagedWindow.ManagedWindow):
             class_list = Rules.Event.editor_rule_list
         elif self.namespace == 'Source':
             class_list = Rules.Source.editor_rule_list
+        elif self.namespace == 'Citation':
+            class_list = Rules.Citation.editor_rule_list
         elif self.namespace == 'Place':
             class_list = Rules.Place.editor_rule_list
         elif self.namespace == 'MediaObject':
@@ -696,7 +704,6 @@ class EditRule(ManagedWindow.ManagedWindow):
             new_rule = class_obj(value_list)
 
             self.update_rule(self.active_rule, new_rule)
-            self._save_size()
             self.close()
         except KeyError:
             pass
@@ -712,7 +719,8 @@ class EditFilter(ManagedWindow.ManagedWindow):
                  filterdb, update=None, selection_callback=None):
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, track, self)
-
+        self.width_key = "interface.edit-filter-width"
+        self.height_key = "interface.edit-filter-height"
         self.namespace = namespace
         self.update = update
         self.dbstate = dbstate
@@ -754,18 +762,16 @@ class EditFilter(ManagedWindow.ManagedWindow):
                                           self.close_window)
         self.fname.connect('changed', self.filter_name_changed)
 
-        if self.filter.get_logical_op() == 'or':
-            self.logical.set_active(1)
-        elif self.filter.get_logical_op() == 'one':
-            self.logical.set_active(2)
-        else:
-            self.logical.set_active(0)
+        op = self.filter.get_logical_op()
+        # WARNING: must be listed in this order:
+        self.logical.set_active(["and", "or", "one", "sequence"].index(op))
         self.logical_not.set_active(self.filter.get_invert())
         if self.filter.get_name():
             self.fname.set_text(self.filter.get_name())
         self.comment.set_text(self.filter.get_comment())
         self.draw_rules()
 
+        self._set_size()
         self.show()
 
     def on_help_clicked(self, obj):
@@ -812,7 +818,12 @@ class EditFilter(ManagedWindow.ManagedWindow):
                 self.filterdb.get_filters(self.namespace).remove(f)
                 break
         val = self.logical.get_active()
-        op = 'or' if val == 1 else 'one' if val == 2 else 'and'
+        # WARNING: must be listed in this order:
+        op = ('and' if val == 0 else 
+              'or' if val == 1 else 
+              'one' if val == 2 else 
+              'sequence')
+        self.logical.set_active(val)
         self.filter.set_logical_op(op)
         self.filter.set_invert(self.logical_not.get_active())
         self.filterdb.add(self.namespace,self.filter)
@@ -916,6 +927,10 @@ class ShowResults(ManagedWindow.ManagedWindow):
             source = self.db.get_source_from_handle(handle)
             name = source.get_title()
             gid = source.get_gramps_id()
+        elif self.namespace == 'Citation':
+            citation = self.db.get_citation_from_handle(handle)
+            name = citation.get_title()
+            gid = citation.get_gramps_id()
         elif self.namespace == 'Place':
             place = self.db.get_place_from_handle(handle)
             name = place.get_title()
@@ -947,6 +962,8 @@ class ShowResults(ManagedWindow.ManagedWindow):
             sortname = self.db.get_event_from_handle(handle).get_description()
         elif self.namespace == 'Source':
             sortname = self.db.get_source_from_handle(handle).get_title()
+        elif self.namespace == 'Citation':
+            sortname = self.db.get_citation_from_handle(handle).get_title()
         elif self.namespace == 'Place':
             sortname = self.db.get_place_from_handle(handle).get_title()
         elif self.namespace == 'MediaObject':
@@ -971,6 +988,8 @@ class FilterEditor(ManagedWindow.ManagedWindow):
         self.db = dbstate.db
         self.filterdb = FilterList(filterdb)
         self.filterdb.load()
+        self.width_key = "interface.filter-editor-width"
+        self.height_key = "interface.filter-editor-height"
         self.namespace = namespace
 
         self.define_glade('filter_list', const.RULE_GLADE)
@@ -1006,6 +1025,7 @@ class FilterEditor(ManagedWindow.ManagedWindow):
                             self.filter_select_row,
                             self.edit_filter)
         self.draw_filters()
+        self._set_size()
         self.show()
 
     def build_menu_names(self, obj):
@@ -1134,6 +1154,8 @@ class FilterEditor(ManagedWindow.ManagedWindow):
             return self.db.get_event_handles()
         elif self.namespace == 'Source':
             return self.db.get_source_handles()
+        elif self.namespace == 'Citation':
+            return self.db.get_citation_handles()
         elif self.namespace == 'Place':
             return self.db.iter_place_handles()
         elif self.namespace == 'MediaObject':
