@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: grampsbar.py 18066 2011-08-25 20:48:53Z nick-h $
+# $Id: grampsbar.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Module that implements the sidebar and bottombar fuctionality.
@@ -58,6 +58,7 @@ from gui.widgets.grampletpane import (AVAILABLE_GRAMPLETS,
                                       GuiGramplet)
 from gui.widgets.undoablebuffer import UndoableBuffer
 from gui.utils import add_menuitem
+from QuestionDialog import QuestionDialog
 
 #-------------------------------------------------------------------------
 #
@@ -83,6 +84,7 @@ class GrampsBar(gtk.Notebook):
         self.uistate = uistate
         self.pageview = pageview
         self.configfile = os.path.join(const.VERSION_DIR, "%s.ini" % configfile)
+        self.defaults = defaults
         self.detached_gramplets = []
         self.empty = False
 
@@ -288,6 +290,14 @@ class GrampsBar(gtk.Notebook):
             return [gramplet.gname for gramplet in self.get_children() +
                                                    self.detached_gramplets]
 
+    def restore(self):
+        """
+        Restore the GrampsBar to its default gramplets.
+        """
+        map(self.remove_gramplet, self.all_gramplets())
+        map(self.add_gramplet, self.defaults)
+        self.set_current_page(0)
+
     def __create_empty_tab(self):
         """
         Create an empty tab to be displayed when the GrampsBar is empty.
@@ -304,7 +314,10 @@ class GrampsBar(gtk.Notebook):
         """
         Add a tab to the notebook for the given gramplet.
         """
-        gramplet.set_size_request(gramplet.width, gramplet.height)
+        width = min(int(self.uistate.screen_width() * 0.25), 400)
+        height = min(int(self.uistate.screen_height() * 0.20), 400)
+        gramplet.set_size_request(width, height)
+
         page_num = self.append_page(gramplet)
         return page_num
 
@@ -425,6 +438,11 @@ class GrampsBar(gtk.Notebook):
                 rg_menu.show()
                 menu.append(rg_menu)
 
+            rd_menu = gtk.MenuItem(_('Restore default gramplets'))
+            rd_menu.connect("activate", self.__restore_clicked)
+            rd_menu.show()
+            menu.append(rd_menu)
+
             menu.popup(None, None, None, 1, event.time)
             return True
 
@@ -456,6 +474,16 @@ class GrampsBar(gtk.Notebook):
         """
         self.remove_gramplet(gname)
 
+    def __restore_clicked(self, menu):
+        """
+        Called when restore defaults is clicked from the context menu.
+        """
+        QuestionDialog(_("Restore to defaults?"),
+            _("The Grampsbar will be restored to contain its default "
+              "gramplets.  This action cannot be undone."),
+            _("OK"),
+            self.restore)
+
     def get_config_funcs(self):
         """
         Return a list of configuration functions.
