@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: grampsgui.py 17256 2011-04-25 21:11:45Z noirauds $
+# $Id: grampsgui.py 19319 2012-04-13 19:55:56Z jralls $
 
 #-------------------------------------------------------------------------
 #
@@ -151,6 +151,7 @@ def register_stock_icons ():
         ('gramps-zoom-out', _('Zoom Out'), gtk.gdk.CONTROL_MASK, 0, ''),
         ('gramps-zoom-fit-width', _('Fit Width'), gtk.gdk.CONTROL_MASK, 0, ''),
         ('gramps-zoom-best-fit', _('Fit Page'), gtk.gdk.CONTROL_MASK, 0, ''),
+        ('gramps-citation', _('Citations'), gtk.gdk.CONTROL_MASK, 0, ''),
         ]
     # the following icons are not yet in new directory structure
     # they should be ported in the near future
@@ -328,4 +329,6 @@ def startgtkloop(errors, argparser):
     gobject.threads_init()
 
     gobject.timeout_add(100, __startgramps, errors, argparser, priority=100)
+    if os.path.exists(os.path.join(const.DATA_DIR, "gramps.accel")):
+        gtk.accel_map_load(os.path.join(const.DATA_DIR, "gramps.accel"))
     gtk.main()
