@@ -4,6 +4,7 @@
 # Copyright (C) 2000-2006  Donald N. Allingham
 # Copyright (C) 2008       Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _windows.py 16746 2011-03-02 17:07:42Z romjerome $
+# $Id: _windows.py 18968 2012-02-24 18:30:37Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -51,7 +52,7 @@ from gen.plug import PluginRegister, PTYPE_STR, load_addon_file
 from gen.ggettext import gettext as _
 from gui.utils import open_file_with_default_application
 from gui.pluginmanager import GuiPluginManager
-from gui.plug import tool
+from gui.plug import tool, add_gui_options
 from QuestionDialog import InfoDialog
 from gui.editors import EditPerson
 import Utils
@@ -263,8 +264,8 @@ class PluginStatus(ManagedWindow.ManagedWindow):
         hbutbox.add(self.__refresh_btn)
         self.__refresh_btn.connect('clicked', self.__refresh_addon_list) 
         install_page.pack_start(hbutbox, expand=False, padding=5)
-        notebook.append_page(install_page, 
-                             tab_label=gtk.Label(_('Install Addons')))
+        # notebook.append_page(install_page, 
+        #                      tab_label=gtk.Label(_('Install Addons')))
 
         #add the notebook to the window
         self.window.vbox.add(notebook)
@@ -476,7 +477,7 @@ class PluginStatus(ManagedWindow.ManagedWindow):
                     '<span weight="bold" color="red">%s</span>' % _('Fail'),
                     i[0], str(i[1][1]), i[1], pdata.id, hiddenstr])
 
-        success_list = self.__pmgr.get_success_list()
+        success_list = sorted(self.__pmgr.get_success_list())
         for i in success_list:
             # i = (filename, module, pdata)
             pdata = i[2]
@@ -493,6 +494,7 @@ class PluginStatus(ManagedWindow.ManagedWindow):
     def __populate_reg_list(self):
         """ Build list of registered plugins"""
         for (type, typestr) in PTYPE_STR.iteritems():
+            registered_plugins = []
             for pdata in self.__preg.type_plugins(type):
                 #  model: plugintype, hidden, pluginname, plugindescr, pluginid
                 hidden = pdata.id in self.hidden
@@ -500,9 +502,10 @@ class PluginStatus(ManagedWindow.ManagedWindow):
                     hiddenstr = self.HIDDEN
                 else:
                     hiddenstr = self.AVAILABLE
-                self.model_reg.append(row=[
-                    typestr, hiddenstr, pdata.name, pdata.description, 
-                    pdata.id])
+                registered_plugins.append([typestr, hiddenstr, pdata.name,
+                                           pdata.description, pdata.id])
+            for row in sorted(registered_plugins):
+                self.model_reg.append(row)
 
     def __rebuild_load_list(self):
         self.model.clear()
@@ -772,7 +775,7 @@ class ToolManagedWindowBase(ManagedWindow.ManagedWindow):
         and run the tool.
         """
         # Save options
-        self.options.parse_user_options(self)
+        self.options.parse_user_options()
         self.options.handler.save_options()
         self.pre_run()
         self.run() # activate results tab
@@ -1014,7 +1017,7 @@ class ToolManagedWindowBase(ManagedWindow.ManagedWindow):
         It is called immediately before the window is displayed. All
         calls to add_option or add_frame_option should be called in
         this task."""
-        self.options.add_user_options(self)
+        add_gui_options(self)
 
     def build_menu_names(self, obj):
         return (_('Main window'), self.get_title())
