@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:_BaseSelector.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: baseselector.py 18548 2011-12-04 17:09:17Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -193,6 +193,8 @@ class BaseSelector(ManagedWindow.ManagedWindow):
             id_list = self.get_selected_ids()
             if id_list and id_list[0]:
                 result = self.get_from_handle_func()(id_list[0])
+                if result is None and self.get_from_handle_func2:
+                    result = self.get_from_handle_func2()(id_list[0])
             self.close()
         elif val != gtk.RESPONSE_DELETE_EVENT:
             self.close()
@@ -225,6 +227,9 @@ class BaseSelector(ManagedWindow.ManagedWindow):
     def get_from_handle_func(self):
         assert False, "Must be defined in the subclass"
         
+    def get_from_handle_func2(self):
+        return None
+        
     def get_handle_column(self):
         # return 3
         assert False, "Must be defined in the subclass"
