@@ -6,6 +6,7 @@
 # Copyright (C) 2009       Benny Malengier
 # Copyright (C) 2010       Nick Hall
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2012       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:ViewManager.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: viewmanager.py 19366 2012-04-20 02:46:03Z dsblank $
 
 """
 Manages the main window and the pluggable views
@@ -226,7 +227,7 @@ UIDEFAULT = '''<ui>
 WIKI_HELP_PAGE_FAQ = '%s_-_FAQ' % const.URL_MANUAL_PAGE
 WIKI_HELP_PAGE_KEY = '%s_-_Keybindings' % const.URL_MANUAL_PAGE
 WIKI_HELP_PAGE_MAN = '%s' % const.URL_MANUAL_PAGE
-ADDONS_URL = "http://gramps-addons.svn.sourceforge.net/viewvc/gramps-addons/branches/gramps33"
+ADDONS_URL = "http://gramps-addons.svn.sourceforge.net/viewvc/gramps-addons/branches/gramps34/"
 
 #-------------------------------------------------------------------------
 #
@@ -435,9 +436,9 @@ class ViewManager(CLIManager):
             elif force:
                 from QuestionDialog import OkDialog
                 OkDialog(_("There are no available addons of this type"),
-                          _("Checked for '%s'") %
-                          _("' and '").join([_(t) for t in config.get('behavior.check-for-update-types')]),
-                          self.window)
+                         _("Checked for '%s'") %
+                         _("' and '").join([_(t) for t in config.get('behavior.check-for-update-types')]),
+                         self.window)
 
     def update_addons(self, addon_update_list):
         from glade import Glade
@@ -477,7 +478,7 @@ class ViewManager(CLIManager):
         for (status,plugin_url,plugin_dict) in addon_update_list:
             count = get_count(addon_update_list, plugin_dict["t"])
             category = _("%(adjective)s: %(addon)s") % {
-                "adjective": status,
+                "adjective": status, 
                 "addon": _(plugin_dict["t"])}
             if last_category != category:
                 last_category = category
@@ -1869,15 +1870,24 @@ def run_plugin(pdata, dbstate, uistate):
       1/ load plugin.
       2/ the report is run
     """
-    mod = GuiPluginManager.get_instance().load_plugin(pdata)
+    pmgr = GuiPluginManager.get_instance()
+    mod = pmgr.load_plugin(pdata)
     if not mod:
         #import of plugin failed
         ErrorDialog(
             _('Failed Loading Plugin'),
-            _('The plugin did not load. See Help Menu, Plugin Manager'
-              ' for more info.\nUse http://bugs.gramps-project.org to'
-              ' submit bugs of official plugins, contact the plugin '
-              'author otherwise. '))
+            _('The plugin %(name)s did not load and reported an error.\n\n'
+              '%(error_msg)s\n\n'
+              'If you are unable to fix the fault yourself then you can '
+              'submit a bug at http://bugs.gramps-project.org or contact '
+              'the plugin author (%(firstauthoremail)s).\n\n'
+              'If you do not want Gramps to try and load this plugin again, '
+              'you can hide it by using the Plugin Manager on the '
+              'Help menu.') % {
+                'name': pdata.name,
+                'firstauthoremail': pdata.authors_email[0] if
+                        pdata.authors_email else '...',
+                'error_msg': pmgr.get_fail_list()[-1][1][1]})
         return
 
     if pdata.ptype == REPORT:
@@ -1915,13 +1925,18 @@ def get_available_views():
             #import of plugin failed
             ErrorDialog(
                 _('Failed Loading View'),
-                _('The view %(name)s did not load. See Help Menu, Plugin Manager'
-                  ' for more info.\nUse http://bugs.gramps-project.org to'
-                  ' submit bugs of official views, contact the view '
-                  'author (%(firstauthoremail)s) otherwise. ') % {
+                _('The view %(name)s did not load and reported an error.\n\n'
+                  '%(error_msg)s\n\n'
+                  'If you are unable to fix the fault yourself then you can '
+                  'submit a bug at http://bugs.gramps-project.org or contact '
+                  'the view author (%(firstauthoremail)s).\n\n'
+                  'If you do not want Gramps to try and load this view again, '
+                  'you can hide it by using the Plugin Manager on the '
+                  'Help menu.') % {
                     'name': pdata.name,
                     'firstauthoremail': pdata.authors_email[0] if
-                            pdata.authors_email else '...'})
+                            pdata.authors_email else '...',
+                    'error_msg': pmgr.get_fail_list()[-1][1][1]})
             continue
         viewclass = getattr(mod, pdata.viewclass)
 
