@@ -1,6 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2009  Benny Malengier
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 14216 2010-02-04 21:05:15Z nick-h $
+# $Id: __init__.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Package init for the treemodels package.
@@ -31,3 +32,6 @@ from placemodel import PlaceBaseModel, PlaceListModel, PlaceTreeModel
 from mediamodel import MediaModel
 from repomodel import RepositoryModel
 from notemodel import NoteModel
+from citationbasemodel import CitationBaseModel
+from citationlistmodel import CitationListModel
+from citationtreemodel import CitationTreeModel
