@@ -3,8 +3,9 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2009       Gary Burton
-# Copyright (C) 2009-2010  Nick Hall
+# Copyright (C) 2009-2011  Nick Hall
 # Copyright (C) 2009       Benny Malengier
+# Copyright (C) 2011       Tim G L lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +21,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# gui/views/treemodels/treebasemodel.py
+# $Id: treebasemodel.py 18740 2012-01-13 22:21:22Z nick-h $
+#
 
 """
 This module provides the model that is used for all hierarchical treeviews.
@@ -78,10 +82,10 @@ class Node(object):
     children    A list of (sortkey, nodeid) tuples for the children of the node.
                 This list is always kept sorted.
     """
-    __slots__ = ('name', 'sortkey', 'ref', 'handle', 'parent', 'prev', 
-                 'next', 'children')#, '__weakref__')
+    __slots__ = ('name', 'sortkey', 'ref', 'handle', 'secondary', 'parent',
+                 'prev', 'next', 'children')#, '__weakref__')
 
-    def __init__(self, ref, parent, sortkey, handle):
+    def __init__(self, ref, parent, sortkey, handle, secondary):
         self.name = sortkey
         if sortkey:
             self.sortkey = map(conv_unicode_tosrtkey_ongtk, sortkey)
@@ -89,17 +93,19 @@ class Node(object):
             self.sortkey = None
         self.ref = ref
         self.handle = handle
+        self.secondary = secondary
         self.parent = parent
         self.prev = None
         self.next = None
         self.children = []
 
-    def set_handle(self, handle):
+    def set_handle(self, handle, secondary=False):
         """
         Assign the handle of a Gramps object to this node.
         """
-        if not self.handle:
+        if not self.handle or handle == None:
             self.handle = handle
+            self.secondary = secondary
         else:
             print ('WARNING: Attempt to add handle twice to the node (%s)' %
                     handle)
@@ -263,6 +269,9 @@ class TreeBaseModel(gtk.GenericTreeModel):
                       can groups have a handle. If False, this means groups 
                       are only used to group subnodes, not for holding data and
                       showing subnodes
+    has_secondary  :  If True, the model contains two Gramps object types.
+                      The suffix '2' is appended to variables relating to the
+                      secondary object type.
     """
 
     # LRU cache size
@@ -272,7 +281,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
                     search=None, skip=set(),
                     scol=0, order=gtk.SORT_ASCENDING, sort_map=None,
                     nrgroups = 1,
-                    group_can_have_handle = False):
+                    group_can_have_handle = False,
+                    has_secondary=False):
         cput = time.clock()
         gtk.GenericTreeModel.__init__(self)
         #two unused attributes pesent to correspond to flatbasemodel
@@ -283,6 +293,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.scol = scol
         self.nrgroups = nrgroups
         self.group_can_have_handle = group_can_have_handle
+        self.has_secondary = has_secondary
         self.db = db
         
         self._set_base_data()
@@ -301,9 +312,13 @@ class TreeBaseModel(gtk.GenericTreeModel):
             #we need the model col, that corresponds with scol
             col = self.sort_map[scol][1]
             self.sort_func = self.smap[col]
+            if self.has_secondary:
+                self.sort_func2 = self.smap2[col]
             self.sort_col = col
         else:
             self.sort_func = self.smap[scol]
+            if self.has_secondary:
+                self.sort_func2 = self.smap2[scol]
             self.sort_col = scol
     
         self._in_build = False
@@ -327,6 +342,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
         """
         self.db = None
         self.sort_func = None
+        if self.has_secondary:
+            self.sort_func2 = None
         if self.nodemap:
             self.nodemap.destroy()
         self.nodemap = None
@@ -348,15 +365,19 @@ class TreeBaseModel(gtk.GenericTreeModel):
         map     : function to obtain the raw bsddb object datamap
         smap    : the map with functions to obtain sort value based on sort col
         fmap    : the map with functions to obtain value of a row with handle
-        hmap    : the map with functions to obtain value of a row without handle
         """
         self.gen_cursor = None
         self.number_items = None   # function 
         self.map = None
-        
         self.smap = None
         self.fmap = None
-        self.hmap = None
+
+        if self.has_secondary:
+            self.gen_cursor2 = None
+            self.number_items2 = None   # function 
+            self.map2 = None
+            self.smap2 = None
+            self.fmap2 = None
 
     def displayed(self):
         """
@@ -404,7 +425,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.handle2node.clear()
         self.nodemap.clear()
         #start with creating the new iters
-        topnode = Node(None, None, None, None)
+        topnode = Node(None, None, None, None, False)
         self.nodemap.add_node(topnode)
         self.tree[None] = topnode
 
@@ -470,15 +491,28 @@ class TreeBaseModel(gtk.GenericTreeModel):
         """
         self.__total = 0
         self.__displayed = 0
-        
+
         items = self.number_items()
+        self.__rebuild_search(dfilter, skip, items, 
+                              self.gen_cursor, self.add_row)
+
+        if self.has_secondary:
+            items = self.number_items2()
+            self.__rebuild_search(dfilter, skip, items, 
+                                  self.gen_cursor2, self.add_row2)
+
+    def __rebuild_search(self, dfilter, skip, items, gen_cursor, add_func):
+        """
+        Rebuild the data map for a single Gramps object type, where a search 
+        condition is applied.
+        """
         pmon = progressdlg.ProgressMonitor(progressdlg.GtkProgressDialog, 
                                             popup_time=2)
         status = progressdlg.LongOpStatus(msg=_("Building View"),
                             total_steps=items, interval=items//20, 
                             can_cancel=True)
         pmon.add_op(status)
-        with self.gen_cursor() as cursor:
+        with gen_cursor() as cursor:
             for handle, data in cursor:
                 status.heartbeat()
                 if status.should_cancel():
@@ -487,7 +521,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
                 if not (handle in skip or (dfilter and not
                                         dfilter.match(handle, self.db))):
                     self.__displayed += 1
-                    self.add_row(handle, data)
+                    add_func(handle, data)
         if not status.was_cancelled():
             status.end()
 
@@ -495,32 +529,49 @@ class TreeBaseModel(gtk.GenericTreeModel):
         """
         Rebuild the data map where a filter is applied.
         """
+        self.__total = 0
+        self.__displayed = 0
+
+        items = self.number_items()
+        self.__rebuild_filter(dfilter, skip, items, 
+                              self.gen_cursor, self.map, self.add_row)
+        if self.has_secondary:
+            items = self.number_items2()
+            self.__rebuild_filter(dfilter, skip, items, 
+                                  self.gen_cursor2, self.map2, self.add_row2)
+            
+    def __rebuild_filter(self, dfilter, skip, items, gen_cursor, data_map, 
+                         add_func):
+        """
+        Rebuild the data map for a single Gramps object type, where a filter 
+        is applied.
+        """
         pmon = progressdlg.ProgressMonitor(progressdlg.GtkProgressDialog, 
                                             popup_time=2)
-        status = progressdlg.LongOpStatus(msg=_("Building People View"),
+        status = progressdlg.LongOpStatus(msg=_("Building View"),
                               total_steps=3, interval=1)
         pmon.add_op(status)
-        self.__total = self.number_items()
-        status_ppl = progressdlg.LongOpStatus(msg=_("Obtaining all people"),
-                        total_steps=self.__total, interval=self.__total//10)
+        status_ppl = progressdlg.LongOpStatus(msg=_("Obtaining all rows"),
+                        total_steps=items, interval=items//10)
         pmon.add_op(status_ppl)
         
+        self.__total += items
+
         def beat(key):
             status_ppl.heartbeat()
             return key
         
-        with self.gen_cursor() as cursor:
+        with gen_cursor() as cursor:
             handle_list = [beat(key) for key, data in cursor]
         status_ppl.end()
-        self.__displayed = 0
         status.heartbeat()
 
         if dfilter:
             status_filter = progressdlg.LongOpStatus(msg=_("Applying filter"),
-                        total_steps=self.__total, interval=self.__total//10)
+                        total_steps=items, interval=items//10)
             pmon.add_op(status_filter)
             handle_list = dfilter.apply(self.db, handle_list, 
-                                        progress=status_filter)
+                                        cb_progress=status_filter.heartbeat)
             status_filter.end()
         status.heartbeat()
 
@@ -530,14 +581,15 @@ class TreeBaseModel(gtk.GenericTreeModel):
         pmon.add_op(status_col)
         for handle in handle_list:
             status_col.heartbeat()
-            data = self.map(handle)
+            data = data_map(handle)
             if not handle in skip:
-                self.add_row(handle, data)
+                add_func(handle, data)
                 self.__displayed += 1
         status_col.end()
         status.end()
         
-    def add_node(self, parent, child, sortkey, handle, add_parent=True):
+    def add_node(self, parent, child, sortkey, handle, add_parent=True,
+                 secondary=False):
         """
         Add a node to the map.
         
@@ -560,10 +612,12 @@ class TreeBaseModel(gtk.GenericTreeModel):
         if child in self.tree:
             #a node is added that is already present,
             child_node = self.tree[child]
-            self._add_dup_node(child_node, parent, child, sortkey, handle)
+            self._add_dup_node(child_node, parent, child, sortkey, handle,
+                               secondary)
         else:
             parent_node = self.tree[parent]
-            child_node = Node(child, id(parent_node), sortkey, handle)
+            child_node = Node(child, id(parent_node), sortkey, handle,
+                              secondary)
             parent_node.add_child(child_node, self.nodemap)
             self.tree[child] = child_node
             self.nodemap.add_node(child_node)
@@ -580,7 +634,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         if handle:
             self.handle2node[handle] = child_node
 
-    def _add_dup_node(self, node, parent, child, sortkey, handle):
+    def _add_dup_node(self, node, parent, child, sortkey, handle, secondary):
         """
         How to handle adding a node a second time
         Default: if group nodes can have handles, it is allowed to add it 
@@ -592,7 +646,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
                    % (str(parent), str(child)))
             return
         if handle:
-            node.set_handle(handle)
+            node.set_handle(handle, secondary)
             if not self._in_build:
                 self.__total += 1
                 self.__displayed += 1
@@ -602,6 +656,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         Remove a node from the map.
         """
         if node.children:
+            del self.handle2node[node.handle]
             node.set_handle(None)
             self.__displayed -= 1
             self.__total -= 1
@@ -673,10 +728,15 @@ class TreeBaseModel(gtk.GenericTreeModel):
                 (self.search and self.search.match(handle, self.db)):
             #row needs to be added to the model
             data = self.map(handle)
-            self.add_row(handle, data)
+            if data:
+                self.add_row(handle, data)
+            else:
+                self.add_row2(handle, self.map2(handle))
 
         _LOG.debug(self.__class__.__name__ + ' add_row_by_handle ' +
                     str(time.clock() - cput) + ' sec')
+        _LOG.debug("displayed %d / total: %d" % 
+                   (self.__displayed, self.__total))
 
     def delete_row_by_handle(self, handle):
         """
@@ -705,6 +765,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
             
         _LOG.debug(self.__class__.__name__ + ' delete_row_by_handle ' +
                     str(time.clock() - cput) + ' sec')
+        _LOG.debug("displayed %d / total: %d" % 
+                   (self.__displayed, self.__total))
 
     def update_row_by_handle(self, handle):
         """
@@ -774,30 +836,34 @@ class TreeBaseModel(gtk.GenericTreeModel):
             if col == self.color_column():
                 return None
 
-            # Look for header fuction for column and call it
-            if self.hmap[col] is not None:
-                return self.hmap[col](node)
-
-            # If no header fuction return an empty string
-            return u''
+            # Return the node name for the first column
+            if col == 0:
+                return self.column_header(node)
 
         else:
             # return values for 'data' row, calling a function
             # according to column_defs table
-            return self._get_value(node.handle, col)
+            return self._get_value(node.handle, col, node.secondary)
             
-    def _get_value(self, handle, col):
+    def _get_value(self, handle, col, secondary=False):
         """
         Returns the contents of a given column of a gramps object
         """
-        try:
-            if handle in self.lru_data:
-                data = self.lru_data[handle]
-            else:
+        if handle in self.lru_data:
+            data = self.lru_data[handle]
+        else:
+            if not secondary:
                 data = self.map(handle)
-                if not self._in_build:
-                    self.lru_data[handle] = data
-            return (self.fmap[col](data))
+            else:
+                data = self.map2(handle)
+        if not self._in_build:
+            self.lru_data[handle] = data
+
+        try:
+            if not secondary:
+                return (self.fmap[col](data))
+            else:
+                return (self.fmap2[col](data))
         except:
             return None
 
