@@ -4,6 +4,7 @@
 # Copyright (C) 2003-2007  Donald N. Allingham
 # Copyright (C) 2007-2008  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: BookReport.py 17022 2011-04-02 03:29:05Z pez4brian $
+# $Id: BookReport.py 18978 2012-02-27 04:48:03Z paul-franklin $
 
 # Written by Alex Roitman, 
 # largely based on the BaseDoc classes by Don Allingham
@@ -71,12 +72,13 @@ import Utils
 import ListModel
 import Errors
 from gui.pluginmanager import GuiPluginManager
-from gen.plug.docgen import StyleSheet, StyleSheetList
+from gen.plug.docgen import StyleSheet, StyleSheetList, PaperStyle
 from QuestionDialog import WarningDialog, ErrorDialog
 from gen.plug.menu import PersonOption, FilterOption, FamilyOption
 import ManagedWindow
 from glade import Glade
 from gui.utils import open_file_with_default_application
+import gui.user
 
 # Import from specific modules in ReportBase
 from gen.plug.report import CATEGORY_BOOK, book_categories
@@ -84,6 +86,7 @@ from gui.plug.report._reportdialog import ReportDialog
 from gui.plug.report._docreportdialog import DocReportDialog
 from gen.plug.report._options import ReportOptions
 from cli.plug import CommandLineReport
+import cli.user
 
 from gen.display.name import displayer as _nd
 
@@ -699,7 +702,7 @@ class BookOptions(ReportOptions):
             'bookname'    : '',
         }
         self.options_help = {
-            'bookname'    : ("=name","Name of the book. MANDATORY",
+            'bookname'    : ("=name",_("Name of the book. MANDATORY"),
                             BookList('books.xml',dbase).get_book_names(),
                             False),
         }
@@ -802,13 +805,14 @@ class BookReportSelector(ManagedWindow.ManagedWindow):
         if not regbi:
             return
 
+        available_reports = []
         for pdata in regbi:
             if not pdata.supported:
                 category = _UNSUPPORTED
             else:
                 category = book_categories[pdata.category]
-            
-            data = [pdata.name, category, pdata.id ] 
+            available_reports.append([ pdata.name, category, pdata.id ])
+        for data in sorted(available_reports):
             new_iter = self.avail_model.add(data)
 
         self.avail_model.connect_model()
@@ -1084,6 +1088,7 @@ class BookReportSelector(ManagedWindow.ManagedWindow):
         if book:
             self.open_book(book)
             self.name_entry.set_text(book.get_name())
+            self.book.name = book.get_name()
 
     def on_edit_clicked(self, obj):
         """
@@ -1189,6 +1194,7 @@ class BookReportDialog(DocReportDialog):
         DocReportDialog.__init__(self, dbstate, uistate, options,
                                   'book', _("Book Report"))
         self.book = book
+        self.options.options_dict['bookname'] = self.book.name
         self.database = dbstate.db
         self.selected_style = StyleSheet()
 
@@ -1250,13 +1256,13 @@ class BookReportDialog(DocReportDialog):
         """Create a document of the type requested by the user."""
         pstyle = self.paper_frame.get_paper_style()
         self.doc = self.format(self.selected_style, pstyle)
-
+        user = gui.user.User()
         self.rptlist = []
         for item in self.book.get_item_list():
             item.option_class.set_document(self.doc)
             report_class = item.get_write_item()
-            obj = write_book_item(self.database,
-                                  report_class, item.option_class)
+            obj = write_book_item(self.database, report_class, 
+                                  item.option_class, user)
             self.rptlist.append(obj)
         self.doc.open(self.target_path)
 
@@ -1299,6 +1305,9 @@ def cl_report(database, name, category, options_str_dict):
     book_list = BookList('books.xml', database)
     book_name = clr.options_dict['bookname']
     if book_name:
+        if book_name not in book_list.get_book_names():
+            print _("No such book '%s'") % book_name
+            return
         book = book_list.get_book(book_name)
     else:
         print _("Please specify a book name")
@@ -1324,14 +1333,41 @@ def cl_report(database, name, category, options_str_dict):
                     this_style_name, 
                     style_sheet.get_paragraph_style(this_style_name))
 
+        for this_style_name in style_sheet.get_draw_style_names():
+            selected_style.add_draw_style(
+                    this_style_name,
+                    style_sheet.get_draw_style(this_style_name))
+
+        for this_style_name in style_sheet.get_table_style_names():
+            selected_style.add_table_style(
+                    this_style_name,
+                    style_sheet.get_table_style(this_style_name))
+
+        for this_style_name in style_sheet.get_cell_style_names():
+            selected_style.add_cell_style(
+                    this_style_name,
+                    style_sheet.get_cell_style(this_style_name))
+
+        # The option values were loaded magically by the book parser.
+        # But they still need to be applied to the menu options.
+        opt_dict = item.option_class.options_dict
+        menu = item.option_class.menu
+        for optname in opt_dict:
+            menu_option = menu.get_option_by_name(optname)
+            if menu_option:
+                menu_option.set_value(opt_dict[optname])
+
     # write report
-    doc = clr.format(selected_style, clr.paper, clr.template_name, clr.orien)
+    doc = clr.format(selected_style,
+                     PaperStyle(clr.paper, clr.orien, clr.marginl,
+                                clr.marginr, clr.margint, clr.marginb))
+    user = cli.user.User()
     rptlist = []
     for item in book.get_item_list():
         item.option_class.set_document(doc)
         report_class = item.get_write_item()
         obj = write_book_item(database,
-                              report_class, item.option_class)
+                              report_class, item.option_class, user)
         rptlist.append(obj)
 
     doc.open(clr.option_class.get_output())
@@ -1350,11 +1386,11 @@ def cl_report(database, name, category, options_str_dict):
 # Generic task function for book report
 #
 #------------------------------------------------------------------------
-def write_book_item(database, report_class, options_class):
-    """Write the Timeline Graph using options set.
+def write_book_item(database, report_class, options, user):
+    """Write the report using options set.
     All user dialog has already been handled and the output file opened."""
     try:
-        return report_class(database, options_class)
+        return report_class(database, options, user)
     except Errors.ReportError, msg:
         (m1, m2) = msg.messages()
         ErrorDialog(m1, m2)
