@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Records.py 17578 2011-05-27 09:06:35Z bmcage $
+# $Id: Records.py 18378 2011-10-29 05:02:33Z pez4brian $
 
 #------------------------------------------------------------------------
 #
@@ -45,7 +45,7 @@ from gen.plug.menu import (BooleanOption, EnumeratedListOption,
                            FilterOption, PersonOption, StringOption)
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from Utils import probably_alive
 
 #------------------------------------------------------------------------
@@ -431,10 +431,10 @@ class RecordsGramplet(Gramplet):
 #------------------------------------------------------------------------
 class RecordsReport(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
 
-        Report.__init__(self, database, options_class)
-        menu = options_class.menu
+        Report.__init__(self, database, options, user)
+        menu = options.menu
 
         self.filter_option =  menu.get_option_by_name('filter')
         self.filter = self.filter_option.get_filter()
