@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GtkPrint.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: GtkPrint.py 18556 2011-12-08 16:40:27Z paul-franklin $
 
 """Printing interface based on gtk.Print* classes.
 """
@@ -45,7 +45,6 @@ from math import radians
 from gen.plug.docgen import PAPER_PORTRAIT
 import libcairodoc
 import Errors
-from glade import Glade
 #import constfunc
 
 #------------------------------------------------------------------------
@@ -61,11 +60,13 @@ log = logging.getLogger(".GtkPrint")
 # GTK modules
 #
 #-------------------------------------------------------------------------
-import gtk
 import cairo
-
-if gtk.pygtk_version < (2, 10, 0):
-    raise Errors.UnavailableError(_("PyGtk 2.10 or later is required"))
+try: # the Gramps-Connect server has no DISPLAY
+    import gtk
+    if gtk.pygtk_version < (2, 10, 0):
+        raise Errors.UnavailableError(_("PyGtk 2.10 or later is required"))
+except:
+    pass
 
 #------------------------------------------------------------------------
 #
@@ -203,7 +204,7 @@ class PrintPreview(object):
     def __build_window(self):
         """Build the window from Glade.
         """
-
+        from glade import Glade
         glade_xml = Glade()
         self._window = glade_xml.toplevel
         #self._window.set_transient_for(parent)
