@@ -6,6 +6,7 @@
 # Copyright (C) 2007-2009  Brian G. Matherly
 # Copyright (C) 2010       Peter Landgren
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ODFDoc.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: ODFDoc.py 18886 2012-02-14 23:11:49Z nick-h $
 
 """
 ODFDoc : used to generate Open Office Document
@@ -81,7 +82,8 @@ from xml.sax.saxutils import escape
 from gen.plug.docgen import (BaseDoc, TextDoc, DrawDoc, graphicstyle,
                     FONT_SANS_SERIF, SOLID, PAPER_PORTRAIT,
                     INDEX_TYPE_TOC, PARA_ALIGN_CENTER, PARA_ALIGN_LEFT, 
-                    INDEX_TYPE_ALP, PARA_ALIGN_RIGHT)
+                    INDEX_TYPE_ALP, PARA_ALIGN_RIGHT, URL_PATTERN,
+                    LOCAL_HYPERLINK, LOCAL_TARGET)
 from gen.plug.docgen.fontscale import string_width
 from libodfbackend import OdfBackend
 import const
@@ -111,7 +113,8 @@ _esc_map = {
 #
 #-------------------------------------------------------------------------
 import re
-NewStyle = re.compile('style-name="([a-zA-Z0-9]*)__([#a-zA-Z0-9 ]*)__">')
+# Hyphen is added because it is used to replace spaces in the font name
+NewStyle = re.compile('style-name="([a-zA-Z0-9]*)__([#a-zA-Z0-9 -]*)__">')
 
 #-------------------------------------------------------------------------
 #
@@ -155,6 +158,7 @@ _FONTS = '''\
     svg:font-family="Arial"
     style:font-family-generic="swiss"
     style:font-pitch="variable"/>
+
 '''
 
 _META_XML = '''\
@@ -297,6 +301,7 @@ _AUTOMATIC_STYLES = '''\
     <style:text-properties
         style:font-name="Courier"/>
 </style:style>
+
 '''
 
 _CLEAR_STYLE = '''\
@@ -416,6 +421,8 @@ _SHEADER_FOOTER = '''\
 </style:style>\n
 '''
 
+_CLICKABLE = r'''<text:a xlink:type="simple" xlink:href="\1">\1</text:a>'''
+
 #-------------------------------------------------------------------------
 #
 # ODFDoc
@@ -441,6 +448,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self.mimetype = None
         self.meta = None
         self.mfile = None
+        self.stfile = None
         self.filename = None
         self.lang = None
         self._backend = None
@@ -451,7 +459,8 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self.new_cell = 0
         self.page = 0
         self.first_page = 1
-        self.StyleList = [] # styles to create depending on styled notes.
+        self.StyleList_notes = [] # styles to create depending on styled notes.
+        self.StyleList_photos = [] # styles to create depending on clipped images.
 
     def open(self, filename):
         """
@@ -484,7 +493,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self.lang = current_locale[0]
         self.lang = self.lang.replace('_', '-') if self.lang else "en-US"
 
-        self.StyleList = [] # styles to create depending on styled notes.
+        self.StyleList_notes = [] # styles to create depending on styled notes.
         wrt1('<?xml version="1.0" encoding="UTF-8"?>\n'
             '<office:document-content\n' +
             _XMLNS +
@@ -783,9 +792,10 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         The content.xml file is closed.
         """
         self.cntntx = StringIO()
-        self.StyleList = self.uniq(self.StyleList)
+        self.StyleList_notes = self.uniq(self.StyleList_notes)
         self.add_styled_notes_fonts()
         self.add_styled_notes_styles()
+        self.add_styled_photo_styles()
         self.cntntx.write(self.cntnt1.getvalue())
         self.cntntx.write(self.cntnt2.getvalue())
         self.cntntx.write(self.cntnt.getvalue())
@@ -805,6 +815,7 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self.finish_cntnt_creation()
         self._write_styles_file()
         self._write_manifest()
+        self._write_settings()
         self._write_meta_file()
         self._write_mimetype_file()
         self._write_zip()
@@ -815,13 +826,16 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         """
         # Need to add new font for styled notes here.
         wrt1 = self.cntnt1.write
-        for style in self.StyleList:
+        for style in self.StyleList_notes:
             if style[1] == "FontFace":
+                # Restore any spaced that were replaced by hyphens in
+                # libodfbackend
                 wrt1(
                     '<style:font-face ' +
-                        'style:name="%s" ' %  style[2] +
-                        'svg:font-family="&apos;%s&apos;" ' % style[2] +
-                        'style:font-pitch="fixed"/>\n'
+                    '    style:name="%s"\n' %  style[2].replace("-", " ") +
+                    '    svg:font-family="&apos;%s&apos;"\n' % 
+                                    style[2].replace("-", " ") +
+                    '    style:font-pitch="fixed"/>\n\n'
                     )
 
     def add_styled_notes_styles(self):
@@ -830,51 +844,163 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         """
         # Need to add new style for styled notes here.
         wrt2 = self.cntnt2.write
-        for style in self.StyleList:
+        for style in self.StyleList_notes:
             if style[1] == "FontSize":
                 wrt2(
                     '<style:style ' +
-                        'style:name="FontSize__%s__" ' % style[2] +
-                        'style:family="text"> ' +
-                        '<style:text-properties ' +
-                            'fo:font-size="%spt" ' % style[2] +
-                            'style:font-size-asian="%spt" ' % style[2] +
-                            'style:font-size-complex="%spt"/>' %  style[2] +
-                    '</style:style>\n'
+                        'style:name="FontSize__%s__"\n' % style[2] +
+                    '    style:family="text">\n' +
+                    '    <style:text-properties\n' +
+                    '        fo:font-size="%spt"\n' % style[2] +
+                    '        style:font-size-asian="%spt"\n' % style[2] +
+                    '        style:font-size-complex="%spt"/>\n' %  style[2] +
+                    '</style:style>\n\n'
                     )
 
             elif style[1] == "FontColor":
+                # Restore the hash at the start that was removed by
+                # libodfbackend
                 wrt2(
                     '<style:style ' +
-                        'style:name="FontColor__%s__" ' % style[2] +
-                        'style:family="text">' +
-                        ' <style:text-properties ' +
-                            'fo:color="%s"/>' % style[2] +
-                    '</style:style>\n'
+                        'style:name="FontColor__%s__"\n' % style[2] +
+                    '    style:family="text">\n' +
+                    '    <style:text-properties\n' +
+                    '        fo:color="#%s"/>\n' % style[2] +
+                    '</style:style>\n\n'
                     )
 
             elif style[1] == "FontHighlight":
                 wrt2(
                     '<style:style ' +
-                        'style:name="FontHighlight__%s__" ' % style[2]  +
-                        'style:family="text"> ' +
-                        '<style:text-properties ' +
-                            'fo:background-color="%s"/>' % style[2] +
-                    '</style:style>\n'
+                        'style:name="FontHighlight__%s__"\n' % style[2]  +
+                    '    style:family="text">\n' +
+                    '    <style:text-properties\n' +
+                    '        fo:background-color="#%s"/>\n' % style[2] +
+                    '</style:style>\n\n'
                     )
 
             elif style[1] == "FontFace":
+                # Restore any spaced that were replaced by hyphens in
+                # libodfbackend
                 wrt2(
                     '<style:style ' +
-                        'style:name="FontFace__%s__" ' % style[2] +
-                        'style:family="text"> ' +
-                        '<style:text-properties ' +
-                            'style:font-name="%s" ' % style[2]  +
-                            'style:font-pitch="variable"/>' +
+                        'style:name="FontFace__%s__"\n' % style[2] +
+                    '    style:family="text">\n' +
+                    '    <style:text-properties\n' +
+                    '        style:font-name="%s"\n' % 
+                                    style[2].replace("-", " ")  +
+                    '        style:font-pitch="variable"/>\n' +
+                    '</style:style>\n\n'
+                    )
+
+    def add_styled_photo_styles(self):
+        """
+        Add the new styles for clipped images in the automatic-styles section.
+        """
+        wrt2 = self.cntnt2.write
+        for style in self.StyleList_photos:
+            if style[0] == "Left":
+                wrt2(
+                    '<style:style ' +
+                        'style:name="Left_%s" ' % str(style[1]) +
+                        'style:family="graphic" ' +
+                        'style:parent-style-name="photo">' +
+                        '<style:graphic-properties ' +
+                            'style:run-through="foreground" ' +
+                            'style:wrap="dynamic" ' +
+                            'style:number-wrapped-paragraphs="no-limit" ' +
+                            'style:wrap-contour="false" ' +
+                            'style:vertical-pos="from-top" ' +
+                            'style:vertical-rel="paragraph-content" ' +
+                            'style:horizontal-pos="left" ' +
+                            'style:horizontal-rel="paragraph-content" ' +
+                            'style:mirror="none" ' +
+                            'fo:clip="rect(%fin %fin %fin %fin)" ' % style[1] +
+                            'draw:luminance="0%" ' +
+                            'draw:contrast="0" ' +
+                            'draw:red="0%" ' +
+                            'draw:green="0%" ' +
+                            'draw:blue="0%" ' +
+                            'draw:gamma="1" ' +
+                            'draw:color-inversion="false" ' +
+                            'draw:transparency="-100%" ' +
+                            'draw:color-mode="standard"/>' +
+                    '</style:style>\n'
+                    )
+            elif style[0] == "Right":
+                wrt2(
+                    '<style:style ' +
+                        'style:name="Right_%s" ' % str(style[1]) +
+                        'style:family="graphic" ' +
+                        'style:parent-style-name="photo">' +
+                        '<style:graphic-properties ' +
+                            'style:run-through="foreground" ' +
+                            'style:wrap="dynamic" ' +
+                            'style:number-wrapped-paragraphs="no-limit" ' +
+                            'style:wrap-contour="false" ' +
+                            'style:vertical-pos="from-top" ' +
+                            'style:vertical-rel="paragraph-content" ' +
+                            'style:horizontal-pos="right" ' +
+                            'style:horizontal-rel="paragraph-content" ' +
+                            'style:mirror="none" ' +
+                            'fo:clip="rect(%fin %fin %fin %fin)" ' % style[1] +
+                            'draw:luminance="0%" ' +
+                            'draw:contrast="0" ' +
+                            'draw:red="0%" ' +
+                            'draw:green="0%" ' +
+                            'draw:blue="0%" ' +
+                            'draw:gamma="1" ' +
+                            'draw:color-inversion="false" ' +
+                            'draw:transparency="-100%" ' +
+                            'draw:color-mode="standard"/>' +
+                    '</style:style>\n'
+                    )
+            elif style[0] == "Single":
+                wrt2(
+                    '<style:style ' +
+                        'style:name="Single_%s" ' % str(style[1]) +
+                        'style:family="graphic" ' +
+                        '<style:graphic-properties ' +
+                            'style:vertical-pos="from-top" ' +
+                            'style:mirror="none" ' +
+                            'fo:clip="rect(%fin %fin %fin %fin)" ' % style[1] +
+                            'draw:luminance="0%" ' +
+                            'draw:contrast="0" ' +
+                            'draw:red="0%" ' +
+                            'draw:green="0%" ' +
+                            'draw:blue="0%" ' +
+                            'draw:gamma="1" ' +
+                            'draw:color-inversion="false" ' +
+                            'draw:transparency="-100%" ' +
+                            'draw:color-mode="standard"/>' +
+                    '</style:style>\n'
+                    )
+            else:
+                wrt2(
+                    '<style:style ' +
+                        'style:name="Row_%s" ' % str(style[1]) +
+                        'style:family="graphic" ' +
+                        'style:parent-style-name="Graphics">' +
+                        '<style:graphic-properties ' +
+                            'style:vertical-pos="from-top" ' +
+                            'style:vertical-rel="paragraph" ' +
+                            'style:horizontal-pos="from-left" ' +
+                            'style:horizontal-rel="paragraph" ' +
+                            'style:mirror="none" ' +
+                            'fo:clip="rect(%fin %fin %fin %fin)" ' % style[1] +
+                            'draw:luminance="0%" ' +
+                            'draw:contrast="0" ' +
+                            'draw:red="0%" ' +
+                            'draw:green="0%" ' +
+                            'draw:blue="0%" ' +
+                            'draw:gamma="1" ' +
+                            'draw:color-inversion="false" ' +
+                            'draw:transparency="-100%" ' +
+                            'draw:color-mode="standard"/>' +
                     '</style:style>\n'
                     )
 
-    def add_media_object(self, file_name, pos, x_cm, y_cm, alt=''):
+    def add_media_object(self, file_name, pos, x_cm, y_cm, alt='', style_name=None, crop=None):
         """
         Add multi-media documents : photos
         """
@@ -885,14 +1011,6 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         if (x, y) == (0, 0):
             return
         
-        ratio = float(x_cm) * float(y) / (float(y_cm) * float(x))
-        if ratio < 1:
-            act_width = x_cm
-            act_height = y_cm * ratio
-        else:
-            act_height = y_cm
-            act_width = x_cm / ratio
-            
         not_extension, extension = os.path.splitext(file_name)
         odf_name = md5(file_name).hexdigest() + extension
 
@@ -907,6 +1025,44 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             self.cntnt.write('<text:p>')
 
         pos = pos.title() if pos in ['left', 'right', 'single'] else 'Row'
+
+        if crop:
+            dpi = ImgManip.image_dpi(file_name)
+
+            if dpi:
+                (act_width, act_height) = ImgManip.image_actual_size(
+                    x_cm, y_cm, crop[2] - crop[0], crop[3] - crop[1]
+                )
+
+                left = ((crop[0]/100.0)*x)/dpi[0]
+                right = (x - ((crop[2]/100.0)*x))/dpi[0]
+                top = ((crop[1]/100.0)*y)/dpi[1]
+                bottom = (y - ((crop[3]/100.0)*y))/dpi[1]
+
+                crop = (top, right, bottom, left)
+
+                self.StyleList_photos.append(
+                    [pos, crop]
+                )
+
+                pos += "_" + str(crop)
+            else:
+                (act_width, act_height) = ImgManip.image_actual_size(x_cm, y_cm, x, y)
+        else:
+            (act_width, act_height) = ImgManip.image_actual_size(x_cm, y_cm, x, y)
+
+        if len(alt):
+            self.cntnt.write(
+                '<draw:frame draw:style-name="%s" ' % pos +
+                    'draw:name="caption_%s" ' % tag +
+                    'text:anchor-type="paragraph" ' +
+                    'svg:y="0in" ' +
+                    'svg:width="%.2fcm" ' % act_width +
+                    'draw:z-index="34"> ' +
+                    '<draw:text-box fo:min-height="%.2fcm"> ' % act_height +
+                    '<text:p text:style-name="%s">' % style_name
+                    )
+
         self.cntnt.write(
             '<draw:frame draw:style-name="%s" ' % pos +
                 'draw:name="%s" ' % tag +
@@ -920,6 +1076,14 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             '</draw:frame>\n'
             )
 
+        if len(alt):
+            self.cntnt.write(
+                '%s' % '<text:line-break/>'.join(alt) +
+                '</text:p>' +
+                '</draw:text-box>' +
+                '</draw:frame>'
+                )
+
         if self.new_cell:
             self.cntnt.write('</text:p>\n')
 
@@ -1034,12 +1198,14 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
         self._add_zip(zfile, "META-INF/manifest.xml", self.mfile.getvalue(), t)
         self._add_zip(zfile, "content.xml", self.cntntx.getvalue(), t)
         self._add_zip(zfile, "meta.xml", self.meta.getvalue(), t)
+        self._add_zip(zfile, "settings.xml", self.stfile.getvalue(), t)
         self._add_zip(zfile, "styles.xml", self.sfile.getvalue(), t)
         self._add_zip(zfile, "mimetype", self.mimetype.getvalue(), t)
 
         self.mfile.close()
         self.cntnt.close()
         self.meta.close()
+        self.stfile.close()
         self.sfile.close()
         self.mimetype.close()
         
@@ -1355,26 +1521,8 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             )
         self.new_cell = 1
 
-    def write_endnotes_ref(self, text, style_name):
-        """
-        Overwrite base method for lines of endnotes references
-        """
-        for line in text.split('\n'):
-            text = escape(line, _esc_map)
-            # Replace multiple spaces: have to go from the largest number down
-            for n in range(text.count(' '), 1, -1):
-                text = text.replace(' '*n, ' <text:s text:c="%d"/>' % (n-1) )
-            self.start_paragraph(style_name)
-#            self.cntnt.write('<text:span text:style-name="GRAMPS-preformat">')
-            self.cntnt.write(
-                '<text:span text:style-name="Standard">' +
-                    text +
-                '</text:span>'
-                )
-            self.end_paragraph()
-
     def write_styled_note(self, styledtext, format, style_name,
-                          contains_html=False):
+                          contains_html=False, links=False):
         """
         Convenience function to write a styledtext to the ODF doc. 
         styledtext : assumed a StyledText object to write
@@ -1384,10 +1532,15 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             If contains_html=True, then the textdoc is free to handle that in 
             some way. Eg, a textdoc could remove all tags, or could make sure
             a link is clickable. ODFDoc prints the html without handling it
+        links: bool, make URLs clickable if True
         """
         text = str(styledtext)
         s_tags = styledtext.get_tags()
         markuptext = self._backend.add_markup_from_styled(text, s_tags, '\n')
+
+        if links == True:
+            markuptext = re.sub(URL_PATTERN, _CLICKABLE, markuptext)
+
         # we need to know if we have new styles to add.
         # if markuptext contains : FontColor, FontFace, FontSize ...
         # we must prepare the new styles for the styles.xml file.
@@ -1399,9 +1552,9 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
             m = NewStyle.search(markuptext, start)
             if not m:
                 break
-            self.StyleList.append([m.group(1)+m.group(2),
-                                  m.group(1),
-                                  m.group(2)])
+            self.StyleList_notes.append([m.group(1)+m.group(2),
+                                        m.group(1),
+                                        m.group(2)])
             start = m.end()
         linenb = 1
         self.start_paragraph(style_name)
@@ -1418,12 +1571,17 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                 linenb += 1
         self.end_paragraph()
 
-    def write_text(self, text, mark=None):
+    def write_text(self, text, mark=None, links=False):
         """
         Uses the xml.sax.saxutils.escape function to convert XML
         entities. The _esc_map dictionary allows us to add our own
         mappings.
         """
+        text = escape(text, _esc_map)
+
+        if links == True:
+            text = re.sub(URL_PATTERN, _CLICKABLE, text)
+
         if mark:
             key = escape(mark.key, _esc_map)
             key = key.replace('"', '&quot;')
@@ -1439,7 +1597,92 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                     'text:string-value="%s" ' % key +
                     'text:outline-level="%d" />' % mark.level
                     )
-        self.cntnt.write(escape(text, _esc_map))
+            elif mark.type == LOCAL_HYPERLINK:
+                self.cntnt.write(
+                    '<text:a xlink:type="simple" xlink:href="%s">' % key)
+                self.cntnt.write(text)
+                self.cntnt.write('</text:a>')
+                return
+            elif mark.type == LOCAL_TARGET:
+                self.cntnt.write(
+                    '<text:bookmark text:name="%s"/>' % key)
+
+        self.cntnt.write(text)
+
+    def insert_toc(self):
+        """
+        Insert a Table of Contents at this point in the document.
+        """
+        title = _('Contents')
+        self.cntnt.write('<text:table-of-content>')
+
+        self.cntnt.write('<text:table-of-content-source ' +
+                         'text:outline-level="3" ' +
+                         'text:use-outline-level="false">')
+
+        self.cntnt.write('<text:index-title-template ' + 
+                         'text:style-name="TOC-Title">' + title)
+        self.cntnt.write('</text:index-title-template>')
+
+        for level in range(1, 4):
+            self.cntnt.write('<text:table-of-content-entry-template ' +
+                             'text:outline-level="%d" ' % level +
+                             'text:style-name="TOC-Heading%d">' % level)
+
+            self.cntnt.write('<text:index-entry-chapter/>')
+            self.cntnt.write('<text:index-entry-text/>')
+            self.cntnt.write('<text:index-entry-tab-stop ' +
+                             'style:type="right" ' +
+                             'style:leader-char="."/>')
+            self.cntnt.write('<text:index-entry-page-number/>')
+            self.cntnt.write('</text:table-of-content-entry-template>')
+
+        self.cntnt.write('</text:table-of-content-source>')
+
+        self.cntnt.write('<text:index-body>')
+        self.cntnt.write('<text:index-title>')
+        self.cntnt.write('<text:p text:style-name="NLTOC-Title">%s</text:p>' % 
+                        title)
+        self.cntnt.write('</text:index-title>')
+        self.cntnt.write('</text:index-body>')
+
+        self.cntnt.write('</text:table-of-content>')
+
+    def insert_index(self):
+        """
+        Insert an Alphabetical Index at this point in the document.
+        """
+        title = _('Index')
+        self.cntnt.write('<text:alphabetical-index>')
+        self.cntnt.write('<text:alphabetical-index-source ' +
+                         'text:ignore-case="true"  ' +
+                         'text:combine-entries="false"  ' +
+                         'text:combineentries-with-pp="false">')
+
+        self.cntnt.write('<text:index-title-template ' + 
+                         'text:style-name="IDX-Title">' + title)
+        self.cntnt.write('</text:index-title-template>')
+        
+        self.cntnt.write('<text:alphabetical-index-entry-template ' +
+                         'text:outline-level="1" ' +
+                         'text:style-name="IDX-Entry">')
+        self.cntnt.write('<text:index-entry-text/>')
+        self.cntnt.write('<text:index-entry-tab-stop ' +
+                         'style:type="right" ' +
+                         'style:leader-char="."/>')
+        self.cntnt.write('<text:index-entry-page-number/>')
+        self.cntnt.write('</text:alphabetical-index-entry-template>')
+
+        self.cntnt.write('</text:alphabetical-index-source>')
+
+        self.cntnt.write('<text:index-body>')
+        self.cntnt.write('<text:index-title>')
+        self.cntnt.write('<text:p text:style-name="NLIDX-Title">%s</text:p>' % 
+                        title)
+        self.cntnt.write('</text:index-title>')
+        self.cntnt.write('</text:index-body>')
+
+        self.cntnt.write('</text:alphabetical-index>')
 
     def _write_manifest(self):
         """
@@ -1475,11 +1718,30 @@ class ODFDoc(BaseDoc, TextDoc, DrawDoc):
                 'manifest:full-path="content.xml"/>'
             '<manifest:file-entry manifest:media-type="text/xml" '
                 'manifest:full-path="styles.xml"/>'
+            '<manifest:file-entry manifest:media-type="text/xml" '
+                'manifest:full-path="settings.xml"/>'
             '<manifest:file-entry manifest:media-type="text/xml" '
                 'manifest:full-path="meta.xml"/>'
             '</manifest:manifest>\n'
             )
 
+    def _write_settings(self):
+        """
+        create the settings.xml file
+        """
+        self.stfile = StringIO()
+        # This minimal settings file has been taken from
+        # http://mashupguide.net/1.0/html/ch17s03.xhtml (Creative commons
+        # licence): http://mashupguide.net/1.0/html/apas02.xhtml
+        self.stfile.write(
+          '<?xml version="1.0" encoding="UTF-8"?>\n' +
+          '<office:document-settings office:version="1.0"\n' +
+          'xmlns:config="urn:oasis:names:tc:opendocument:xmlns:config:1.0"\n' +
+          'xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0"\n' +
+          'xmlns:ooo="http://openoffice.org/2004/office"\n' +
+          'xmlns:xlink="http://www.w3.org/1999/xlink" />'
+            )
+    
     def _write_mimetype_file(self):
         """
         create the mimetype.xml file
@@ -1743,4 +2005,4 @@ def process_spaces(line, format):
             sigcount += 1
             txt += char
     return [txt, sigcount]
-    
\ No newline at end of file
+    
