@@ -4,6 +4,7 @@
 # Copyright (C) 2000-2006  Donald N. Allingham
 # Copyright (C) 2007-2009  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PSDrawDoc.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: PSDrawDoc.py 18848 2012-02-10 19:57:57Z nick-h $
 
 """
 PostScript document generator.
@@ -147,7 +148,7 @@ class PSDrawDoc(BaseDoc, DrawDoc):
             )
         self.file.close()
         
-    def write_text(self, text, mark=None):
+    def write_text(self, text, mark=None, links=False):
         pass
 
     def start_page(self):
