@@ -5,6 +5,7 @@
 # Copyright (C) 2007-2009  Brian G. Matherly
 # Copyright (C) 2009       Gary Burton
 # Copyright (C) 2010       Peter Landgren
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:RTFDoc.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: RTFDoc.py 18770 2012-01-25 23:28:42Z kulath $
 
 #------------------------------------------------------------------------
 #
@@ -29,6 +30,8 @@
 #
 #------------------------------------------------------------------------
 from gen.ggettext import gettext as _
+import logging
+LOG = logging.getLogger(".rtfdoc")
 
 #------------------------------------------------------------------------
 #
@@ -36,11 +39,19 @@ from gen.ggettext import gettext as _
 #
 #------------------------------------------------------------------------
 from gen.plug.docgen import (BaseDoc, TextDoc, FONT_SERIF, PARA_ALIGN_RIGHT,
-                             PARA_ALIGN_CENTER, PARA_ALIGN_JUSTIFY)
+                             PARA_ALIGN_CENTER, PARA_ALIGN_JUSTIFY,
+                             URL_PATTERN)
 import ImgManip
 import Errors
 import Utils
 
+#------------------------------------------------------------------------
+#
+# Set up to make links clickable
+#
+#------------------------------------------------------------------------
+_CLICKABLE = r'''{\\field{\\*\\fldinst HYPERLINK "\1"}{\\fldrslt \1}}'''
+
 #------------------------------------------------------------------------
 #
 # RTF uses a unit called "twips" for its measurements. According to the 
@@ -231,6 +242,9 @@ class RTFDoc(BaseDoc,TextDoc):
         # there is no newline between the description and the note.
         if not self.in_table:
             self.f.write(self.text)
+            LOG.debug("end_paragraph: opened: %d write: %s" % 
+                      (self.opened,
+                       self.text + '}' if self.opened else "" + "newline"))
             if self.opened:
                 self.f.write('}')
                 self.opened = 0
@@ -255,9 +269,12 @@ class RTFDoc(BaseDoc,TextDoc):
     #
     #--------------------------------------------------------------------
     def start_bold(self):
+        LOG.debug("start_bold: opened: %d saved text: %s" % 
+                  (self.opened, 
+                   '}' if self.opened else "" + '{%s\\b ' % self.font_type))
         if self.opened:
-            self.f.write('}')
-        self.f.write('{%s\\b ' % self.font_type)
+            self.text += '}'
+        self.text += '{%s\\b ' % self.font_type
         self.opened = 1
 
     #--------------------------------------------------------------------
@@ -266,10 +283,14 @@ class RTFDoc(BaseDoc,TextDoc):
     #
     #--------------------------------------------------------------------
     def end_bold(self):
+        LOG.debug("end_bold: opened: %d saved text: %s" % 
+                  (self.opened, 
+                   self.text + '}'))
+        if not self.opened == 1:
+            print self.opened
+            raise RuntimeError
         self.opened = 0
-        self.f.write(self.text)
-        self.text = ""
-        self.f.write('}')
+        self.text += '}'
 
     def start_superscript(self):
         self.text += '{{\*\updnprop5801}\up10 '
@@ -372,31 +393,23 @@ class RTFDoc(BaseDoc,TextDoc):
     # dumped as a string of HEX numbers.
     #
     #--------------------------------------------------------------------
-    def add_media_object(self, name, pos, x_cm, y_cm, alt=''):
+    def add_media_object(self, name, pos, x_cm, y_cm, alt='', style_name=None, crop=None):
 
         nx, ny = ImgManip.image_size(name)
 
         if (nx, ny) == (0,0):
             return
 
-        if (nx, ny) == (0,0):
-            return
-
-        ratio = float(x_cm)*float(ny)/(float(y_cm)*float(nx))
-
-        if ratio < 1:
-            act_width = x_cm
-            act_height = y_cm*ratio
-        else:
-            act_height = y_cm
-            act_width = x_cm/ratio
-
-        buf = ImgManip.resize_to_jpeg_buffer(name, int(act_width*40), 
-                                             int(act_height*40))
+        (act_width, act_height) = ImgManip.image_actual_size(x_cm, y_cm, nx, ny)
 
         act_width = twips(act_width)
         act_height = twips(act_height)
 
+        size = [act_width, act_height]
+        buf = ImgManip.resize_to_jpeg_buffer(name, size, crop=crop)
+        act_width = size[0] # In case it changed because of cropping or keeping the ratio
+        act_height = size[1]
+
         self.f.write('{\*\shppict{\\pict\\jpegblip')
         self.f.write('\\picwgoal%d\\pichgoal%d\n' % (act_width,act_height))
         index = 1
@@ -407,8 +420,11 @@ class RTFDoc(BaseDoc,TextDoc):
             index = index+1
         self.f.write('}}\\par\n')
 
+        if len(alt):
+            self.f.write('%s\n\\par\n' % '\\par'.join(alt))
+
     def write_styled_note(self, styledtext, format, style_name,
-                          contains_html=False):
+                          contains_html=False, links=False):
         """
         Convenience function to write a styledtext to the RTF doc. 
         styledtext : assumed a StyledText object to write
@@ -418,6 +434,7 @@ class RTFDoc(BaseDoc,TextDoc):
             If contains_html=True, then the textdoc is free to handle that in 
             some way. Eg, a textdoc could remove all tags, or could make sure
             a link is clickable. RTFDoc prints the html without handling it
+        links: bool, make URLs clickable if True
         """
         text = str(styledtext)
         self.start_paragraph(style_name)
@@ -434,7 +451,7 @@ class RTFDoc(BaseDoc,TextDoc):
             else:
                 if ( linenb > 1 ):
                     self.write_text('\\line ')
-                self.write_text(line)
+                self.write_text(line, links=links)
                 linenb += 1
         # FIXME: I don't understand why these newlines are necessary.
         # It may be related to the behaviour of end_paragraph inside tables, and
@@ -446,21 +463,6 @@ class RTFDoc(BaseDoc,TextDoc):
             self.write_text('\n')
         self.end_paragraph()
 
-    def write_endnotes_ref(self,text,style_name):
-        """
-        Overwrite base method for lines of endnotes references
-        """
-        for line in text.split('\n'):
-            self.start_paragraph(style_name)
-            self.write_text(line)
-            if self.in_table:
-                # Add LF when in table as in indiv_complete report
-                self.write_text('\n')
-            self.end_paragraph()
-        # Write an empty para after all ref lines for each source
-        self.start_paragraph(style_name)
-        self.end_paragraph()
-
     #--------------------------------------------------------------------
     #
     # Writes text. If braces are not currently open, open them. Loop 
@@ -469,10 +471,13 @@ class RTFDoc(BaseDoc,TextDoc):
     # the form of \`XX. Make sure to escape braces.
     #
     #--------------------------------------------------------------------
-    def write_text(self,text,mark=None):
+    def write_text(self,text,mark=None,links=False):
     # Convert to unicode, just in case it's not. Fix of bug 2449.
         text = unicode(text)
         text = text.replace('\n','\n\\par ')
+        LOG.debug("write_text: opened: %d input text: %s" % 
+                  (self.opened, 
+                   text))
         if self.opened == 0:
             self.opened = 1
             self.text += '{%s ' % self.font_type
@@ -490,6 +495,13 @@ class RTFDoc(BaseDoc,TextDoc):
             else:
                 self.text += i
 
+        if links ==  True:
+            import re
+            self.text = re.sub(URL_PATTERN, _CLICKABLE, self.text)
+        LOG.debug("write_text, exit: opened: %d saved text: %s" % 
+                  (self.opened, 
+                   self.text))
+
 def process_spaces(line, format):
     """
     Function to process spaces in text lines for flowed and pre-formatted notes.
