@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Ancestor2.py 
+# $Id: AncestorTree.py 18915 2012-02-17 16:51:40Z romjerome $
 
 """Reports/Graphical Reports/Ancestor Tree"""
 
@@ -57,12 +57,10 @@ from gen.plug.menu import PersonOption
 
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 
 from gen.display.name import displayer as name_displayer
 
-from gui.utils import ProgressMeter
-
 PT2CM = ReportUtils.pt2cm
 #cm2pt = ReportUtils.cm2pt
 
@@ -149,6 +147,7 @@ class TitleA(TitleBox):
         if center is not None:
             name = name_displayer.display(center)
         
+        # feature request 2356: avoid genitive form
         self.text = _("Ancestor Graph for %s") % name
         self.set_box_height_width()
 
@@ -205,7 +204,7 @@ class CalcItems(object):
             return self.__calc_l.calc_lines(indi_handle, fams_handle,
                                     working_lines)
         
-    def calc_marrage(self, indi_handle, fams_handle):
+    def calc_marriage(self, indi_handle, fams_handle):
         if indi_handle == fams_handle == None:
             return self.__blank_marriage
         else:
@@ -246,13 +245,13 @@ class MakeAncestorTree(object):
         myself = FamilyBox(index)
 
         #calculate the text.
-        myself.text = self.calc_items.calc_marrage(indi_handle, fams_handle)
+        myself.text = self.calc_items.calc_marriage(indi_handle, fams_handle)
 
         self.canvas.add_box(myself)
     
     def iterate(self, person_handle, index):
         """ Fills out the Ancestor tree as desired/needed.
-            this is an iterative apporach.  
+            this is an iterative approach.  
         """
         if self.max_generations < 1:
             return
@@ -353,7 +352,7 @@ class MakeAncestorTree(object):
                 #Set __fams[cur_gen] and __pers[cur_gen]
                 #make sure there is a NEW int.
                 __index.pop()
-                #not a refernce that will clobber dads (other peoples) info
+                #not a reference that will clobber dads (other peoples) info
                 __index.append((__index[cur_gen-1] *2) +1)
 
                 _get_person(cur_gen)
@@ -390,7 +389,7 @@ class MakeAncestorTree(object):
     
     def __fill(self, index, max_fill):
         """ Fills out the Ancestor tree as desired/needed.
-            this is an iterative apporach.  
+            this is an iterative approach.  
         """
         if max_fill < 1:
             return
@@ -446,7 +445,7 @@ class MakeAncestorTree(object):
                 
                 #make sure there is a NEW int.
                 __index.pop()
-                #not a refernce that will clobber dada info
+                #not a reference that will clobber dads info
                 __index.append((__index[cur_gen-1] *2) +1)
                 #__index[cur_gen] +=1
                 
@@ -646,21 +645,22 @@ class GUIConnect():
 #------------------------------------------------------------------------
 class AncestorTree(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create AncestorTree object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        person          - currently selected person
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         """
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
 
-        self.options_class = options_class
+        self.options = options
         self.database = database
+        self._user = user
 
         #The canvas that we will put our report on and print off of
         self.canvas = Canvas(self.doc)
@@ -687,15 +687,15 @@ class AncestorTree(Report):
         database = self.database
 
         self.connect = GUIConnect()
-        self.connect.set__opts(self.options_class.menu)
+        self.connect.set__opts(self.options.menu)
 
         #Set up the canvas that we will print on.
         style_sheet = self.doc.get_style_sheet()
         font_normal = style_sheet.get_paragraph_style("AC2-Normal").get_font()
         self.doc.report_opts = ReportOptions(self.doc, font_normal, 'AC2-line')
         
-        self.progress = ProgressMeter(_('Ancestor Tree'))
-        self.progress.set_pass(_('Making the Tree...'), 4)
+        self._user.begin_progress(_('Ancestor Tree'), 
+                                  _('Making the Tree...'), 4)
 
         #make the tree onto the canvas
         inlc_marr = self.connect.get_val("inc_marr")
@@ -706,7 +706,7 @@ class AncestorTree(Report):
         tree.start(self.connect.get_val('pid'))
         tree = None
 
-        self.progress.step()
+        self._user.step_progress()
 
         #Title
         title = self.connect.title_class(self.doc)
@@ -724,7 +724,7 @@ class AncestorTree(Report):
         self.max_generations = report.get_generations()  #already know
         report = None
 
-        self.progress.step()
+        self._user.step_progress()
 
         #Note?
         if self.connect.get_val("inc_note"):
@@ -756,7 +756,7 @@ class AncestorTree(Report):
         prnnum = self.connect.get_val("inc_pagenum")
 
         #####################
-        #Setup page infomation
+        #Setup page information
 
         colsperpage = self.doc.get_usable_width() 
         colsperpage += self.doc.report_opts.col_width
@@ -769,7 +769,7 @@ class AncestorTree(Report):
         if prnnum:
             page_num_box = PageNumberBox(self.doc, 'AC2-box')
         
-        self.progress.step()
+        self._user.step_progress()
         #####################
         #ok, everyone is now ready to print on the canvas.  Paginate?
         self.canvas.paginate(colsperpage, one_page)
@@ -779,7 +779,9 @@ class AncestorTree(Report):
         #lets finally make some pages!!!
         #####################
         pages = self.canvas.page_count(incblank)
-        self.progress.set_pass(_('Printing the Tree...'), pages)
+        self._user.end_progress()
+        self._user.begin_progress( _('Ancestor Tree'), 
+                                   _('Printing the Tree...'), pages)
 
         for page in self.canvas.page_iter_gen(incblank):
 
@@ -796,10 +798,10 @@ class AncestorTree(Report):
             #Print the individual people and lines
             page.display()
                     
-            self.progress.step()
+            self._user.step_progress()
             self.doc.end_page()
 
-        self.progress.close()
+        self._user.end_progress()
         
 
     def scale_styles(self, scale):
