@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Calendar.py 16707 2011-02-23 23:39:11Z dsblank $
+# $Id: Calendar.py 18651 2011-12-24 19:08:19Z paul-franklin $
 #
 #------------------------------------------------------------------------
 #
@@ -45,10 +45,9 @@ from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
 from gen.plug.docgen.fontscale import string_trim
 from gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
                          EnumeratedListOption, FilterOption, PersonOption)
-from gui.utils import ProgressMeter
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from Utils import probably_alive
 from DateHandler import displayer as _dd
 import GrampsLocale
@@ -74,9 +73,10 @@ class Calendar(Report):
     """
     Create the Calendar object that produces the report.
     """
-    def __init__(self, database, options_class):
-        Report.__init__(self, database, options_class)
-        menu = options_class.menu
+    def __init__(self, database, options, user):
+        Report.__init__(self, database, options, user)
+        menu = options.menu
+        self._user = user
         get_value = lambda name: menu.get_option_by_name(name).get_value()
         
         self.year = get_value('year')
@@ -154,7 +154,6 @@ class Calendar(Report):
     def write_report(self):
         """ The short method that runs through each month and creates a page. """
         # initialize the dict to fill:
-        self.progress = ProgressMeter(_('Calendar Report'))
         self.calendar = {}
         
         # get the information, first from holidays:
@@ -164,11 +163,12 @@ class Calendar(Report):
         # get data from database:
         self.collect_data()
         # generate the report:
-        self.progress.set_pass(_('Formatting months...'), 12)
+        self._user.begin_progress( _('Calendar Report'), 
+                                   _('Formatting months...'), 12)
         for month in range(1, 13):
-            self.progress.step()
+            self._user.step_progress()
             self.print_page(month)
-        self.progress.close()
+        self._user.end_progress()
 
     def print_page(self, month):
         """
@@ -261,13 +261,18 @@ class Calendar(Report):
         """
         db = self.database
         people = db.iter_person_handles()
-        self.progress.set_pass(_('Applying Filter...'), db.get_number_of_people())
-        people = self.filter.apply(self.database, people, self.progress)
+        self._user.begin_progress(_('Calendar Report'), 
+                                  _('Applying Filter...'), 
+                                  db.get_number_of_people())
+        people = self.filter.apply(self.database, people, 
+                                   self._user.step_progress)
         rel_calc = Relationship.get_relationship_calculator()
+        self._user.end_progress()
 
-        self.progress.set_pass(_('Reading database...'), len(people))
+        self._user.begin_progress(_('Calendar Report'), 
+                                 _('Reading database...'), len(people))
         for person_handle in people:
-            self.progress.step()
+            self._user.step_progress()
             person = db.get_person_from_handle(person_handle)
             birth_ref = person.get_birth_ref()
             birth_date = None
@@ -332,7 +337,7 @@ class Calendar(Report):
                         if spouse:
                             spouse_name = self.get_name(spouse)
                             short_name = self.get_name(person)
-                            # TEMP: this will hanlde ordered events
+                            # TEMP: this will handle ordered events
                             # GRAMPS 3.0 will have a new mechanism for start/stop events
                             are_married = None
                             for event_ref in fam.get_event_ref_list():
@@ -381,6 +386,7 @@ class Calendar(Report):
                                                     prob_alive_date)
                                         if ((self.alive and alive1 and alive2) or not self.alive):
                                             self.add_day_item(text, month, day)
+        self._user.end_progress()
 
 #------------------------------------------------------------------------
 #
