@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FanChart.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: FanChart.py 18651 2011-12-24 19:08:19Z paul-franklin $
 
 #------------------------------------------------------------------------
 #
@@ -47,7 +47,7 @@ from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
 from gen.plug.menu import EnumeratedListOption, NumberOption, PersonOption
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 import config
 
 #------------------------------------------------------------------------
@@ -135,15 +135,15 @@ def draw_wedge(doc,  style,  centerx,  centery,  radius,  start_angle,
 #------------------------------------------------------------------------
 class FanChart(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the FanChart object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        person          - currently selected person
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
@@ -154,7 +154,7 @@ class FanChart(Report):
         radial          - Print radial texts roundabout or as upright as possible.
         """
 
-        menu = options_class.menu
+        menu = options.menu
         self.max_generations = menu.get_option_by_name('maxgen').get_value()
         self.circle          = menu.get_option_by_name('circle').get_value()
         self.background      = menu.get_option_by_name('background').get_value()
@@ -177,7 +177,7 @@ class FanChart(Report):
         
         self.calendar = 0
 
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
 
         self.height = 0
         self.map = [None] * 2**self.max_generations
@@ -240,7 +240,7 @@ class FanChart(Report):
                 fontsize = pt2cm(style_sheet.get_paragraph_style('FC-Title').get_font().get_size())
                 # y is vertical distance to center of circle, move center down 1 fontsize
                 y += fontsize
-                # min_XY is the diamter of the circle, subtract two fontsize
+                # min_XY is the diameter of the circle, subtract two fontsize
                 # so we dont draw outside bottom of the paper
                 min_xy = min(min_xy,y-2*fontsize)
         if self.max_generations > max_circular:
