@@ -7,6 +7,7 @@
 # Copyright (C) 2008       Robert Cheramy <robert@cheramy.net>
 # Copyright (C) 2010       Jakim Friant
 # Copyright (C) 2010       Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGedcom.py 18754 2012-01-19 09:01:47Z romjerome $
+# $Id: ExportGedcom.py 19053 2012-03-13 17:09:08Z kulath $
 
 "Export to GEDCOM"
 
@@ -109,10 +110,10 @@ MIME2GED = {
     }
 
 QUALITY_MAP = {
-    gen.lib.SourceRef.CONF_VERY_HIGH : "3", 
-    gen.lib.SourceRef.CONF_HIGH      : "2", 
-    gen.lib.SourceRef.CONF_LOW       : "1", 
-    gen.lib.SourceRef.CONF_VERY_LOW  : "0", 
+    gen.lib.Citation.CONF_VERY_HIGH : "3", 
+    gen.lib.Citation.CONF_HIGH      : "2", 
+    gen.lib.Citation.CONF_LOW       : "1", 
+    gen.lib.Citation.CONF_VERY_LOW  : "0", 
     }
 
 #-------------------------------------------------------------------------
@@ -194,7 +195,7 @@ def event_has_subordinate_data(event, event_ref):
                 event.get_attribute_list() or
                 event_ref.get_attribute_list() or
                 event.get_note_list() or
-                event.get_source_references() or
+                event.get_citation_list() or
                 event.get_media_list())
     else:
         return False
@@ -488,7 +489,7 @@ class GedcomWriter(UpdateCallback):
                 self.__writeln(level, "ASSO", "@%s@" % person.get_gramps_id())
                 self.__writeln(level+1, "RELA", ref.get_relation())
                 self.__note_references(ref.get_note_list(), level+1)
-                self.__source_references(ref.get_source_references(), level+1)
+                self.__source_references(ref.get_citation_list(), level+1)
 
     def __note_references(self, notelist, level):
         """
@@ -569,7 +570,7 @@ class GedcomWriter(UpdateCallback):
             if role != gen.lib.EventRoleType.PRIMARY:
                 continue
                 
-            val = libgedcom.personalConstantEvents.get(etype, "").strip()
+            val = libgedcom.PERSONALCONSTANTEVENTS.get(etype, "").strip()
                         
             if val and val.strip():
                 if val in NEEDS_PARAMETER:
@@ -649,7 +650,7 @@ class GedcomWriter(UpdateCallback):
         for attr in attr_list:
 
             attr_type = int(attr.get_type())
-            name = libgedcom.personalConstantAttributes.get(attr_type)
+            name = libgedcom.PERSONALCONSTANTATTRIBUTES.get(attr_type)
             key = str(attr.get_type())
             value = attr.get_value().strip().replace('\r', ' ')
             
@@ -669,15 +670,15 @@ class GedcomWriter(UpdateCallback):
             else:
                 continue
             self.__note_references(attr.get_note_list(), 2)
-            self.__source_references(attr.get_source_references(), 2)
+            self.__source_references(attr.get_citation_list(), 2)
 
-    def __source_references(self, ref_list, level):
+    def __source_references(self, citation_list, level):
         """
-        Loop through the list of source references, writing the information
+        Loop through the list of citation handles, writing the information
         to the file.
         """
-        for srcref in ref_list:
-            self.__source_ref_record(level, srcref)
+        for citation_handle in citation_list:
+            self.__source_ref_record(level, citation_handle)
 
     def __addresses(self, person):
         """
@@ -703,7 +704,7 @@ class GedcomWriter(UpdateCallback):
                 self.__writeln(2, 'PHON', addr.get_phone())
 
             self.__note_references(addr.get_note_list(), 2)
-            self.__source_references(addr.get_source_references(), 2)
+            self.__source_references(addr.get_citation_list(), 2)
 
     def __photos(self, media_list, level):
         """
@@ -743,11 +744,11 @@ class GedcomWriter(UpdateCallback):
 
     def __person_sources(self, person):
         """
-        Loop through the list of source references, writing the information
+        Loop through the list of citations, writing the information
         to the file.
         """
-        for srcref in person.get_source_references():
-            self.__source_ref_record(1, srcref)
+        for citation_handle in person.get_citation_list():
+            self.__source_ref_record(1, citation_handle)
 
     def __url_list(self, obj, level):
         """
@@ -809,7 +810,7 @@ class GedcomWriter(UpdateCallback):
         self.__family_events(family)
         self.__family_attributes(family.get_attribute_list(), 1)
         self.__family_child_list(family.get_child_ref_list())
-        self.__source_references(family.get_source_references(), 1)
+        self.__source_references(family.get_citation_list(), 1)
         self.__photos(family.get_media_list(), 1)
         self.__note_references(family.get_note_list(), 1)
         self.__change(family.get_change_time(), 1)
@@ -851,7 +852,7 @@ class GedcomWriter(UpdateCallback):
             event = self.dbase.get_event_from_handle(event_ref.ref)
             if event is None: continue
             etype = int(event.get_type())
-            val = libgedcom.familyConstantEvents.get(etype)
+            val = libgedcom.FAMILYCONSTANTEVENTS.get(etype)
             
             if val:
                 if event_has_subordinate_data(event, event_ref):
@@ -906,7 +907,7 @@ class GedcomWriter(UpdateCallback):
         for attr in attr_list:
             
             attr_type = int(attr.get_type())
-            name = libgedcom.familyConstantAttributes.get(attr_type)
+            name = libgedcom.FAMILYCONSTANTATTRIBUTES.get(attr_type)
             value = attr.get_value().replace('\r', ' ')
 
             if attr_type in ("AFN", "RFN", "REFN", "_UID"):
@@ -921,7 +922,7 @@ class GedcomWriter(UpdateCallback):
                 self.__writeln(2, 'TYPE', str(attr.get_type()))
 
             self.__note_references(attr.get_note_list(), level+1)
-            self.__source_references(attr.get_source_references(), 
+            self.__source_references(attr.get_citation_list(), 
                                      level+1)
 
     def __sources(self):
@@ -1137,7 +1138,7 @@ class GedcomWriter(UpdateCallback):
                 self.__writeln(3, 'AGE', attr.get_value())
 
         self.__note_references(event.get_note_list(), 2)
-        self.__source_references(event.get_source_references(), 2)
+        self.__source_references(event.get_citation_list(), 2)
 
         self.__photos(event.get_media_list(), 2)
         if place:
@@ -1193,7 +1194,7 @@ class GedcomWriter(UpdateCallback):
             self.__writeln(2, 'STAT', LDS_STATUS[lds_ord.get_status()])
         
         self.__note_references(lds_ord.get_note_list(), index+1)
-        self.__source_references(lds_ord.get_source_references(), index+1)
+        self.__source_references(lds_ord.get_citation_list(), index+1)
 
     def __date(self, level, date):
         """
@@ -1256,6 +1257,14 @@ class GedcomWriter(UpdateCallback):
             nick = attr_nick
 
         self.__writeln(1, 'NAME', gedcom_name)
+        if int(name.get_type()) == gen.lib.NameType.BIRTH:
+            pass
+        elif int(name.get_type()) == gen.lib.NameType.MARRIED:
+            self.__writeln(2, 'TYPE', 'married')
+        elif int(name.get_type()) == gen.lib.NameType.AKA:
+            self.__writeln(2, 'TYPE', 'aka')
+        else:
+            self.__writeln(2, 'TYPE', name.get_type().xml_str())
 
         if firstname:
             self.__writeln(2, 'GIVN', firstname)
@@ -1270,10 +1279,10 @@ class GedcomWriter(UpdateCallback):
         if nick:
             self.__writeln(2, 'NICK', nick)
 
-        self.__source_references(name.get_source_references(), 2)
+        self.__source_references(name.get_citation_list(), 2)
         self.__note_references(name.get_note_list(), 2)
 
-    def __source_ref_record(self, level, ref):
+    def __source_ref_record(self, level, citation_handle):
         """
         n SOUR @<XREF:SOUR>@ /* pointer to source record */ {1:1} 
         +1 PAGE <WHERE_WITHIN_SOURCE> {0:1} 
@@ -1288,7 +1297,9 @@ class GedcomWriter(UpdateCallback):
         +1 <<NOTE_STRUCTURE>> {0:M} 
         """
 
-        src_handle = ref.get_reference_handle()
+        citation = self.dbase.get_citation_from_handle(citation_handle)
+                
+        src_handle = citation.get_reference_handle()
         if src_handle is None:
             return
 
@@ -1298,25 +1309,27 @@ class GedcomWriter(UpdateCallback):
 
         # Reference to the source
         self.__writeln(level, "SOUR", "@%s@" % src.get_gramps_id())
-        if ref.get_page() != "":
+        if citation.get_page() != "":
         # PAGE <WHERE_WITHIN_SOURCE> can not have CONC lines.
         # WHERE_WITHIN_SOURCE:= {Size=1:248}
         # Maximize line to 248 and set limit to 248, for no line split
-            self.__writeln(level+1, 'PAGE', ref.get_page()[0:248], limit=248)
+            self.__writeln(level+1, 'PAGE', citation.get_page()[0:248], 
+                           limit=248)
 
 
-        conf = min(ref.get_confidence_level(), gen.lib.SourceRef.CONF_VERY_HIGH)
-        if conf != gen.lib.SourceRef.CONF_NORMAL and conf != -1:
+        conf = min(citation.get_confidence_level(), 
+                   gen.lib.Citation.CONF_VERY_HIGH)
+        if conf != gen.lib.Citation.CONF_NORMAL and conf != -1:
             self.__writeln(level+1, "QUAY", QUALITY_MAP[conf])
 
-        if not ref.get_date_object().is_empty():
+        if not citation.get_date_object().is_empty():
             self.__writeln(level+1, 'DATA')
-            self.__date(level+2, ref.get_date_object())
+            self.__date(level+2, citation.get_date_object())
 
-        if len(ref.get_note_list()) > 0:
+        if len(citation.get_note_list()) > 0:
 
             note_list = [ self.dbase.get_note_from_handle(h) 
-                          for h in ref.get_note_list() ]
+                          for h in citation.get_note_list() ]
             note_list = [ n for n in note_list 
                           if n.get_type() == gen.lib.NoteType.SOURCE_TEXT]
 
@@ -1325,16 +1338,24 @@ class GedcomWriter(UpdateCallback):
             else:
                 ref_text = ""
 
-            if ref_text != "" and ref.get_date_object().is_empty():
+            if ref_text != "" and citation.get_date_object().is_empty():
                 self.__writeln(level+1, 'DATA')
             if ref_text != "":
                 self.__writeln(level+2, "TEXT", ref_text)
 
             note_list = [ self.dbase.get_note_from_handle(h) 
-                          for h in ref.get_note_list() ]
+                          for h in citation.get_note_list() ]
             note_list = [ n.handle for n in note_list 
                           if n and n.get_type() != gen.lib.NoteType.SOURCE_TEXT]
             self.__note_references(note_list, level+1)
+            self.__photos(citation.get_media_list(), level+1)
+            
+        if "EVEN" in citation.get_data_map().keys():
+            self.__writeln(level+1, "EVEN", citation.get_data_map()["EVEN"])
+            if "EVEN:ROLE" in citation.get_data_map().keys():
+                self.__writeln(level+2, "ROLE", 
+                               citation.get_data_map()["EVEN:ROLE"])
+                
 
     def __photo(self, photo, level):
         """
