@@ -1,6 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2011 Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Gallery.py 18678 2012-01-01 17:57:42Z nick-h $
+# $Id: Gallery.py 18679 2012-01-01 17:58:33Z nick-h $
 #
 
 from gen.plug import Gramplet
@@ -61,7 +62,7 @@ class Gallery(Gramplet):
             full_path = Utils.media_path_full(self.dbstate.db, media.get_path())
             mime_type = media.get_mime_type()
             if mime_type and mime_type.startswith("image"):
-                photo = Photo()
+                photo = Photo(self.uistate.screen_height() < 1000)
                 photo.set_image(full_path, mime_type, media_ref.get_rectangle())
                 self.image_list.append(photo)
                 self.top.pack_start(photo, expand=False, fill=False)
@@ -201,3 +202,26 @@ class SourceGallery(Gallery):
         else:
             self.set_has_data(False)
 
+class CitationGallery(Gallery):
+    """
+    Displays a gallery of media objects for a Citation.
+    """
+    def db_changed(self):
+        self.dbstate.db.connect('event-update', self.update)
+        self.connect_signal('Citation', self.update)
+
+    def update_has_data(self):
+        active_handle = self.get_active('Citation')
+        active = self.dbstate.db.get_citation_from_handle(active_handle)
+        self.set_has_data(self.get_has_data(active))
+
+    def main(self):
+        active_handle = self.get_active('Citation')
+        active = self.dbstate.db.get_citation_from_handle(active_handle)
+        
+        self.clear_images()
+        if active:
+            self.load_images(active)
+        else:
+            self.set_has_data(False)
+
