@@ -1,6 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2011 Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Notes.py 18678 2012-01-01 17:57:42Z nick-h $
+# $Id: Notes.py 18679 2012-01-01 17:58:33Z nick-h $
 #
 
 from gen.plug import Gramplet
@@ -243,6 +244,28 @@ class SourceNotes(Notes):
             self.clear_text()
             self.set_has_data(False)
 
+class CitationNotes(Notes):
+    """
+    Displays the notes for a Citation.
+    """
+    def db_changed(self):
+        self.dbstate.db.connect('citation-update', self.update)
+        self.connect_signal('Citation', self.update)
+
+    def update_has_data(self):
+        active_handle = self.get_active('Citation')
+        active = self.dbstate.db.get_citation_from_handle(active_handle)
+        self.set_has_data(self.get_has_data(active))
+    
+    def main(self):
+        active_handle = self.get_active('Citation')
+        active = self.dbstate.db.get_citation_from_handle(active_handle)
+        if active:
+            self.get_notes(active)
+        else:
+            self.clear_text()
+            self.set_has_data(False)
+
 class RepositoryNotes(Notes):
     """
     Displays the notes for a repository.
