@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: PedigreeGramplet.py 15215 2010-04-18 13:42:46Z dsblank $
+# $Id: PedigreeGramplet.py 18511 2011-11-26 17:35:04Z dsblank $
 
 #------------------------------------------------------------------------
 #
@@ -240,10 +240,10 @@ class PedigreeGramplet(Gramplet):
         self.gui.buffer.set_text("")
         active_handle = self.get_active('Person')
         active_person = self.dbstate.db.get_person_from_handle(active_handle)
-        if not active_person:
-            yield False
         #no wrap in Gramplet
         self.no_wrap()
+        if active_person is None:
+            return
         self.process_person(active_person.handle, 1, "f") # father
         self.process_person(active_person.handle, 0, "a") # active #FIXME: should be 1?
         self.process_person(active_person.handle, 1, "m") # mother
