@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: PersonDetails.py 18678 2012-01-01 17:57:42Z nick-h $
+# $Id: PersonDetails.py 18679 2012-01-01 17:58:33Z nick-h $
 #
 
 from gen.lib import EventType, EventRoleType
@@ -45,7 +45,7 @@ class PersonDetails(Gramplet):
         """
         self.top = gtk.HBox()
         vbox = gtk.VBox()
-        self.photo = Photo()
+        self.photo = Photo(self.uistate.screen_height() < 1000)
         self.photo.show()
         self.name = gtk.Label()
         self.name.set_alignment(0, 0)
