@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2011 Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: bottombar.gpr.py 17446 2011-05-07 18:41:14Z nick-h $
+# $Id: bottombar.gpr.py 18548 2011-12-04 17:09:17Z kulath $
 
 #------------------------------------------------------------------------
 #
@@ -30,7 +31,7 @@ register(GRAMPLET,
          name=_("Person Details"), 
          description = _("Gramplet showing details of a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="PersonDetails.py",
          height=200,
@@ -44,7 +45,7 @@ register(GRAMPLET,
          name=_("Repository Details"), 
          description = _("Gramplet showing details of a repository"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="RepositoryDetails.py",
          height=200,
@@ -58,7 +59,7 @@ register(GRAMPLET,
          name=_("Place Details"), 
          description = _("Gramplet showing details of a place"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="PlaceDetails.py",
          height=200,
@@ -72,7 +73,7 @@ register(GRAMPLET,
          name=_("Media Preview"), 
          description = _("Gramplet showing a preview of a media object"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="MediaPreview.py",
          height=200,
@@ -96,7 +97,7 @@ if available:
             name = _("Metadata Viewer"), 
             description = _("Gramplet showing metadata for a media object"),
             version = "1.0.0",
-            gramps_target_version = "3.3",
+            gramps_target_version = "3.4",
             status = STABLE,
             fname = "MetadataViewer.py",
             height = 200,
@@ -110,7 +111,7 @@ register(GRAMPLET,
          name=_("Person Residence"), 
          description = _("Gramplet showing residence events for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="PersonResidence.py",
          height=200,
@@ -124,7 +125,7 @@ register(GRAMPLET,
          name=_("Person Events"), 
          description = _("Gramplet showing the events for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Events.py",
          height=200,
@@ -138,7 +139,7 @@ register(GRAMPLET,
          name=_("Family Events"), 
          description = _("Gramplet showing the events for a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Events.py",
          height=200,
@@ -152,7 +153,7 @@ register(GRAMPLET,
          name=_("Person Gallery"), 
          description = _("Gramplet showing media objects for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Gallery.py",
          height=200,
@@ -166,7 +167,7 @@ register(GRAMPLET,
          name=_("Family Gallery"), 
          description = _("Gramplet showing media objects for a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Gallery.py",
          height=200,
@@ -180,7 +181,7 @@ register(GRAMPLET,
          name=_("Event Gallery"), 
          description = _("Gramplet showing media objects for an event"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Gallery.py",
          height=200,
@@ -194,7 +195,7 @@ register(GRAMPLET,
          name=_("Place Gallery"), 
          description = _("Gramplet showing media objects for a place"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Gallery.py",
          height=200,
@@ -208,7 +209,7 @@ register(GRAMPLET,
          name=_("Source Gallery"), 
          description = _("Gramplet showing media objects for a source"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Gallery.py",
          height=200,
@@ -217,12 +218,26 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
+register(GRAMPLET, 
+         id="Citation Gallery", 
+         name=_("Citation Gallery"), 
+         description = _("Gramplet showing media objects for a citation"),
+         version="1.0.0",
+         gramps_target_version="3.4",
+         status = STABLE,
+         fname="Gallery.py",
+         height=200,
+         gramplet = 'CitationGallery',
+         gramplet_title=_("Gallery"),
+         navtypes=["Citation"],
+         )
+
 register(GRAMPLET, 
          id="Person Attributes", 
          name=_("Person Attributes"), 
          description = _("Gramplet showing the attributes of a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Attributes.py",
          height=200,
@@ -236,7 +251,7 @@ register(GRAMPLET,
          name=_("Event Attributes"), 
          description = _("Gramplet showing the attributes of an event"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Attributes.py",
          height=200,
@@ -250,7 +265,7 @@ register(GRAMPLET,
          name=_("Family Attributes"), 
          description = _("Gramplet showing the attributes of a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Attributes.py",
          height=200,
@@ -264,7 +279,7 @@ register(GRAMPLET,
          name=_("Media Attributes"), 
          description = _("Gramplet showing the attributes of a media object"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Attributes.py",
          height=200,
@@ -278,7 +293,7 @@ register(GRAMPLET,
          name=_("Person Notes"), 
          description = _("Gramplet showing the notes for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -292,7 +307,7 @@ register(GRAMPLET,
          name=_("Event Notes"), 
          description = _("Gramplet showing the notes for an event"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -306,7 +321,7 @@ register(GRAMPLET,
          name=_("Family Notes"), 
          description = _("Gramplet showing the notes for a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -320,7 +335,7 @@ register(GRAMPLET,
          name=_("Place Notes"), 
          description = _("Gramplet showing the notes for a place"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -334,7 +349,7 @@ register(GRAMPLET,
          name=_("Source Notes"), 
          description = _("Gramplet showing the notes for a source"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -343,12 +358,26 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
+register(GRAMPLET, 
+         id="Citation Notes", 
+         name=_("Citation Notes"), 
+         description = _("Gramplet showing the notes for a citation"),
+         version="1.0.0",
+         gramps_target_version="3.4",
+         status = STABLE,
+         fname="Notes.py",
+         height=200,
+         gramplet = 'CitationNotes',
+         gramplet_title=_("Notes"),
+         navtypes=["Citation"],
+         )
+
 register(GRAMPLET, 
          id="Repository Notes", 
          name=_("Repository Notes"), 
          description = _("Gramplet showing the notes for a repository"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -362,7 +391,7 @@ register(GRAMPLET,
          name=_("Media Notes"), 
          description = _("Gramplet showing the notes for a media object"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Notes.py",
          height=200,
@@ -372,72 +401,72 @@ register(GRAMPLET,
          )
 
 register(GRAMPLET, 
-         id="Person Sources", 
-         name=_("Person Sources"), 
-         description = _("Gramplet showing the sources for a person"),
+         id="Person Citations", 
+         name=_("Person Citations"), 
+         description = _("Gramplet showing the citations for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
-         fname="Sources.py",
+         fname="Citations.py",
          height=200,
-         gramplet = 'PersonSources',
-         gramplet_title=_("Sources"),
+         gramplet = 'PersonCitations',
+         gramplet_title=_("Citations"),
          navtypes=["Person"],
          )
 
 register(GRAMPLET, 
-         id="Event Sources", 
-         name=_("Event Sources"), 
-         description = _("Gramplet showing the sources for an event"),
+         id="Event Citations", 
+         name=_("Event Citations"), 
+         description = _("Gramplet showing the citations for an event"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
-         fname="Sources.py",
+         fname="Citations.py",
          height=200,
-         gramplet = 'EventSources',
-         gramplet_title=_("Sources"),
+         gramplet = 'EventCitations',
+         gramplet_title=_("Citations"),
          navtypes=["Event"],
          )
 
 register(GRAMPLET, 
-         id="Family Sources", 
-         name=_("Family Sources"), 
-         description = _("Gramplet showing the sources for a family"),
+         id="Family Citations", 
+         name=_("Family Citations"), 
+         description = _("Gramplet showing the citations for a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
-         fname="Sources.py",
+         fname="Citations.py",
          height=200,
-         gramplet = 'FamilySources',
-         gramplet_title=_("Sources"),
+         gramplet = 'FamilyCitations',
+         gramplet_title=_("Citations"),
          navtypes=["Family"],
          )
 
 register(GRAMPLET, 
-         id="Place Sources", 
-         name=_("Place Sources"), 
-         description = _("Gramplet showing the sources for a place"),
+         id="Place Citations", 
+         name=_("Place Citations"), 
+         description = _("Gramplet showing the citations for a place"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
-         fname="Sources.py",
+         fname="Citations.py",
          height=200,
-         gramplet = 'PlaceSources',
-         gramplet_title=_("Sources"),
+         gramplet = 'PlaceCitations',
+         gramplet_title=_("Citations"),
          navtypes=["Place"],
          )
 
 register(GRAMPLET, 
-         id="Media Sources", 
-         name=_("Media Sources"), 
-         description = _("Gramplet showing the sources for a media object"),
+         id="Media Citations", 
+         name=_("Media Citations"), 
+         description = _("Gramplet showing the citations for a media object"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
-         fname="Sources.py",
+         fname="Citations.py",
          height=200,
-         gramplet = 'MediaSources',
-         gramplet_title=_("Sources"),
+         gramplet = 'MediaCitations',
+         gramplet_title=_("Citations"),
          navtypes=["Media"],
          )
 
@@ -446,7 +475,7 @@ register(GRAMPLET,
          name=_("Person Children"), 
          description = _("Gramplet showing the children of a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Children.py",
          height=200,
@@ -460,7 +489,7 @@ register(GRAMPLET,
          name=_("Family Children"), 
          description = _("Gramplet showing the children of a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Children.py",
          height=200,
@@ -474,7 +503,7 @@ register(GRAMPLET,
          name=_("Person Backlinks"), 
          description = _("Gramplet showing the backlinks for a person"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -488,7 +517,7 @@ register(GRAMPLET,
          name=_("Event Backlinks"), 
          description = _("Gramplet showing the backlinks for an event"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -502,7 +531,7 @@ register(GRAMPLET,
          name=_("Family Backlinks"), 
          description = _("Gramplet showing the backlinks for a family"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -516,7 +545,7 @@ register(GRAMPLET,
          name=_("Place Backlinks"), 
          description = _("Gramplet showing the backlinks for a place"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -530,7 +559,7 @@ register(GRAMPLET,
          name=_("Source Backlinks"), 
          description = _("Gramplet showing the backlinks for a source"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -539,12 +568,26 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
+register(GRAMPLET, 
+         id="Citation Backlinks", 
+         name=_("Citation Backlinks"), 
+         description = _("Gramplet showing the backlinks for a citation"),
+         version="1.0.0",
+         gramps_target_version="3.4",
+         status = STABLE,
+         fname="Backlinks.py",
+         height=200,
+         gramplet = 'CitationBacklinks',
+         gramplet_title=_("References"),
+         navtypes=["Citation"],
+         )
+
 register(GRAMPLET, 
          id="Repository Backlinks", 
          name=_("Repository Backlinks"), 
          description = _("Gramplet showing the backlinks for a repository"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -558,7 +601,7 @@ register(GRAMPLET,
          name=_("Media Backlinks"), 
          description = _("Gramplet showing the backlinks for a media object"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -572,7 +615,7 @@ register(GRAMPLET,
          name=_("Note Backlinks"), 
          description = _("Gramplet showing the backlinks for a note"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Backlinks.py",
          height=200,
@@ -586,7 +629,7 @@ register(GRAMPLET,
          name=_("Person Filter"), 
          description = _("Gramplet providing a person filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -600,7 +643,7 @@ register(GRAMPLET,
          name=_("Family Filter"), 
          description = _("Gramplet providing a family filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -614,7 +657,7 @@ register(GRAMPLET,
          name=_("Event Filter"), 
          description = _("Gramplet providing an event filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -628,7 +671,7 @@ register(GRAMPLET,
          name=_("Source Filter"), 
          description = _("Gramplet providing a source filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -637,12 +680,26 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
+register(GRAMPLET, 
+         id="Citation Filter", 
+         name=_("Citation Filter"), 
+         description = _("Gramplet providing a citation filter"),
+         version="1.0.0",
+         gramps_target_version="3.4",
+         status = STABLE,
+         fname="Filter.py",
+         height=200,
+         gramplet = 'CitationFilter',
+         gramplet_title=_("Filter"),
+         navtypes=["Citation"],
+         )
+
 register(GRAMPLET, 
          id="Place Filter", 
          name=_("Place Filter"), 
          description = _("Gramplet providing a place filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -656,7 +713,7 @@ register(GRAMPLET,
          name=_("Media Filter"), 
          description = _("Gramplet providing a media filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -670,7 +727,7 @@ register(GRAMPLET,
          name=_("Repository Filter"), 
          description = _("Gramplet providing a repository filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
@@ -684,7 +741,7 @@ register(GRAMPLET,
          name=_("Note Filter"), 
          description = _("Gramplet providing a note filter"),
          version="1.0.0",
-         gramps_target_version="3.3",
+         gramps_target_version="3.4",
          status = STABLE,
          fname="Filter.py",
          height=200,
