@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:_ReadGedcom.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: ImportGedcom.py 18850 2012-02-10 20:14:14Z kulath $
 
 "Import from GEDCOM"
 
@@ -47,13 +48,10 @@ from QuestionDialog import ErrorDialog, DBErrorDialog
 from glade import Glade
 from libmixin import DbMixin
 import libgedcom
+module = __import__("libgedcom")
+reload (module)
 
-try:
-    import config
-    DEFAULT_SOURCE = config.get('preferences.default-source')
-except ImportError:
-    LOG.warn("No Config module available using defaults.")
-    DEFAULT_SOURCE = False
+import config
     
 #-------------------------------------------------------------------------
 #
@@ -108,8 +106,9 @@ def importData(database, filename, callback=None):
         if code_set:
             stage_one.set_encoding(code_set)
         ifile.seek(0)
-        gedparse = libgedcom.GedcomParser(database, ifile, filename, callback, 
-                                          stage_one, DEFAULT_SOURCE)
+        gedparse = libgedcom.GedcomParser(
+                            database, ifile, filename, callback, stage_one, 
+                            config.get('preferences.default-source'))
     except IOError, msg:
         ErrorDialog(_("%s could not be opened\n") % filename, str(msg))
         return
