@@ -5,7 +5,8 @@
 # Copyright (C) 2009  Benny Malengier
 # Copyright (C) 2009  Brian Matherly
 # Copyright (C) 2010  Peter Landgren
-# Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2010  Jakim Friant
+# Copyright (C) 2011  Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libcairodoc.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: libcairodoc.py 18870 2012-02-12 21:55:07Z nick-h $
 
 """Report output generator based on Cairo.
 """
@@ -34,6 +35,7 @@
 #------------------------------------------------------------------------
 from gen.ggettext import gettext as _
 from math import radians
+import re
 
 #------------------------------------------------------------------------
 #
@@ -46,6 +48,7 @@ from gen.plug.docgen import (BaseDoc, TextDoc, DrawDoc, ParagraphStyle,
 from gen.plug.report import utils as ReportUtils
 from Errors import PluginError
 from gen.plug.docbackend import CairoBackend
+import ImgManip
 
 #------------------------------------------------------------------------
 #
@@ -60,9 +63,7 @@ log = logging.getLogger(".libcairodoc")
 # GTK modules
 #
 #-------------------------------------------------------------------------
-import gtk
 import pango
-import pangocairo
 
 #------------------------------------------------------------------------
 #
@@ -101,6 +102,7 @@ font_families = _GNOME_FONT
 
 # FIXME debug logging does not work here.
 def set_font_families():
+    import pangocairo
 ##def set_font_families(pango_context):
     """Set the used font families depending on availability.
     """
@@ -173,6 +175,18 @@ def tabstops_to_tabarray(tab_stops, dpi):
         
     return tab_array
 
+def raw_length(s):
+    """
+    Return the length of the raw string after all pango markup has been removed.
+    """
+    s = re.sub('<.*?>', '', s)
+    s = s.replace('&amp;', '&')
+    s = s.replace('&lt;', '<')
+    s = s.replace('&gt;', '>')
+    s = s.replace('&quot;', '"')
+    s = s.replace('&apos;', "'")
+    return len(s)
+
 ###------------------------------------------------------------------------
 ###
 ### Table row style
@@ -264,12 +278,12 @@ class GtkDocBaseElement(object):
     Support document element structuring and can render itself onto
     a Cairo surface.
     
-    There are two cathegories of methods:
+    There are two categories of methods:
       1. hierarchy building methods (add_child, get_children, set_parent,
          get_parent);
       2. rendering methods (divide, draw).
       
-    The hierarchy building methods generally don't have to be overriden in
+    The hierarchy building methods generally don't have to be overridden in
     the subclass, while the rendering methods (divide, draw) must be
     implemented in the subclasses.
     
@@ -310,7 +324,7 @@ class GtkDocBaseElement(object):
                       (element.__class__, self.__class__))
             return False
         
-        # append the child and set it's parent
+        # append the child and set its parent
         self._children.append(element)
         element.set_parent(self)
         return True
@@ -320,6 +334,14 @@ class GtkDocBaseElement(object):
         """
         return self._children
     
+    def get_marks(self):
+        """Get the list of index marks for this element.
+        """
+        marks = []
+        for child in self._children:
+            marks.extend(child.get_marks())
+        return marks
+
     def divide(self, layout, width, height, dpi_x, dpi_y):
         """Divide the element into two depending on available space.
         
@@ -364,7 +386,8 @@ class GtkDocDocument(GtkDocBaseElement):
     """The whole document or a page.
     """
     _type = 'DOCUMENT'
-    _allowed_children = ['PARAGRAPH', 'PAGEBREAK', 'TABLE', 'IMAGE', 'FRAME']
+    _allowed_children = ['PARAGRAPH', 'PAGEBREAK', 'TABLE', 'IMAGE', 'FRAME',
+                         'TOC', 'INDEX']
     
     def draw(self, cairo_context, pango_layout, width, dpi_x, dpi_y):
             
@@ -377,7 +400,19 @@ class GtkDocDocument(GtkDocBaseElement):
             y += elem_height
             
         return y
-    
+
+    def has_toc(self):
+        for elem in self._children:
+            if elem.get_type() == 'TOC':
+                return True
+        return False
+
+    def has_index(self):
+        for elem in self._children:
+            if elem.get_type() == 'INDEX':
+                return True
+        return False
+
 class GtkDocPagebreak(GtkDocBaseElement):
     """Implement a page break.
     """
@@ -387,6 +422,30 @@ class GtkDocPagebreak(GtkDocBaseElement):
     def divide(self, layout, width, height, dpi_x, dpi_y):
         return (None, None), 0
     
+class GtkDocTableOfContents(GtkDocBaseElement):
+    """Implement a table of contents.
+    """
+    _type = 'TOC'
+    _allowed_children = []
+    
+    def divide(self, layout, width, height, dpi_x, dpi_y):
+        return (self, None), 0
+
+    def draw(self, cr, layout, width, dpi_x, dpi_y):
+        return 0
+
+class GtkDocAlphabeticalIndex(GtkDocBaseElement):
+    """Implement an alphabetical index.
+    """
+    _type = 'INDEX'
+    _allowed_children = []
+    
+    def divide(self, layout, width, height, dpi_x, dpi_y):
+        return (self, None), 0
+
+    def draw(self, cr, layout, width, dpi_x, dpi_y):
+        return 0
+
 class GtkDocParagraph(GtkDocBaseElement):
     """Paragraph.
     """
@@ -409,12 +468,32 @@ class GtkDocParagraph(GtkDocBaseElement):
         self._plaintext = None
         self._attrlist = None
         
+        self._marklist = []
+        
     def add_text(self, text):
         if self._plaintext is not None:
             raise PluginError('CairoDoc: text is already parsed.'
                             ' You cannot add text anymore')
         self._text = self._text + text
     
+    def add_mark(self, mark):
+        """
+        Add an index mark to this paragraph
+        """
+        self._marklist.append((mark, raw_length(self._text)))
+
+    def get_marks(self):
+        """
+        Return a list of index marks for this paragraph
+        """
+        return [elem[0] for elem in self._marklist]
+
+    def __set_marklist(self, marklist):
+        """
+        Internal method to allow for splitting of paragraphs
+        """
+        self._marklist = marklist
+
     def __set_plaintext(self, plaintext):
         """
         Internal method to allow for splitting of paragraphs
@@ -561,7 +640,18 @@ class GtkDocParagraph(GtkDocBaseElement):
         # then update the first one
         self.__set_plaintext(self._plaintext.encode('utf-8')[:index])
         self._style.set_bottom_margin(0)
-        
+
+        # split the list of index marks
+        para1 = []
+        para2 = []
+        for mark, position in self._marklist:
+            if position < index:
+                para1.append((mark, position))
+            else:
+                para2.append((mark, position - index))
+        self.__set_marklist(para1)
+        new_paragraph.__set_marklist(para2)
+
         paragraph_height = endheight - startheight + spacing + t_margin + 2 * v_padding
         return (self, new_paragraph), paragraph_height
 
@@ -835,7 +925,7 @@ class GtkDocTableCell(GtkDocBaseElement):
         if cell_height <> 0:
             cell_height += 2 * v_padding
         
-        # a cell can't be divided, return the heigth
+        # a cell can't be divided, return the height
         return (self, new_cell), cell_height
     
     def draw(self, cr, layout, width, cell_height, dpi_x, dpi_y):
@@ -894,11 +984,12 @@ class GtkDocPicture(GtkDocBaseElement):
     _type = 'IMAGE'
     _allowed_children = []
     
-    def __init__(self, style, filename, width, height):
+    def __init__(self, style, filename, width, height, crop=None):
         GtkDocBaseElement.__init__(self, style)
         self._filename = filename
         self._width = width
         self._height = height
+        self._crop = crop
     
     def divide(self, layout, width, height, dpi_x, dpi_y):
         img_width = self._width * dpi_x / 2.54
@@ -912,6 +1003,7 @@ class GtkDocPicture(GtkDocBaseElement):
             return (None, self), 0
 
     def draw(self, cr, layout, width, dpi_x, dpi_y):
+        import gtk
         img_width = self._width * dpi_x / 2.54
         img_height = self._height * dpi_y / 2.54
         
@@ -923,7 +1015,9 @@ class GtkDocPicture(GtkDocBaseElement):
             l_margin = 0
         
         # load the image and get its extents
-        pixbuf = gtk.gdk.pixbuf_new_from_file(self._filename)
+        pixbuf = ImgManip.resize_to_buffer(self._filename,
+                                           [img_width, img_height],
+                                           self._crop)
         pixbuf_width = pixbuf.get_width()
         pixbuf_height = pixbuf.get_height()
         
@@ -1222,11 +1316,14 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
     # BaseDoc implementation
     
     def open(self, filename):
+        if filename[-4:] != '.pdf':
+            filename = filename + '.pdf'
         self._backend = CairoBackend(filename)
         self._doc = GtkDocDocument()
         self._active_element = self._doc
         self._pages = []
         self._elements_to_paginate = []
+        self._links_error = False
     
     def close(self):
         self.run()
@@ -1293,27 +1390,19 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
     
     def end_cell(self):
         self._active_element = self._active_element.get_parent()
-    
-    def write_endnotes_ref(self, text, style_name):
-        """
-        Overwrite base method for lines of endnotes references
-        """
-        for line in text.split('\n\n'):
-            self.start_paragraph(style_name)
-            self.write_text(line)
-            self.end_paragraph()
 
-    def write_styled_note(self, styledtext, format, style_name,                                                   
-                          contains_html=False):
+    def write_styled_note(self, styledtext, format, style_name,
+                          contains_html=False, links=False):
         """
         Convenience function to write a styledtext to the cairo doc. 
         styledtext : assumed a StyledText object to write
         format : = 0 : Flowed, = 1 : Preformatted
-        style_name : name of the style to use for default presentation                                          
-        contains_html: bool, the backend should not check if html is present.                                     
-            If contains_html=True, then the textdoc is free to handle that in                                     
-            some way. Eg, a textdoc could remove all tags, or could make sure                                     
+        style_name : name of the style to use for default presentation
+        contains_html: bool, the backend should not check if html is present.
+            If contains_html=True, then the textdoc is free to handle that in
+            some way. Eg, a textdoc could remove all tags, or could make sure
             a link is clickable. CairoDoc does nothing different for html notes
+        links:  bool, true if URLs should be made clickable
         """
         text = str(styledtext)
 
@@ -1328,7 +1417,7 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
             #FIXME: following split should be regex to match \n\s*\n instead?
             for line in markuptext.split('\n\n'):
                 self.start_paragraph(style_name)
-                self.__write_text(line, markup=True)
+                self.__write_text(line, markup=True, links=links)
                 self.end_paragraph()
         elif format == 0:
             #flowed
@@ -1340,31 +1429,54 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
                 newlines = []
                 for singleline in lines:
                     newlines.append(' '.join(singleline.split()))
-                self.__write_text('\n'.join(newlines), markup=True)
+                self.__write_text('\n'.join(newlines), markup=True, links=links)
                 self.end_paragraph()
 
-    def __write_text(self, text, mark=None, markup=False):
+    def __write_text(self, text, mark=None, markup=False, links=False):
         """
         @param text: text to write.
         @param mark:  IndexMark to use for indexing (if supported)
         @param markup: True if text already contains markup info. 
                        Then text will no longer be escaped
+        @param links:  True if URLs should be made clickable
         """
+        if links == True:
+            import cairo
+
+            if cairo.cairo_version() < 11210 and self._links_error == False:
+                # Cairo v1.12 is suppose to be the first version
+                # that supports clickable links
+                print """
+WARNING: This version of cairo (%s) does NOT support clickable links.
+The first version that is suppose to is v1.12.  See the roadmap:
+
+    http://www.cairographics.org/roadmap/
+
+The work around is to save to another format that supports clickable
+links (like ODF) and write PDF from that format.
+                """ % cairo.version
+                self._links_error = True
+
         if not markup:            
             # We need to escape the text here for later pango.Layout.set_markup
             # calls. This way we save the markup created by the report
             # The markup in the note editor is not in the text so is not 
             # considered. It must be added by pango too
             text = self._backend.ESCAPE_FUNC()(text)
+
+        if mark:
+            self._active_element.add_mark(mark)
+
         self._active_element.add_text(text)
 
-    def write_text(self, text, mark=None):
+    def write_text(self, text, mark=None, links=False):
         """Write a normal piece of text according to the
            present style
         @param text: text to write.
         @param mark:  IndexMark to use for indexing (if supported)
+        @param links:  True if URLs should be made clickable
         """
-        self.__write_text(text, mark)
+        self.__write_text(text, mark, links=links)
     
     def write_markup(self, text, s_tags):
         """
@@ -1378,10 +1490,37 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
         markuptext = self._backend.add_markup_from_styled(text, s_tags)
         self.__write_text(markuptext, markup=True)
     
-    def add_media_object(self, name, pos, x_cm, y_cm, alt=''):
-        new_image = GtkDocPicture(pos, name, x_cm, y_cm)
+    def add_media_object(self, name, pos, x_cm, y_cm, alt='', 
+                         style_name=None, crop=None):
+        new_image = GtkDocPicture(pos, name, x_cm, y_cm, crop=crop)
         self._active_element.add_child(new_image)
 
+        if len(alt):
+            style_sheet = self.get_style_sheet()
+
+            style = style_sheet.get_paragraph_style(style_name)
+            style.set_alignment(PARA_ALIGN_CENTER)
+            # Center the caption under the image
+            if pos == "right":
+                style.set_left_margin(self.get_usable_width() - new_image._width)
+            else:
+                style.set_right_margin(self.get_usable_width() - new_image._width)
+            new_paragraph = GtkDocParagraph(style)
+            new_paragraph.add_text('\n'.join(alt))
+            self._active_element.add_child(new_paragraph)
+
+    def insert_toc(self):
+        """
+        Insert a Table of Contents at this point in the document.
+        """
+        self._doc.add_child(GtkDocTableOfContents())
+
+    def insert_index(self):
+        """
+        Insert an Alphabetical Index at this point in the document.
+        """
+        self._doc.add_child(GtkDocAlphabeticalIndex())
+
     # DrawDoc implementation
     
     def start_page(self):
@@ -1481,6 +1620,12 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
         """
         raise NotImplementedError
 
+    def paginate_document(self, layout, page_width, page_height, dpi_x, dpi_y):
+        """Paginate the entire document.
+        """
+        while not self.paginate(layout, page_width, page_height, dpi_x, dpi_y):
+            pass
+
     def paginate(self, layout, page_width, page_height, dpi_x, dpi_y):
         """Paginate the meta document in chunks.
         
