@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libhtml.py 16639 2011-02-17 07:42:37Z robhealey1 $
+# $Id: libhtml.py 18743 2012-01-14 20:27:24Z gbritton $
 
 #------------------------------------------------------------------------
 #
@@ -60,6 +60,8 @@ __all__ = ['Html']
 #
 # XHTML DOCTYPE constants to be used in <!DOCTYPE ... > statements
 #
+# Reference: http://www.w3.org/QA/2002/04/valid-dtd-list.html
+#
 #------------------------------------------------------------------------
 
 _XHTML10_STRICT = '"-//W3C//DTD XHTML 1.0 Strict//EN"\n' \
@@ -74,6 +76,7 @@ _XHTML10_BASIC = '"-//W3C//DTD XHTML Basic 1.0//EN"\n' \
                  '\t"http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd"'
 _XHTML11_BASIC = '"-//W3C//DTD XHTML Basic 1.1//EN"\n ' \
                  '\t"http://www.w3.org/TR/xhtml-basic/xhtml-basic11.dtd"'
+_HTML5 = ""
 
 #------------------------------------------------------------------------
 #
@@ -135,7 +138,7 @@ class Html(list):
             )
 #
     @staticmethod
-    def doctype(name='html', public='PUBLIC', external_id=_XHTML10_STRICT):
+    def doctype(name='HTML', public='', external_id=_HTML5):
         """
         Build and return a DOCTYPE statement
 
@@ -150,11 +153,13 @@ class Html(list):
         :param args: 0 or more positional parameters to be added to this    
                      DOCTYPE.
         """
-        return '<!DOCTYPE %s %s %s>' % (
-            name,
-            public, 
-            external_id,
-            )
+        return (
+            '<!DOCTYPE %s %s %s' % (
+                name,
+                public, 
+                external_id,
+                )
+            ).rstrip() + '>'
 #
     @staticmethod
     def html(xmlns=_XMLNS, lang='en', *args, **keywargs):
@@ -176,7 +181,7 @@ class Html(list):
             )
 #
     @staticmethod
-    def head(title=None, encoding='utf-8', *args, **keywargs):
+    def head(title=None, encoding='utf-8', html5=True, *args, **keywargs):
         """
         Build and return a properly-formated <head> object
     
@@ -185,20 +190,26 @@ class Html(list):
                     title tag is written
         :type  encoding: string
         :param encoding: encoding to be used. Default = 'utf-8'
+        :param html5: generate html5 syntax. Default = True. Set to False
+                      if pre-html5 syntax required
         :rtype:  reference to new Html instance
         :returns: reference to the newly-created Html instances for <head> object
         """ 
-        meta1 = 'http-equiv="content-type" content="text/html;charset=%s"'
-        meta2 = 'http-equiv="Content-Style-Type" content="text/css"'
+
         head = Html('head', *args, **keywargs) 
         if title is not None: 
             head += (Html('title', title, inline=True, indent=True))
-        head += Html('meta', attr=meta1 % encoding, indent=True)
-        head += Html('meta', attr=meta2, indent=True)
+        if html5:
+            head += Html('meta', charset="utf-8", indent=True)
+        else:
+            meta1 = 'http-equiv="content-type" content="text/html;charset=%s"'
+            meta2 = 'http-equiv="Content-Style-Type" content="text/css"'
+            head += Html('meta', attr=meta1 % encoding, indent=True)
+            head += Html('meta', attr=meta2, indent=True)
         return head
 #
     @staticmethod
-    def page(title=None, encoding='utf-8', lang='en', *args, **keywargs):
+    def page(title=None, encoding='utf-8', lang='en', html5=True, *args, **keywargs):
         """
         This function prepares a new Html class based page and returns
     
@@ -208,17 +219,23 @@ class Html(list):
         :param encoding: encoding to be used. Default = 'utf-8'
         :type  lang: string
         :param lang: language to be used. Defaul = 'en'
+        :param html5: generate html5 syntax. Default = True. Set to False
+                      if pre-html5 syntax required
         :rtype:   three object references
         :returns:  references to the newly-created Html instances for
                   page, head and body
         """
         page = Html.html(lang=lang, *args, **keywargs)
-        page.addXML(encoding=encoding)
-        page.addDOCTYPE()
+        if html5:
+            page.addDOCTYPE(external_id=_HTML5)
+        else:
+            page.addXML(encoding=encoding)
+            page.addDOCTYPE(external_id=_XHTML10_STRICT)
 #
         head = Html.head(title=title,
                encoding=encoding,
                lang=lang,
+               html5=html5,
                indent=False,
                *args, **keywargs 
                )
@@ -425,7 +442,7 @@ class Html(list):
         self[0:0] = [xmldecl]
 #
     def addDOCTYPE(self, name='html', public='PUBLIC',
-            external_id=_XHTML10_STRICT, *args):
+            external_id=_HTML5, *args):
         """
         Add a DOCTYPE statement to the start of the list
 
@@ -438,12 +455,14 @@ class Html(list):
         :param args: 0 or more positional parameters to be added to this    
                      DOCTYPE.
         """
-        doctype = '<!DOCTYPE %s %s %s%s>' % (
-            name,
-            public,
-            external_id,
-            ' %s'*len(args) % args
-            )
+        doctype = (
+            '<!DOCTYPE %s %s %s%s' % (
+                name,
+                ('' if external_id ==_HTML5 else public),
+                external_id,
+                ' %s'*len(args) % args
+                )
+            ).rstrip() + '>'
         # Note: DOCTYPE declaration must follow XML declaration
 
         if len(self) and self[0][:6] == '<?xml ':
