@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#!/usr/bin/python
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
@@ -7,7 +9,7 @@
 # Copyright (C) 2007-2009  Stephane Charette <stephanecharette@gmail.com>
 # Copyright (C) 2008       Brian G. Matherly
 # Copyright (C) 2008       Jason M. Simanek <jason@bohemianalps.com>
-# Copyright (C) 2008-2009  Rob G. Healey <robhealey1@gmail.com>	
+# Copyright (C) 2008-2011  Rob G. Healey <robhealey1@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +26,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libhtmlconst.py 17994 2011-08-06 17:09:09Z robhealey1 $
+# $Id: libhtmlconst.py 18645 2011-12-21 00:44:16Z robhealey1 $
 
 """
 General constants used in different html enabled plugins
@@ -116,58 +118,3 @@ _COPY_OPTIONS = [
 
         _('No copyright notice'),
         ]
-
-# NarrativeWeb javascript code for PlacePage's "Google Maps"...
-google_jsc = """
-var myLatlng = new google.maps.LatLng(%s, %s);
-
-function initialize() {
-    var mapOptions = {
-        zoom: 13,
-        mapTypeId: google.maps.MapTypeId.ROADMAP,
-        center: myLatlng
-    };
-    var map = new google.maps.Map(document.getElementById("map_canvas"), mapOptions);
-          
-    var marker = new google.maps.Marker({
-        map:       map,
-        draggable: true,
-        animation: google.maps.Animation.DROP,
-        position:  myLatlng
-    });
-    google.maps.event.addListener(marker, 'click', toggleBounce);
-}
-
-function toggleBounce() {
-    if (marker.getAnimation() != null) {
-        marker.setAnimation(null);
-    } else {
-        marker.setAnimation(google.maps.Animation.BOUNCE);
-    }
-}"""
-
-# NarrativeWeb javascript code for PlacePage's "Open Street Map"...
-openstreet_jsc = """
-    OpenLayers.Lang.setCode("%s");
-
-    map = new OpenLayers.Map("map_canvas");
-    var osm = new OpenLayers.Layer.OSM()
-    map.addLayer(osm);
-
-    var lonLat = new OpenLayers.LonLat(%s, %s)
-        .transform(
-            new OpenLayers.Projection("EPSG:4326"), // transform from WGS 1984
-            map.getProjectionObject() // to Spherical Mercator Projection
-        );
-    var zoom =16;
-    map.setCenter(lonLat, zoom);
- 
-    var markers = new OpenLayers.Layer.Markers("Markers");
-    markers.addMarker(new OpenLayers.Marker(lonLat));
-    map.addLayer(markers);
-
-    // add overview control
-    map.addControl(new OpenLayers.Control.OverviewMap());
-
-    // add a layer switcher
-    map.addControl(new OpenLayers.Control.LayerSwitcher());"""
