@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2009 Benny Malengier
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: quickview.gpr.py 15348 2010-05-07 12:59:23Z dsblank $
+# $Id: quickview.gpr.py 18548 2011-12-04 17:09:17Z kulath $
 
 #------------------------------------------------------------------------
 #
@@ -31,7 +32,7 @@ id    = 'ageondate',
 name  = _("Age on Date"),
 description =  _("Display people and ages on a particular date"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'AgeOnDate.py',
 authors = ["Douglas Blank"],
@@ -51,7 +52,7 @@ id    = 'attribute_match',
 name  = _("Attribute Match"),
 description =  _("Display people with same attribute."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'AttributeMatch.py',
 authors = ["Douglas Blank"],
@@ -71,7 +72,7 @@ id    = 'all_events',
 name  = _("All Events"),
 description =  _("Display a person's events, both personal and family."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'all_events.py',
 authors = ["Donald N. Allingham"],
@@ -86,7 +87,7 @@ id    = 'all_events_fam',
 name  = _("All Family Events"),
 description =  _("Display the family and family members events."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'all_events.py',
 authors = ["B. Malengier"],
@@ -106,7 +107,7 @@ id    = 'all_relations',
 name  = _("Relation to Home Person"),
 description =  _("Display all relationships between person and home person."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'all_relations.py',
 authors = ["B. Malengier"],
@@ -126,7 +127,7 @@ id    = 'filterbyname',
 name  = _("Filter"),
 description =  _("Display filtered data"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'FilterByName.py',
 authors = ["Douglas Blank"],
@@ -146,7 +147,7 @@ id    = 'father_lineage',
 name  = _("Father lineage"),
 description =  _("Display father lineage"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'lineage.py',
 authors = ["B. Malengier"],
@@ -160,7 +161,7 @@ id    = 'mother_lineage',
 name  = _("Mother lineage"),
 description =  _("Display mother lineage"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'lineage.py',
 authors = ["B. Malengier"],
@@ -180,7 +181,7 @@ id    = 'onthisday',
 name  = _("On This Day"),
 description =  _("Display events on a particular day"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'OnThisDay.py',
 authors = ["Douglas Blank"],
@@ -202,6 +203,9 @@ refitems = [(CATEGORY_QR_PERSON, 'person', _("Person")),
             (CATEGORY_QR_PLACE, 'place', _("Place")), 
             (CATEGORY_QR_MEDIA, 'media', _("Media")), 
             (CATEGORY_QR_NOTE, 'note', _("Note")), 
+            (CATEGORY_QR_CITATION, 'citation', _("Citation")),
+            (CATEGORY_QR_SOURCE_OR_CITATION, 'source or citation', 
+                    _("Source or Citation"))
             ]
 
 for (category, item, trans) in refitems:
@@ -210,7 +214,7 @@ for (category, item, trans) in refitems:
         name  = _("%s References") % trans,
         description =  _("Display references for a %s") % trans,
         version = '1.0',
-        gramps_target_version = '3.3',
+        gramps_target_version = '3.4',
         status = STABLE,
         fname = 'References.py',
         authors = ["Douglas Blank"],
@@ -224,7 +228,7 @@ register(QUICKREPORT,
   name  = _("Link References"),
   description =  _("Display link references for a note"),
   version = '1.0',
-  gramps_target_version = '3.3',
+  gramps_target_version = '3.4',
   status = STABLE,
   fname = 'LinkReferences.py',
   authors = ["Douglas Blank"],
@@ -245,7 +249,7 @@ name  = _("Repository References"),
 description =  _("Display the repository reference for sources related to"
                  " the active repository"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'Reporef.py',
 authors = ["Jerome Rapinat"],
@@ -265,7 +269,7 @@ id    = 'samesurnames',
 name  = _("Same Surnames"),
 description =  _("Display people with the same surname as a person."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'SameSurnames.py',
 authors = ["Douglas Blank"],
@@ -279,7 +283,7 @@ id    = 'samegivens',
 name  = _("Same Given Names"),
 description =  _("Display people with the same given name as a person."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'SameSurnames.py',
 authors = ["Douglas Blank"],
@@ -293,7 +297,7 @@ id    = 'samegivens_misc',
 name  = _("Same Given Names - stand-alone"),
 description =  _("Display people with the same given name as a person."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'SameSurnames.py',
 authors = ["Douglas Blank"],
@@ -312,7 +316,7 @@ id    = 'siblings',
 name  = _("Siblings"),
 description =  _("Display a person's siblings."),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'siblings.py',
 authors = ["Donald N. Allingham"],
