@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: BirthdayReport.py 18259 2011-10-08 11:25:38Z romjerome $
+# $Id: BirthdayReport.py 18915 2012-02-17 16:51:40Z romjerome $
 #
 
 #------------------------------------------------------------------------
@@ -27,6 +27,7 @@
 # python modules
 #
 #------------------------------------------------------------------------
+import copy
 from gen.ggettext import gettext as _
 from gen.ggettext import ngettext
 import datetime, time
@@ -36,7 +37,7 @@ import datetime, time
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gen.display.name import displayer as _nd
+from gen.display.name import displayer as global_name_display
 from Errors import ReportError
 from gen.lib import NameType, EventType, Name, Date, Person
 import Relationship
@@ -45,10 +46,9 @@ from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
                              PARA_ALIGN_LEFT, PARA_ALIGN_CENTER)
 from gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
                          EnumeratedListOption, FilterOption, PersonOption)
-from gui.utils import ProgressMeter
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from Utils import probably_alive
 import GrampsLocale
 from DateHandler import displayer as _dd
@@ -64,15 +64,15 @@ class CalendarReport(Report):
     """
     Create the Calendar object that produces the report.
     """
-    def __init__(self, database, options_class):
-        Report.__init__(self, database, options_class)
-        menu = options_class.menu
-        mgobn = lambda name:options_class.menu.get_option_by_name(name).get_value()
+    def __init__(self, database, options, user):
+        Report.__init__(self, database, options, user)
+        self._user = user
+        menu = options.menu
+        mgobn = lambda name:options.menu.get_option_by_name(name).get_value()
 
         self.titletext = mgobn('titletext')
         self.relationships = mgobn('relationships')
         self.year = mgobn('year')
-        self.name_format = mgobn('name_format')
         self.country = mgobn('country')
         self.anniversaries = mgobn('anniversaries')
         self.start_dow = mgobn('start_dow')
@@ -85,6 +85,14 @@ class CalendarReport(Report):
         self.filter_option =  menu.get_option_by_name('filter')
         self.filter = self.filter_option.get_filter()
         pid = mgobn('pid')
+        
+        # Copy the global NameDisplay so that we don't change application 
+        # defaults.
+        self._name_display = copy.deepcopy(global_name_display)
+        name_format = menu.get_option_by_name("name_format").get_value()
+        if name_format != 0:
+            self._name_display.set_default_format(name_format)
+        
         self.center_person = database.get_person_from_gramps_id(pid)
         if (self.center_person == None) :
             raise ReportError(_("Person %s is not in the Database") % pid )        
@@ -112,8 +120,7 @@ class CalendarReport(Report):
                 surname_obj.set_surname(maiden_name)
         else:
             name = Name(primary_name)
-        name.set_display_as(self.name_format)
-        return _nd.display_name(name)
+        return self._name_display.display_name(name)
 
     def add_day_item(self, text, month, day):
         """ Add an item to a day. """
@@ -137,7 +144,6 @@ class CalendarReport(Report):
     def write_report(self):
         """ The short method that runs through each month and creates a page. """
         # initialize the dict to fill:
-        self.progress = ProgressMeter(_('Birthday and Anniversary Report'))
         self.calendar = {}
         # get the information, first from holidays:
         if self.country != 0:
@@ -163,13 +169,16 @@ class CalendarReport(Report):
         if self.relationships:
             name = self.center_person.get_primary_name()
             self.doc.start_paragraph('BIR-Text3style')
-            self.doc.write_text(_("Relationships shown are to %s") % _nd.display_name(name))
+            # feature request 2356: avoid genitive form
+            self.doc.write_text(_("Relationships shown are to %s") %
+                                self._name_display.display_name(name))
             self.doc.end_paragraph()
-        self.progress.set_pass(_('Formatting months...'), 12)
+        self._user.begin_progress(_('Birthday and Anniversary Report'), 
+                                  _('Formatting months...'), 12)
         for month in range(1, 13):
-            self.progress.step()
+            self._user.step_progress()
             self.print_page(month)
-        self.progress.close()
+        self._user.end_progress()
 
     def print_page(self, month):
         """ Prints a month as a page """
@@ -202,14 +211,19 @@ class CalendarReport(Report):
         and text.
         """
         people = self.database.iter_person_handles()
-        self.progress.set_pass(_('Applying Filter...'), 
-            self.database.get_number_of_people())
-        people = self.filter.apply(self.database, people, self.progress)
+        self._user.begin_progress(_('Birthday and Anniversary Report'), 
+                                  _('Applying Filter...'), 
+                                  self.database.get_number_of_people())
+        people = self.filter.apply(self.database, people, 
+                                   self._user.step_progress)
+        self._user.end_progress()
+        
         rel_calc = Relationship.get_relationship_calculator()
 
-        self.progress.set_pass(_('Reading database...'), len(people))
+        self._user.begin_progress(_('Birthday and Anniversary Report'), 
+                                  _('Reading database...'), len(people))
         for person_handle in people:
-            self.progress.step()
+            self._user.step_progress()
             person = self.database.get_person_from_handle(person_handle)
             birth_ref = person.get_birth_ref()
             birth_date = None
@@ -284,7 +298,7 @@ class CalendarReport(Report):
                         if spouse:
                             spouse_name = self.get_name(spouse)
                             short_name = self.get_name(person)
-                            # TEMP: this will hanlde ordered events
+                            # TEMP: this will handle ordered events
                             # GRAMPS 3.0 will have a new mechanism for start/stop events
                             are_married = None
                             for event_ref in fam.get_event_ref_list():
@@ -324,6 +338,7 @@ class CalendarReport(Report):
                                                                     prob_alive_date)
                                             if (self.alive and alive1 and alive2) or not self.alive:
                                                 self.add_day_item(text, month, day)
+        self._user.end_progress()
 
 #------------------------------------------------------------------------
 #
@@ -359,10 +374,9 @@ class CalendarOptions(MenuReportOptions):
         
         self.__update_filters()
 
-        # We must figure out the value of the first option before we can
-        # create the EnumeratedListOption
-        fmt_list = _nd.get_name_format()
-        name_format = EnumeratedListOption(_("Name format"), fmt_list[0][0])
+        fmt_list = global_name_display.get_name_format()
+        name_format = EnumeratedListOption(_("Name format"), 0)
+        name_format.add_item(0, _("Default"))
         for num, name, fmt_str, act in fmt_list:
             name_format.add_item(num, name)
         name_format.set_help(_("Select the format to display names"))
