@@ -8,6 +8,7 @@
 # Copyright (C) 2009      Benny Malengier <benny.malengier@gramps-project.org>
 # Copyright (C) 2010      Jakim Friant
 # Copyright (C) 2010      Vlada Peri\u0107
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +25,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetAncestralReport.py 17729 2011-06-09 13:33:49Z ldnp $
+# $Id: DetAncestralReport.py 18915 2012-02-17 16:51:40Z romjerome $
 
 """Reports/Text Reports/Detailed Ancestral Report"""
 
@@ -33,6 +34,7 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
+import copy
 from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
@@ -40,7 +42,7 @@ from gen.ggettext import gettext as _
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gen.display.name import displayer as _nd
+from gen.display.name import displayer as global_name_display
 from Errors import ReportError
 from gen.lib import EventType, FamilyRelType, Person, NoteType
 from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
@@ -50,7 +52,7 @@ from gen.plug.menu import BooleanOption, NumberOption, PersonOption, EnumeratedL
 from gen.plug.report import ( Report, Bibliography )
 from gen.plug.report import endnotes
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
                         
 import DateHandler
 
@@ -72,15 +74,15 @@ EMPTY_ENTRY = "_____________"
 #------------------------------------------------------------------------
 class DetAncestorReport(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the DetAncestorReport object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        person          - currently selected person
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
@@ -101,12 +103,14 @@ class DetAncestorReport(Report):
         childref      - Whether to add descendant references in child list.
         addimages     - Whether to include images.
         pid           - The Gramps ID of the center person for the report.
+        name_format   - Preferred format to display names
         """
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
 
         self.map = {}
+        self._user = user
 
-        menu = options_class.menu
+        menu = options.menu
         get_option_by_name = menu.get_option_by_name
         get_value = lambda name: get_option_by_name(name).get_value()
 
@@ -136,6 +140,14 @@ class DetAncestorReport(Report):
         if (self.center_person == None) :
             raise ReportError(_("Person %s is not in the Database") % pid )
 
+        # Copy the global NameDisplay so that we don't change application 
+        # defaults.
+        self._name_display = copy.deepcopy(global_name_display)
+            
+        name_format = menu.get_option_by_name("name_format").get_value()
+        if name_format != 0:
+            self._name_display.set_default_format(name_format)
+
         self.gen_handles = {}
         self.prev_gen_handles = {}
         
@@ -179,8 +191,9 @@ class DetAncestorReport(Report):
     def write_report(self):
         self.apply_filter(self.center_person.get_handle(), 1)
 
-        name = _nd.display_name(self.center_person.get_primary_name())
+        name = self._name_display.display_name(self.center_person.get_primary_name())
         self.doc.start_paragraph("DAR-Title")
+        # feature request 2356: avoid genitive form
         title = self._("Ancestral Report for %s") % name
         mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.write_text(title, mark)
@@ -238,11 +251,11 @@ class DetAncestorReport(Report):
         
         if self.addimages and len(plist) > 0:
             photo = plist[0]
-            ReportUtils.insert_image(self.database, self.doc, photo)
+            ReportUtils.insert_image(self.database, self.doc, photo, self._user)
 
         self.doc.start_paragraph("DAR-First-Entry","%s." % str(key))
 
-        name = _nd.display_formal(person)
+        name = self._name_display.display_formal(person)
         mark = ReportUtils.get_person_mark(self.database, person)
 
         self.doc.start_bold()
@@ -301,6 +314,7 @@ class DetAncestorReport(Report):
         notelist = person.get_note_list()
         if len(notelist) > 0 and self.includenotes:
             self.doc.start_paragraph("DAR-NoteHeader")
+            # feature request 2356: avoid genitive form
             self.doc.write_text(self._("Notes for %s") % name)
             self.doc.end_paragraph()
             for notehandle in notelist:
@@ -341,7 +355,7 @@ class DetAncestorReport(Report):
                 if first:
                     self.doc.start_paragraph('DAR-MoreHeader')
                     self.doc.write_text(self._('More about %(person_name)s:') % { 
-                        'person_name' : _nd.display(person) })
+                        'person_name' : self._name_display.display(person) })
                     self.doc.end_paragraph()
                     first = 0
                     
@@ -471,14 +485,16 @@ class DetAncestorReport(Report):
             father_handle = family.get_father_handle()
             if mother_handle:
                 mother = self.database.get_person_from_handle(mother_handle)
-                mother_name = _nd.display_name(mother.get_primary_name())
+                mother_name = \
+                    self._name_display.display_name(mother.get_primary_name())
                 mother_mark = ReportUtils.get_person_mark(self.database, mother)
             else:
                 mother_name = ""
                 mother_mark = ""
             if father_handle:
                 father = self.database.get_person_from_handle(father_handle)
-                father_name = _nd.display_name(father.get_primary_name())
+                father_name = \
+                    self._name_display.display_name(father.get_primary_name())
                 father_mark = ReportUtils.get_person_mark(self.database, father)
             else:
                 father_name = ""
@@ -501,10 +517,14 @@ class DetAncestorReport(Report):
             family = self.database.get_family_from_handle(family_handle)
             spouse_handle = ReportUtils.find_spouse(person,family)
             spouse = self.database.get_person_from_handle(spouse_handle)
+            if spouse:
+                name = self._name_display.display_formal(spouse)
+            else:
+                name = ""
             text = ""
             spouse_mark = ReportUtils.get_person_mark(self.database, spouse)
             
-            text = self.__narrator.get_married_string(family, is_first)
+            text = self.__narrator.get_married_string(family, is_first, self._name_display)
 
             if text:
                 self.doc.write_text_citation(text, spouse_mark)
@@ -520,14 +540,14 @@ class DetAncestorReport(Report):
         mother_handle = family.get_mother_handle()
         if mother_handle:
             mother = self.database.get_person_from_handle(mother_handle)
-            mother_name = _nd.display(mother)
+            mother_name = self._name_display.display(mother)
         else:
             mother_name = self._("unknown")
 
         father_handle = family.get_father_handle()
         if father_handle:
             father = self.database.get_person_from_handle(father_handle)
-            father_name = _nd.display(father)
+            father_name = self._name_display.display(father)
         else:
             father_name = self._("unknown")
 
@@ -542,7 +562,7 @@ class DetAncestorReport(Report):
         for child_ref in family.get_child_ref_list():
             child_handle = child_ref.ref
             child = self.database.get_person_from_handle(child_handle)
-            child_name = _nd.display(child)
+            child_name = self._name_display.display(child)
             child_mark = ReportUtils.get_person_mark(self.database, child)
 
             if self.childref and self.prev_gen_handles.get(child_handle):
@@ -570,14 +590,14 @@ class DetAncestorReport(Report):
         mother_handle = family.get_mother_handle()
         if mother_handle:
             mother = self.database.get_person_from_handle(mother_handle)
-            mother_name = _nd.display(mother)
+            mother_name = self._name_display.display(mother)
         else:
             mother_name = self._("unknown")
 
         father_handle = family.get_father_handle()
         if father_handle:
             father = self.database.get_person_from_handle(father_handle)
-            father_name = _nd.display(father)
+            father_name = self._name_display.display(father)
         else:
             father_name = self._("unknown")
 
@@ -632,9 +652,10 @@ class DetAncestorReport(Report):
                 
                 if self.addimages and len(plist) > 0:
                     photo = plist[0]
-                    ReportUtils.insert_image(self.database, self.doc, photo)
+                    ReportUtils.insert_image(self.database, self.doc, 
+                                             photo, self._user)
         
-                name = _nd.display_formal(ind)
+                name = self._name_display.display_formal(ind)
                 mark = ReportUtils.get_person_mark(self.database, ind)
         
                 if family.get_relationship() == FamilyRelType.MARRIED:
@@ -678,7 +699,7 @@ class DetAncestorReport(Report):
         if not obj or not self.inc_sources:
             return ""
         
-        txt = endnotes.cite_source(self.bibli, obj)
+        txt = endnotes.cite_source(self.bibli, self.database, obj)
         if txt:
             txt = '<super>' + txt + '</super>'
         return txt
@@ -707,6 +728,16 @@ class DetAncestorOptions(MenuReportOptions):
         pid = PersonOption(_("Center Person"))
         pid.set_help(_("The center person for the report"))
         addopt("pid", pid)
+
+        # We must figure out the value of the first option before we can
+        # create the EnumeratedListOption
+        fmt_list = global_name_display.get_name_format()
+        name_format = EnumeratedListOption(_("Name format"), 0)
+        name_format.add_item(0, _("Default"))
+        for num, name, fmt_str, act in fmt_list:
+            name_format.add_item(num, name)
+        name_format.set_help(_("Select the format to display names"))
+        addopt("name_format", name_format)
         
         gen = NumberOption(_("Generations"),10,1,100)
         gen.set_help(_("The number of generations to include in the report"))
