@@ -9,6 +9,8 @@
 # Copyright (C) 2009      Benny Malengier <benny.malengier@gramps-project.org>
 # Copyright (C) 2010      Jakim Friant
 # Copyright (C) 2010      Vlada Peri\u0107
+# Copyright (C) 2011      Matt Keenan <matt.keenan@gmail.com>
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +27,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetDescendantReport.py 17729 2011-06-09 13:33:49Z ldnp $
+# $Id: DetDescendantReport.py 18915 2012-02-17 16:51:40Z romjerome $
 
 """Reports/Text Reports/Detailed Descendant Report"""
 
@@ -34,6 +36,7 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
+import copy
 from gen.ggettext import gettext as _
 from functools import partial
 
@@ -42,7 +45,7 @@ from functools import partial
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gen.display.name import displayer as _nd
+from gen.display.name import displayer as global_name_display
 from Errors import ReportError
 from gen.lib import FamilyRelType, Person, NoteType
 from gen.plug.menu import (BooleanOption, NumberOption, PersonOption, 
@@ -53,7 +56,7 @@ from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
 from gen.plug.report import (Report, Bibliography)
 from gen.plug.report import endnotes
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
                         
 import DateHandler
 
@@ -76,15 +79,15 @@ HENRY = "123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 #------------------------------------------------------------------------
 class DetDescendantReport(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the DetDescendantReport object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        person          - currently selected person
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
@@ -113,12 +116,15 @@ class DetDescendantReport(Report):
         incpaths      - Whether to include the path of descendancy from the start-person to each descendant.
         incssign      - Whether to include a sign ('+') before the descendant number in the child-list to indicate a child has succession.
         pid           - The Gramps ID of the center person for the report.
+        name_format   - Preferred format to display names
+        incmateref    - Whether to print mate information or reference
         """
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
 
         self.map = {}
+        self._user = user
 
-        menu = options_class.menu
+        menu = options.menu
         get_option_by_name = menu.get_option_by_name
         get_value = lambda name: get_option_by_name(name).get_value()
         self.max_generations = get_value('gen')
@@ -146,6 +152,7 @@ class DetDescendantReport(Report):
         self.inc_attrs     = get_value('incattrs')
         self.inc_paths     = get_value('incpaths')
         self.inc_ssign     = get_value('incssign')
+        self.inc_materef   = get_value('incmateref')
         pid                = get_value('pid')
         self.center_person = database.get_person_from_gramps_id(pid)
         if (self.center_person == None) :
@@ -155,6 +162,7 @@ class DetDescendantReport(Report):
         self.prev_gen_handles = {}
         self.gen_keys = []
         self.dnumber = {}
+        self.dmates = {}
 
         if blankdate:
             empty_date = EMPTY_ENTRY
@@ -170,6 +178,13 @@ class DetDescendantReport(Report):
         translator = Translator(language)
         self._ = translator.gettext
 
+        # Copy the global NameDisplay so that we don't change application 
+        # defaults.
+        self._name_display = copy.deepcopy(global_name_display)
+        name_format = menu.get_option_by_name("name_format").get_value()
+        if name_format != 0:
+            self._name_display.set_default_format(name_format)
+
         self.__narrator = Narrator(self.database, self.verbose,
                                    use_call, use_fulldate, 
                                    empty_date, empty_place,
@@ -250,8 +265,9 @@ class DetDescendantReport(Report):
         for generation in xrange(len(self.gen_keys)):
             for key in self.gen_keys[generation]:
                 person_handle = self.map[key]
-                self.dnumber[person_handle] = mod_reg_number
-                mod_reg_number += 1
+                if person_handle not in self.dnumber:
+                    self.dnumber[person_handle] = mod_reg_number
+                    mod_reg_number += 1
 
     def write_report(self):
         """
@@ -266,10 +282,11 @@ class DetDescendantReport(Report):
         else:
             raise AttributeError("no such numbering: '%s'" % self.numbering)
 
-        name = _nd.display_name(self.center_person.get_primary_name())
+        name = self._name_display.display_name(self.center_person.get_primary_name())
 
         self.doc.start_paragraph("DDR-Title")
 
+        # feature request 2356: avoid genitive form
         title = self._("Descendant Report for %(person_name)s") % {
                     'person_name' : name }
         mark = IndexMark(title, INDEX_TYPE_TOC, 1)
@@ -278,6 +295,7 @@ class DetDescendantReport(Report):
 
         generation = 0
 
+        self.numbers_printed = list()
         for generation in xrange(len(self.gen_keys)):
             if self.pgbrk and generation > 0:
                 self.doc.page_break()
@@ -313,11 +331,13 @@ class DetDescendantReport(Report):
                 father_handle = family.get_father_handle()
                 if mother_handle and mother_handle in self.dnumber:
                     person = self.database.get_person_from_handle(mother_handle)
-                    person_name = _nd.display_name(person.get_primary_name())
+                    person_name = \
+                        self._name_display.display_name(person.get_primary_name())
                     path.append(person_name)
                 elif father_handle and father_handle in self.dnumber:
                     person = self.database.get_person_from_handle(father_handle)
-                    person_name = _nd.display_name(person.get_primary_name())
+                    person_name = \
+                        self._name_display.display_name(person.get_primary_name())
                     path.append(person_name)
                 else:
                     break
@@ -343,9 +363,15 @@ class DetDescendantReport(Report):
         person = self.database.get_person_from_handle(person_handle)
 
         val = self.dnumber[person_handle]
+
+        if val in self.numbers_printed:
+            return
+        else:
+            self.numbers_printed.append(val)
+
         self.doc.start_paragraph("DDR-First-Entry","%s." % val)
 
-        name = _nd.display_formal(person)
+        name = self._name_display.display_formal(person)
         mark = ReportUtils.get_person_mark(self.database, person)
 
         self.doc.start_bold()
@@ -368,7 +394,7 @@ class DetDescendantReport(Report):
                     self.doc.write_text(self._(
                         "%(name)s is the same person as [%(id_str)s].") % {
                             'name' :'',
-                            'id_str': str(dkey),
+                            'id_str': self.dnumber[self.map[dkey]],
                             }
                         )
                     self.doc.end_paragraph()
@@ -471,14 +497,16 @@ class DetDescendantReport(Report):
             father_handle = family.get_father_handle()
             if mother_handle:
                 mother = self.database.get_person_from_handle(mother_handle)
-                mother_name = _nd.display_name(mother.get_primary_name())
+                mother_name = \
+                    self._name_display.display_name(mother.get_primary_name())
                 mother_mark = ReportUtils.get_person_mark(self.database, mother)
             else:
                 mother_name = ""
                 mother_mark = ""
             if father_handle:
                 father = self.database.get_person_from_handle(father_handle)
-                father_name = _nd.display_name(father.get_primary_name())
+                father_name = \
+                    self._name_display.display_name(father.get_primary_name())
                 father_mark = ReportUtils.get_person_mark(self.database, father)
             else:
                 father_name = ""
@@ -500,10 +528,14 @@ class DetDescendantReport(Report):
             family = self.database.get_family_from_handle(family_handle)
             spouse_handle = ReportUtils.find_spouse(person, family)
             spouse = self.database.get_person_from_handle(spouse_handle)
+            if spouse:
+                name = self._name_display.display_formal(spouse)
+            else:
+                name = ""
             text = ""
             spouse_mark = ReportUtils.get_person_mark(self.database, spouse)
             
-            text = self.__narrator.get_married_string(family, is_first)
+            text = self.__narrator.get_married_string(family, is_first, self._name_display)
             
             if text:
                 self.doc.write_text_citation(text, spouse_mark)
@@ -522,7 +554,7 @@ class DetDescendantReport(Report):
             mate = self.database.get_person_from_handle(mate_handle)
 
             self.doc.start_paragraph("DDR-MoreHeader")
-            name = _nd.display_formal(mate)
+            name = self._name_display.display_formal(mate)
             mark = ReportUtils.get_person_mark(self.database, mate)
             if family.get_relationship() == FamilyRelType.MARRIED:
                 self.doc.write_text(self._("Spouse: %s") % name, mark)
@@ -533,20 +565,33 @@ class DetDescendantReport(Report):
             self.doc.write_text_citation(self.endnotes(mate))
             self.doc.end_paragraph()
 
-            self.write_person_info(mate)
+            if not self.inc_materef:
+                # Don't want to just print reference
+                self.write_person_info(mate)
+            else:
+                # Check to see if we've married a cousin
+                if mate_handle in self.dnumber:
+                    self.doc.start_paragraph('DDR-MoreDetails')
+                    self.doc.write_text_citation(
+                        self._("Ref: %s. %s") %
+                        (self.dnumber[mate_handle], name))
+                    self.doc.end_paragraph()
+                else:
+                    self.dmates[mate_handle] = person.get_handle()
+                    self.write_person_info(mate)
 
     def __get_mate_names(self, family):
         mother_handle = family.get_mother_handle()
         if mother_handle:
             mother = self.database.get_person_from_handle(mother_handle)
-            mother_name = _nd.display(mother)
+            mother_name = self._name_display.display(mother)
         else:
             mother_name = self._("unknown")
 
         father_handle = family.get_father_handle()
         if father_handle:
             father = self.database.get_person_from_handle(father_handle)
-            father_name = _nd.display(father)
+            father_name = self._name_display.display(father)
         else:
             father_name = self._("unknown")
 
@@ -573,7 +618,7 @@ class DetDescendantReport(Report):
         for child_ref in family.get_child_ref_list():
             child_handle = child_ref.ref
             child = self.database.get_person_from_handle(child_handle)
-            child_name = _nd.display(child)
+            child_name = self._name_display.display(child)
             child_mark = ReportUtils.get_person_mark(self.database, child)
 
             if self.childref and self.prev_gen_handles.get(child_handle):
@@ -689,13 +734,13 @@ class DetDescendantReport(Report):
 
 
     def write_person_info(self, person):
-        name = _nd.display_formal(person)
+        name = self._name_display.display_formal(person)
         self.__narrator.set_subject(person)
         
         plist = person.get_media_list()
         if self.addimages and len(plist) > 0:
             photo = plist[0]
-            ReportUtils.insert_image(self.database, self.doc, photo)
+            ReportUtils.insert_image(self.database, self.doc, photo, self._user)
         
         self.doc.start_paragraph("DDR-Entry")
         
@@ -730,6 +775,7 @@ class DetDescendantReport(Report):
         notelist = person.get_note_list()
         if len(notelist) > 0 and self.inc_notes:
             self.doc.start_paragraph("DDR-NoteHeader")
+            # feature request 2356: avoid genitive form
             self.doc.write_text(self._("Notes for %s") % name)
             self.doc.end_paragraph()
             for notehandle in notelist:
@@ -762,7 +808,7 @@ class DetDescendantReport(Report):
                 if first:
                     self.doc.start_paragraph('DDR-MoreHeader')
                     self.doc.write_text(self._('More about %(person_name)s:') % { 
-                        'person_name' : _nd.display(person) })
+                        'person_name' : self._name_display.display(person) })
                     self.doc.end_paragraph()
                     first = 0
 
@@ -815,7 +861,7 @@ class DetDescendantReport(Report):
         if not obj or not self.inc_sources:
             return ""
         
-        txt = endnotes.cite_source(self.bibli, obj)
+        txt = endnotes.cite_source(self.bibli, self.database, obj)
         if txt:
             txt = '<super>' + txt + '</super>'
         return txt
@@ -847,6 +893,16 @@ class DetDescendantOptions(MenuReportOptions):
         pid.set_help(_("The center person for the report"))
         add_option("pid", pid)
         
+        # We must figure out the value of the first option before we can
+        # create the EnumeratedListOption
+        fmt_list = global_name_display.get_name_format()
+        name_format = EnumeratedListOption(_("Name format"), 0)
+        name_format.add_item(0, _("Default"))
+        for num, name, fmt_str, act in fmt_list:
+            name_format.add_item(num, name)
+        name_format.set_help(_("Select the format to display names"))
+        add_option("name_format", name_format)
+
         numbering = EnumeratedListOption(_("Numbering system"), "Henry")
         numbering.set_items([
                 ("Henry",      _("Henry numbering")), 
@@ -956,6 +1012,10 @@ class DetDescendantOptions(MenuReportOptions):
         incmates.set_help(_("Whether to include detailed spouse information."))
         add_option("incmates", incmates)
 
+        incmateref = BooleanOption(_("Include spouse reference"), False)
+        incmateref.set_help(_("Whether to include reference to spouse."))
+        add_option("incmateref", incmateref)
+
         incssign = BooleanOption(_("Include sign of succession ('+')"
                                    " in child-list"), True)
         incssign.set_help(_("Whether to include a sign ('+') before the"
