@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: EndOfLineReport.py 16979 2011-03-30 01:50:08Z pez4brian $
+# $Id: EndOfLineReport.py 18915 2012-02-17 16:51:40Z romjerome $
 
 """Reports/Text Reports/End of Line Report"""
 
@@ -28,6 +28,7 @@
 # python modules
 #
 #------------------------------------------------------------------------
+import copy
 from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
@@ -35,15 +36,15 @@ from gen.ggettext import gettext as _
 # gramps modules
 #
 #------------------------------------------------------------------------
-from gen.display.name import displayer as name_displayer
+from gen.display.name import displayer as global_name_display
 from Errors import ReportError
 from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle, TableStyle,
                             TableCellStyle, FONT_SANS_SERIF, INDEX_TYPE_TOC,
                             PARA_ALIGN_CENTER)
-from gen.plug.menu import PersonOption
+from gen.plug.menu import (PersonOption, EnumeratedListOption)
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 import DateHandler
 
 #------------------------------------------------------------------------
@@ -53,27 +54,35 @@ import DateHandler
 #------------------------------------------------------------------------
 class EndOfLineReport(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the EndOfLineReport object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        person          - currently selected person
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
+        name_format   - Preferred format to display names
 
         """
-        Report.__init__(self, database, options_class)
-        menu = options_class.menu
+        Report.__init__(self, database, options, user)
+        menu = options.menu
         pid = menu.get_option_by_name('pid').get_value()
         self.center_person = database.get_person_from_gramps_id(pid)
         if (self.center_person == None) :
             raise ReportError(_("Person %s is not in the Database") % pid )
 
+        # Copy the global NameDisplay so that we don't change application 
+        # defaults.
+        self._name_display = copy.deepcopy(global_name_display)
+        name_format = menu.get_option_by_name("name_format").get_value()
+        if name_format != 0:
+            self._name_display.set_default_format(name_format)
+
         # eol_map is a map whose:
         #   keys are the generations of the people
         #   values are a map whose:
@@ -134,15 +143,17 @@ class EndOfLineReport(Report):
         The routine the actually creates the report. At this point, the document
         is opened and ready for writing.
         """
-        pname = name_displayer.display(self.center_person)
+        pname = self._name_display.display(self.center_person)
         
         self.doc.start_paragraph("EOL-Title")
+        # feature request 2356: avoid genitive form
         title = _("End of Line Report for %s") % pname
         mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.write_text(title, mark)
         self.doc.end_paragraph()
         
         self.doc.start_paragraph("EOL-Subtitle")
+        # feature request 2356: avoid genitive form
         title = _("All the ancestors of %s who are missing a parent") % pname
         self.doc.write_text(title)
         self.doc.end_paragraph()
@@ -173,7 +184,7 @@ class EndOfLineReport(Report):
         """
         person = self.database.get_person_from_handle(person_handle)
 
-        name = name_displayer.display(person)
+        name = self._name_display.display(person)
         mark = ReportUtils.get_person_mark(self.database, person)
         birth_date = ""
         birth_ref = person.get_birth_ref()
@@ -208,7 +219,7 @@ class EndOfLineReport(Report):
         names = []
         for person_handle in pedigree:
             person = self.database.get_person_from_handle(person_handle)
-            names.append(name_displayer.display(person))
+            names.append(self._name_display.display(person))
         text = " -- ".join(names)
         self.doc.start_row()
         self.doc.start_cell('EOL-TableCell')
@@ -243,6 +254,17 @@ class EndOfLineOptions(MenuReportOptions):
         pid.set_help(_("The center person for the report"))
         menu.add_option(category_name, "pid", pid)
 
+        # We must figure out the value of the first option before we can
+        # create the EnumeratedListOption
+        fmt_list = global_name_display.get_name_format()
+        name_format = EnumeratedListOption(_("Name format"), 0)
+        name_format.add_item(0, _("Default"))
+        for num, name, fmt_str, act in fmt_list:
+            name_format.add_item(num, name)
+        name_format.set_help(_("Select the format to display names"))
+        menu.add_option(category_name, "name_format", name_format)
+
+
     def make_default_style(self, default_style):
         """Make the default output style for the End of Line Report."""
         # Paragraph Styles
