@@ -6,6 +6,7 @@
 # Copyright (C) 2009      Nick Hall
 # Copyright (C) 2009      Benny Malengier
 # Copyright (C) 2010      Jakim Friant
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: IndivComplete.py 17729 2011-06-09 13:33:49Z ldnp $
+# $Id: IndivComplete.py 18915 2012-02-17 16:51:40Z romjerome $
 
 #------------------------------------------------------------------------
 #
@@ -30,6 +31,7 @@
 #
 #------------------------------------------------------------------------
 import os
+import copy
 from gen.ggettext import gettext as _
 from collections import defaultdict
 
@@ -44,15 +46,14 @@ from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle, TableStyle,
                              PARA_ALIGN_CENTER)
 import DateHandler
 from gen.plug.menu import (BooleanOption, FilterOption, PersonOption,
-                           BooleanListOption)
+                           BooleanListOption, EnumeratedListOption)
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from gen.plug.report import Bibliography
 from gen.plug.report import endnotes as Endnotes
-from gen.display.name import displayer as _nd
+from gen.display.name import displayer as global_name_display
 from Utils import media_path_full
-from QuestionDialog import WarningDialog
 
 #------------------------------------------------------------------------
 #
@@ -142,14 +143,15 @@ for event_group, type_list in GROUP_DICT.iteritems():
 #------------------------------------------------------------------------
 class IndivCompleteReport(Report):
 
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the IndivCompleteReport object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
@@ -158,23 +160,37 @@ class IndivCompleteReport(Report):
                     The option class carries its number, and the function
                     returning the list of filters.
         cites     - Whether or not to include source information.
-        sort      - Whether ot not to sort events into chronological order.
+        sort      - Whether or not to sort events into chronological order.
+        images    - Whether or not to include images.
         sections  - Which event groups should be given separate sections.
+        name_format   - Preferred format to display names
         """
 
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
+        self._user = user
 
-        menu = options_class.menu
+        menu = options.menu
+        self.use_pagebreak = menu.get_option_by_name('pageben').get_value()
         self.use_srcs = menu.get_option_by_name('cites').get_value()
+        self.use_srcs_notes = menu.get_option_by_name('incsrcnotes').get_value()
         
         self.sort = menu.get_option_by_name('sort').get_value()
 
-        filter_option = options_class.menu.get_option_by_name('filter')
+        self.use_images = menu.get_option_by_name('images').get_value()
+
+        filter_option = options.menu.get_option_by_name('filter')
         self.filter = filter_option.get_filter()
         self.bibli = None
 
         self.section_list = menu.get_option_by_name('sections').get_selected()
 
+        # Copy the global NameDisplay so that we don't change application 
+        # defaults.
+        self._name_display = copy.deepcopy(global_name_display)
+        name_format = menu.get_option_by_name("name_format").get_value()
+        if name_format != 0:
+            self._name_display.set_default_format(name_format)
+
     def write_fact(self, event_ref, event, event_group):
         """
         Writes a single event.
@@ -204,7 +220,7 @@ class IndivCompleteReport(Report):
 
         endnotes = ""
         if self.use_srcs:
-            endnotes = Endnotes.cite_source(self.bibli, event)
+            endnotes = Endnotes.cite_source(self.bibli, self.database, event)
 
         self.doc.start_row()
         self.normal_cell(column_1)
@@ -304,7 +320,7 @@ class IndivCompleteReport(Report):
             father_handle = family.get_father_handle()
             if father_handle:
                 father = self.database.get_person_from_handle(father_handle)
-                fname = _nd.display(father)
+                fname = self._name_display.display(father)
                 mark = ReportUtils.get_person_mark(self.database, father)
                 self.write_p_entry(_('Father'), fname, frel, mark)
             else:
@@ -313,7 +329,7 @@ class IndivCompleteReport(Report):
             mother_handle = family.get_mother_handle()
             if mother_handle:
                 mother = self.database.get_person_from_handle(mother_handle)
-                mname = _nd.display(mother)
+                mname = self._name_display.display(mother)
                 mark = ReportUtils.get_person_mark(self.database, mother)
                 self.write_p_entry(_('Mother'), mname, mrel, mark)
             else:
@@ -341,10 +357,10 @@ class IndivCompleteReport(Report):
             name_type = str( name.get_type() )
             self.doc.start_row()
             self.normal_cell(name_type)
-            text = _nd.display_name(name)
+            text = self._name_display.display_name(name)
             endnotes = ""
             if self.use_srcs:
-                endnotes = Endnotes.cite_source(self.bibli, name)
+                endnotes = Endnotes.cite_source(self.bibli, self.database, name)
             self.normal_cell(text, endnotes)
             self.doc.end_row()
         self.doc.end_table()
@@ -372,7 +388,7 @@ class IndivCompleteReport(Report):
             date = DateHandler.get_date(addr)
             endnotes = ""
             if self.use_srcs:
-                endnotes = Endnotes.cite_source(self.bibli, addr)
+                endnotes = Endnotes.cite_source(self.bibli, self.database, addr)
             self.doc.start_row()
             self.normal_cell(date)
             self.normal_cell(text, endnotes)
@@ -406,7 +422,7 @@ class IndivCompleteReport(Report):
             self.doc.start_paragraph("IDS-Spouse")
             if spouse_id:
                 spouse = self.database.get_person_from_handle(spouse_id)
-                text = _nd.display(spouse)
+                text = self._name_display.display(spouse)
                 mark = ReportUtils.get_person_mark(self.database, spouse)
             else:
                 text = _("unknown")
@@ -430,7 +446,7 @@ class IndivCompleteReport(Report):
                 for child_ref in child_ref_list:
                     self.doc.start_paragraph("IDS-Normal")
                     child = self.database.get_person_from_handle(child_ref.ref)
-                    name = _nd.display(child)
+                    name = self._name_display.display(child)
                     mark = ReportUtils.get_person_mark(self.database, child)
                     self.doc.write_text(name, mark)
                     self.doc.end_paragraph()
@@ -502,6 +518,10 @@ class IndivCompleteReport(Report):
 
     def normal_cell(self, text, endnotes=None, mark=None):
         self.doc.start_cell('IDS-NormalCell')
+        self.normal_paragraph(text, endnotes, mark)
+        self.doc.end_cell()
+
+    def normal_paragraph(self, text, endnotes=None, mark=None):
         self.doc.start_paragraph('IDS-Normal')
         self.doc.write_text(text, mark)
         if endnotes:
@@ -509,7 +529,6 @@ class IndivCompleteReport(Report):
             self.doc.write_text(endnotes)
             self.doc.end_superscript()
         self.doc.end_paragraph()
-        self.doc.end_cell()
 
     def write_report(self):
         plist = self.database.get_person_handles(sort_handles=True)
@@ -529,7 +548,8 @@ class IndivCompleteReport(Report):
         self.bibli = Bibliography(Bibliography.MODE_DATE|Bibliography.MODE_PAGE)
         
         media_list = self.person.get_media_list()
-        name = _nd.display(self.person)
+        name = self._name_display.display(self.person)
+        # feature request 2356: avoid genitive form
         title = _("Summary of %s") % name
         mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.start_paragraph("IDS-Title")
@@ -539,42 +559,12 @@ class IndivCompleteReport(Report):
         self.doc.start_paragraph("IDS-Normal")
         self.doc.end_paragraph()
 
-        if len(media_list) > 0:
-            media_handle = media_list[0].get_reference_handle()
-            media = self.database.get_object_from_handle(media_handle)
-            mime_type = media.get_mime_type()
-            if mime_type and mime_type.startswith("image"):
-                filename = media_path_full(self.database, media.get_path())
-                if os.path.exists(filename):
-                    self.doc.start_paragraph("IDS-Normal")
-                    self.doc.add_media_object(filename, "right", 4.0, 4.0)
-                    self.doc.end_paragraph()
-                else:
-                    WarningDialog(_("Could not add photo to page"),
-                          "%s: %s" % (filename, _('File does not exist')))
-
-        self.doc.start_table("one","IDS-IndTable")
-
-        self.doc.start_row()
-        self.normal_cell("%s:" % _("Name"))
         name = self.person.get_primary_name()
-        text = _nd.display_name(name)
+        text = self._name_display.display_name(name)
         mark = ReportUtils.get_person_mark(self.database, self.person)
         endnotes = ""
         if self.use_srcs:
-            endnotes = Endnotes.cite_source(self.bibli, name)
-        self.normal_cell(text, endnotes, mark)
-        self.doc.end_row()
-
-        self.doc.start_row()
-        self.normal_cell("%s:" % _("Gender"))
-        if self.person.get_gender() == Person.MALE:
-            self.normal_cell(_("Male"))
-        elif self.person.get_gender() == Person.FEMALE:
-            self.normal_cell(_("Female"))
-        else:
-            self.normal_cell(_("Unknown"))
-        self.doc.end_row()
+            endnotes = Endnotes.cite_source(self.bibli, self.database, name)
 
         family_handle = self.person.get_main_parents_family_handle()
         if family_handle:
@@ -583,7 +573,7 @@ class IndivCompleteReport(Report):
             if father_inst_id:
                 father_inst = self.database.get_person_from_handle(
                     father_inst_id)
-                father = _nd.display(father_inst)
+                father = self._name_display.display(father_inst)
                 fmark = ReportUtils.get_person_mark(self.database, father_inst)
             else:
                 father = ""
@@ -592,7 +582,7 @@ class IndivCompleteReport(Report):
             if mother_inst_id:
                 mother_inst = self.database.get_person_from_handle(
                     mother_inst_id) 
-                mother = _nd.display(mother_inst)
+                mother = self._name_display.display(mother_inst)
                 mmark = ReportUtils.get_person_mark(self.database, mother_inst)
             else:
                 mother = ""
@@ -603,14 +593,44 @@ class IndivCompleteReport(Report):
             mother = ""
             mmark = None
 
+        self.doc.start_table('person','IDS-PersonTable')
         self.doc.start_row()
-        self.normal_cell("%s:" % _("Father"))
-        self.normal_cell(father, mark=fmark)
-        self.doc.end_row()
 
-        self.doc.start_row()
-        self.normal_cell("%s:" % _("Mother"))
-        self.normal_cell(mother, mark=mmark)
+        self.doc.start_cell('IDS-NormalCell')
+        self.normal_paragraph("%s:" % _("Name"))
+        self.normal_paragraph("%s:" % _("Gender"))
+        self.normal_paragraph("%s:" % _("Father"))
+        self.normal_paragraph("%s:" % _("Mother"))
+        self.doc.end_cell()
+
+        self.doc.start_cell('IDS-NormalCell')
+        self.normal_paragraph(text, endnotes, mark)
+        if self.person.get_gender() == Person.MALE:
+            self.normal_paragraph(_("Male"))
+        elif self.person.get_gender() == Person.FEMALE:
+            self.normal_paragraph(_("Female"))
+        else:
+            self.normal_paragraph(_("Unknown"))
+        self.normal_paragraph(father, mark=fmark)
+        self.normal_paragraph(mother, mark=mmark)
+        self.doc.end_cell()
+
+        self.doc.start_cell('IDS-NormalCell')
+        if self.use_images and len(media_list) > 0:
+            media0 = media_list[0]
+            media_handle = media0.get_reference_handle()
+            media = self.database.get_object_from_handle(media_handle)
+            mime_type = media.get_mime_type()
+            if mime_type and mime_type.startswith("image"):
+                filename = media_path_full(self.database, media.get_path())
+                if os.path.exists(filename):
+                    self.doc.add_media_object(filename, "right", 4.0, 4.0,
+                                              crop=media0.get_rectangle())
+                else:
+                    self._user.warn(_("Could not add photo to page"),
+                          "%s: %s" % (filename, _('File does not exist')))
+        self.doc.end_cell()
+
         self.doc.end_row()
         self.doc.end_table()
 
@@ -624,7 +644,10 @@ class IndivCompleteReport(Report):
         self.write_addresses()
         self.write_note()
         if self.use_srcs:
-            Endnotes.write_endnotes(self.bibli, self.database, self.doc)
+            if self.use_pagebreak and self.bibli.get_citation_count():
+                self.doc.page_break()
+            Endnotes.write_endnotes(self.bibli, self.database, self.doc,
+                                    printnotes=self.use_srcs_notes)
             
 #------------------------------------------------------------------------
 #
@@ -656,17 +679,42 @@ class IndivCompleteOptions(MenuReportOptions):
         self.__pid.set_help(_("The center person for the filter."))
         menu.add_option(category_name, "pid", self.__pid)
         self.__pid.connect('value-changed', self.__update_filters)
+
+        # We must figure out the value of the first option before we can
+        # create the EnumeratedListOption
+        fmt_list = global_name_display.get_name_format()
+        name_format = EnumeratedListOption(_("Name format"), 0)
+        name_format.add_item(0, _("Default"))
+        for num, name, fmt_str, act in fmt_list:
+            name_format.add_item(num, name)
+        name_format.set_help(_("Select the format to display names"))
+        menu.add_option(category_name, "name_format", name_format)
+
         
         self.__update_filters()
         
         sort = BooleanOption(_("List events chronologically"), True)
         sort.set_help(_("Whether to sort events into chronological order."))
         menu.add_option(category_name, "sort", sort)
+
+        pageben = BooleanOption(_("Page break before end notes"),False)
+        pageben.set_help(
+                     _("Whether to start a new page before the end notes."))
+        menu.add_option(category_name, "pageben", pageben)
         
         cites = BooleanOption(_("Include Source Information"), True)
         cites.set_help(_("Whether to cite sources."))
         menu.add_option(category_name, "cites", cites)
 
+        incsrcnotes = BooleanOption(_("Include sources notes"), False)
+        incsrcnotes.set_help(_("Whether to include source notes in the "
+            "Endnotes section. Only works if Include sources is selected."))
+        menu.add_option(category_name, "incsrcnotes", incsrcnotes)
+
+        images = BooleanOption(_("Include Photo/Images from Gallery"), True)
+        images.set_help(_("Whether to include images."))
+        menu.add_option(category_name, "images", images)
+
         ################################
         category_name = SECTION_CATEGORY
         ################################
@@ -774,6 +822,14 @@ class IndivCompleteOptions(MenuReportOptions):
         cell.set_longlist(1)
         default_style.add_cell_style("IDS-ListCell", cell)
         
+        tbl = TableStyle()
+        tbl.set_width(100)
+        tbl.set_columns(3)
+        tbl.set_column_width(0,20)
+        tbl.set_column_width(1,40)
+        tbl.set_column_width(2,40)
+        default_style.add_table_style('IDS-PersonTable', tbl)
+
         Endnotes.add_endnote_styles(default_style)
 
 #------------------------------------------------------------------------
