@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Summary.py 17495 2011-05-14 13:58:44Z romjerome $
+# $Id: Summary.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Reports/Text Reports/Database Summary Report.
@@ -42,7 +42,7 @@ from gen.ggettext import gettext as _
 import gen.lib
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
                     FONT_SANS_SERIF, INDEX_TYPE_TOC, PARA_ALIGN_CENTER)
 from Utils import media_path_full
@@ -58,17 +58,18 @@ class SummaryReport(Report):
     """
     This report produces a summary of the objects in the database.
     """
-    def __init__(self, database, options_class):
+    def __init__(self, database, options, user):
         """
         Create the SummaryReport object that produces the report.
         
         The arguments are:
 
         database        - the GRAMPS database instance
-        options_class   - instance of the Options class for this report
+        options         - instance of the Options class for this report
+        user            - a gen.user.User() instance
 
         """
-        Report.__init__(self, database, options_class)
+        Report.__init__(self, database, options, user)
         self.__db = database
         
     def write_report(self):
