@@ -4,7 +4,7 @@
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2008       Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
-# Copyright (C) 2011       PaulFranklin
+# Copyright (C) 2011       Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Verify.py 19449 2012-05-06 09:45:24Z m_d_n $
+# $Id: Verify.py 19450 2012-05-06 09:46:29Z m_d_n $
 
 """
 A plugin to verify the data against user-adjusted tests.
@@ -81,6 +81,7 @@ WIKI_HELP_SEC = _('manual|Verify_the_Data...')
 _person_cache = {}
 _family_cache = {}
 _event_cache = {}
+_today = gen.lib.date.Today().get_sort_value()
 
 def find_event(db, handle):
     if handle in _event_cache:
@@ -365,6 +366,7 @@ class Verify(tool.Tool, ManagedWindow, UpdateCallback):
                 BirthAfterDeath(self.db,person),
                 BaptAfterBury(self.db,person),
                 OldAge(self.db,person, oldage,estimate_age),
+                OldAgeButNoDeath(self.db,person, oldage,estimate_age),
                 UnknownGender(self.db,person),
                 MultipleParents(self.db,person),
                 MarriedOften(self.db,person,wedder),
@@ -527,7 +529,7 @@ class VerifyResults(ManagedWindow):
     def load_ignored(self,db_filename):
         md5sum = md5(db_filename)
         self.ignores_filename = os.path.join(
-            const.HOME_DIR,md5sum.hexdigest() + os.path.extsep + 'vfm')
+            const.VERSION_DIR,md5sum.hexdigest() + os.path.extsep + 'vfm')
         if not self._load_ignored(self.ignores_filename):
             self.ignores = {}
 
@@ -742,7 +744,7 @@ class VerifyOptions(tool.ToolOptions):
                               "Number of years"),
             'oldunm'       : ("=num","Maximum age for an unmarried person"
                               "Number of years"),
-            'estimate_age' : ("=0/1","Whether to estimate missing dates",
+            'estimate_age' : ("=0/1","Whether to estimate missing or inexact dates",
                               ["Do not estimate","Estimate dates"],
                               True),
             'invdate'      : ("=0/1","Whether to check for invalid dates"
@@ -1545,3 +1547,26 @@ class MarriedRelation(FamilyRule):
 
     def get_message(self):
         return _("Marriage date but not married")
+
+class OldAgeButNoDeath(PersonRule):
+    ID = 32
+    SEVERITY = Rule.WARNING
+    def __init__(self,db,person, old_age,est):
+        PersonRule.__init__(self,db,person)
+        self.old_age = old_age
+        self.est = est
+
+    def _get_params(self):
+        return (self.old_age,self.est)
+
+    def broken(self):
+        birth_date = get_birth_date(self.db,self.obj,self.est)
+        dead = get_death_date(self.db,self.obj,True) # if no death use burial
+        if dead or not birth_date:
+            return 0
+        age = ( _today - birth_date ) / 365
+        return ( age > self.old_age )
+
+    def get_message(self):
+        return _("Old age but no death")
+
