@@ -3,6 +3,7 @@
 # Copyright (C) 2001-2006  Donald N. Allingham
 # Copyright (C) 2008       Gary Burton
 # Copyright (C) 2010       Nick Hall
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: mediaview.py 17446 2011-05-07 18:41:14Z nick-h $
+# $Id: mediaview.py 18548 2011-12-04 17:09:17Z kulath $
 
 """
 Media View.
@@ -425,7 +426,7 @@ class MediaView(ListView):
         """
         return (("Media Filter",),
                 ("Media Preview",
-                 "Media Sources",
+                 "Media Citations"
                  "Media Notes",
                  "Media Attributes",
                  "Metadata Viewer",
