@@ -1,4 +1,4 @@
-# encoding: utf-8
+#!/usr/bin/python
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: WebCal.py 19314 2012-04-13 16:07:20Z romjerome $
+# $Id: WebCal.py 19315 2012-04-13 16:08:49Z romjerome $
 
 """
 Web Calendar generator.
@@ -53,14 +53,12 @@ import const
 import constfunc
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
-from gui.plug.report import MenuReportOptions
+from gen.plug.report import MenuReportOptions
 from gen.plug.menu import BooleanOption, NumberOption, StringOption, \
                           EnumeratedListOption, FilterOption, PersonOption, \
                           DestinationOption, NoteOption
 import GrampsLocale
-from QuestionDialog import WarningDialog
 from Utils import probably_alive, xml_lang, get_researcher
-from gui.utils import ProgressMeter
 from DateHandler import displayer as _dd
 
 from gen.display.name import displayer as _nd
@@ -74,9 +72,7 @@ from gui.pluginmanager import GuiPluginManager
 # src/plugins/lib/libhtmlbackend.py
 from libhtmlbackend import HtmlBackend
 #------------------------------------------------------------------------
-#
 # constants
-#
 #------------------------------------------------------------------------
 # full clear line for proper styling
 fullclear = Html("div", class_ = "fullclear", inline = True)
@@ -100,9 +96,10 @@ class WebCalReport(Report):
     """
     Create WebCalReport object that produces the report.
     """
-    def __init__(self, database, options):
-        Report.__init__(self, database, options)
+    def __init__(self, database, options, user):
+        Report.__init__(self, database, options, user)
         mgobn = lambda name:options.menu.get_option_by_name(name).get_value()
+        self._user = user
 
         # class to do conversion of styled notes to html markup
         self._backend = HtmlBackend()
@@ -242,7 +239,7 @@ class WebCalReport(Report):
         if from_fname != dest:
             shutil.copyfile(from_fname, dest)
         elif self.warn_dir:
-            WarningDialog(
+            self._user.warn(
                 _("Possible destination error") + "\n" +
                 _("You appear to have set your target directory "
                   "to a directory used for data storage. This "
@@ -252,9 +249,6 @@ class WebCalReport(Report):
                   "web pages."))
             self.warn_dir = False
 
-# ---------------------------------------------------------------------------------------
-#                Adds Birthdays, Anniversaries, and holidays
-# ---------------------------------------------------------------------------------------
     def add_day_item(self, text, year, month, day, event):
         """
         adds birthdays, anniversaries, and holidays to their perspective lists
@@ -294,14 +288,12 @@ class WebCalReport(Report):
         else:
             self.holidays[month] = month_dict
 
-# ---------------------------------------------------------------------------------------
-#         Retrieves Holidays from the Holiday file, 
-#         src/plugins/lib/holidays.xml
-# ---------------------------------------------------------------------------------------
     def __get_holidays(self, year):
 
         # _('translation')
-        self.progress.set_pass((_('Calculating Holidays for year %04d') % year), 365)
+        self._user.begin_progress(_("Web Calendar Report"),
+                                  (_('Calculating Holidays for year %04d') % year),
+                                  365)
 
         """ Get the holidays for the specified country and year """
         holiday_table = libholiday.HolidayTable()
@@ -312,13 +304,9 @@ class WebCalReport(Report):
                 holiday_names = holiday_table.get_holidays(month, day) 
                 for holiday_name in holiday_names:
                     self.add_day_item(holiday_name, year, month, day, 'Holiday')
+                self._user.step_progress()
+        self._user.end_progress()
 
-                # increment progress bar
-                self.progress.step() 
-
-# ---------------------------------------------------------------------------------------
-#          Copies all of the calendar files for all calendars
-# ---------------------------------------------------------------------------------------
     def copy_calendar_files(self):
         """
         Copies all the necessary stylesheets and images for these calendars
@@ -330,8 +318,8 @@ class WebCalReport(Report):
 
         # copy Navigation Menu Layout if Blue or Visually is being used
         if CSS[self.css]["navigation"]:
-            fname = CSS["Navigation-Horizontal"]["filename"] 
-            self.copy_file(fname, "Web_Navigation-Menus.css", "styles")
+            fname = CSS["Horizontal-Menus"]["filename"]
+            self.copy_file(fname, "calendar-menus.css", "styles")
 
         # copy print stylesheet
         fname = CSS["Print-Default"]["filename"]
@@ -355,9 +343,6 @@ class WebCalReport(Report):
             fdir, fname = os.path.split(from_path)
             self.copy_file(from_path, fname, "images")
 
-# ---------------------------------------------------------------------------------------
-#                     Creates file name passed to it
-# ---------------------------------------------------------------------------------------
     def create_file(self, fname, subdir):
         """
         Create a file in the html_dir tree.
@@ -380,16 +365,10 @@ class WebCalReport(Report):
         of = codecs.EncodedFile(open(fname, "w"), 'utf-8', self.encoding, 'xmlcharrefreplace')
         return of
 
-# ---------------------------------------------------------------------------------------
-#                             Closes all file name passed to it
-# ---------------------------------------------------------------------------------------
     def close_file(self, of):
         """ will close whatever filename is passed to it """
         of.close()
 
-# ---------------------------------------------------------------------------------------
-#                       Beginning of Calendar Creation
-# ---------------------------------------------------------------------------------------
     def write_header(self, nr_up, title, body_id = None, add_print = True):
         """
         This creates the header for the Calendars
@@ -405,11 +384,23 @@ class WebCalReport(Report):
 
         # Header contants
         xmllang = xml_lang()
-        _META1 = 'name="generator" content="%s %s %s"' % \
-                    (const.PROGRAM_NAME, const.VERSION, const.URL_HOMEPAGE)
-        _META2 = 'name="author" content="%s"' % self.author
+        _META1 = 'name ="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=1"'
+        _META2 = 'name ="apple-mobile-web-app-capable" content="yes"'
+        _META3 = 'name="generator" content="%s %s %s"' % (
+                    const.PROGRAM_NAME, const.VERSION, const.URL_HOMEPAGE)
+        _META4 = 'name="author" content="%s"' % self.author
 
-        page, head, body = Html.page(title, self.encoding, xmllang)
+        # create additional meta tags
+        meta = Html("meta", attr = _META1) + (
+                Html("meta", attr = _META2, indent = False),
+                Html("meta", attr = _META3, indent =False),
+                Html("meta", attr = _META4, indent = False)
+        )
+
+        # begin each html page...
+        page, head, body = Html.page(title,
+                                     self.encoding,
+                                     xmllang)
 
         # add body id tag if not None
         if body_id is not None:
@@ -421,59 +412,47 @@ class WebCalReport(Report):
         # _CALENDARSCREEN stylesheet
         fname2 = "/".join(subdirs + ["styles", _CALENDARSCREEN])
 
-        # create additional meta tags
-        meta = Html("meta", attr = _META1) + (
-            Html("meta", attr = _META2, indent=False)
-            )
-
         # links for GRAMPS favicon and stylesheets
         links = Html("link", rel = 'shortcut icon', href = fname1, type = "image/x-icon") + (
-            Html("link",rel = "stylesheet", href = fname2, type = "text/css", media = "screen", indent = False)
+            Html("link",href = fname2, type = "text/css", media = "screen", rel = "stylesheet", indent = False)
+        )
+
+        # add horizontal menu if css == Blue or Visually because there is no menus?
+        if CSS[self.css]["navigation"]:
+            fname = "/".join(subdirs + ["styles", "calendar-menus.css"])
+            links.extend( 
+                Html("link", href = fname, type = "text/css", media = "screen", rel = "stylesheet", indent = False)
             )
 
         # add printer stylesheet to webcalendar() and one_day() only
         if add_print:
             fname = "/".join(subdirs + ["styles", _CALENDARPRINT])
-            links += Html("link",rel = "stylesheet", href = fname,type = "text/css", media = "print", indent = False)
-
-        # add horizontal menu if css == Blue or Visually because there is no menus
-        if CSS[self.css]["navigation"]:
-
-            # Link to Navigation Menus stylesheet
-            fname = "/".join(subdirs + ["styles", "Web_Navigation-Menus.css"])
-            links.extend( 
-                Html("link", href = fname, type = "text/css", media = "screen", rel = "stylesheet")
+            links.extend(
+                Html("link",href = fname,type = "text/css", media = "print", rel = "stylesheet", indent = False)
             )
 
         # add meta tags and links to head section
         head += (meta, links)
 
-        # start header division section
-        header = Html("div", id = "header") + (
+        # start header section and page title...
+        with Html("div", id = "header", role = "Title-n-Navigation") as header:
+            header += Html("h1", title, id = "SiteTitle", inline = True)
 
-            # page title 
-            Html("h1", title, id = "SiteTitle", inline = True)
-            )
-        body += header
+            # Created for ?
+            msg = None
+            if self.author and self.email:  
+                msg = _('Created for <a href="mailto:%(email)s?'
+                        'subject=WebCal">%(author)s</a>') % {'email'  : self.email,
+                                                             'author' : self.author}
+            elif self.author:
+                msg = _('Created for %(author)s') % {'author' : self.author}
 
-        # Created for ?
-        msg = None
-        if self.author and self.email:  
-            msg = _('Created for <a href="mailto:%(email)s?'
-                    'subject=WebCal">%(author)s</a>') % {'email'  : self.email,
-                                                         'author' : self.author}
-        elif self.author:
-            msg = _('Created for %(author)s') % {'author' : self.author}
+            if msg:
+                header += Html("p", msg, id = "CreatorInfo")
 
-        if msg is not None:
-            header += Html("p", msg, id = "CreatorInfo")
-
-        # return to its callers; either webcalendar(), year_glance(), or one_day()
+            body += header 
         return page, body
 
-# ---------------------------------------------------------------------------------------
-#                        Creates year navigation, if multiyear
-# ---------------------------------------------------------------------------------------
     def year_navigation(self, nr_up, currentsection):
         """
         This will create the year navigation menu bar for a total of seventeen (17) years
@@ -487,9 +466,8 @@ class WebCalReport(Report):
         num_years = nyears if 0 < nyears < 19 else 18
 
         # begin year division and begin unordered list
-        with Html("div", id = "subnavigation") as section: 
+        with Html("div", id = "subnavigation", role = "subnavigation") as submenu:
             unordered = Html("ul")
-            section += unordered
 
             for cal_year in xrange(self.start_year, (self.start_year + num_years)):
                 url = ''
@@ -500,27 +478,26 @@ class WebCalReport(Report):
 
                 # each year will link to current month.
                 # this will always need an extension added
-                full_month_name = get_full_month_name(self.today.get_month())
+                full_month_name = _dd.long_months[self.today.get_month() ]
 
                 # Note. We use '/' here because it is a URL, not a OS dependent 
                 # pathname.
                 url = '/'.join(subdirs + [full_month_name]) + self.ext
+                hyper = Html("a", str(cal_year), href = url, title = str(cal_year))
 
                 # Figure out if we need <li class="CurrentSection"> or just plain <li>
-                cs = str(cal_year) == currentsection and 'class="CurrentSection"' or ''
-                unordered += Html("li", attr = cs, inline = True) + (
-
-                    # create hyperlink
-                    Html("a", str(cal_year), href = url, title = _("Sub Navigation Menu Item: "
-                        "Year %04d" % cal_year), inline = True)
+                check_cs = str(cal_year) == currentsection and 'class = "CurrentSection"' or False
+                if check_cs:
+                    unordered.extend(
+                        Html("li", hyper, attr = check_cs, inline = True)
                     )
+                else:
+                    unordered.extend(
+                        Html("li", hyper, inline = True)
+                    )
+            submenu += unordered
+        return submenu
 
-        # return yearnav to its caller
-        return section
-
-# ---------------------------------------------------------------------------------------
-#                     Creates month navigation for all Calendars
-# ---------------------------------------------------------------------------------------
     def month_navigation(self, nr_up, year, currentsection, add_home):
         """
         Will create and display the navigation menu bar
@@ -532,65 +509,68 @@ class WebCalReport(Report):
         use_home = if creating a link to home 
             -- a link to root directory of website
         """
-
         navs = []
 
         # An optional link to a home page
         if self.home_link:
-            navs.append((self.home_link,  _('html|Home'),  add_home))
+            navs.append((self.home_link,  _('Home'),  add_home))
         navs.extend(
-            (month, month, True) for month in range(1,13)
-        )
+            (_dd.long_months[month], _dd.short_months[month], True) for month in xrange(1, 13) )
 
         # Add a link for year_glance() if requested
         navs.append(('fullyearlinked', _('Year Glance'), self.fullyear))
 
+        # remove menu items if they are not True
+        navs = [(u, n) for u, n, c in navs if c]
+
         # begin month subnavigation
-        with Html("div", id = "navigation") as section:
+        with Html("div", class_ = "wrapper", id = "nav", role = "navigation") as navigation:
+            with Html("div", class_ = "container") as container:
 
-            unordered = Html("ul")
-            section += unordered 
+                unordered = Html("ul", class_ = "menu")
 
-            navs = [(u, n) for u, n, c in navs if c]
-            for url_fname, nav_text in navs:
+                for url_fname, nav_text in navs:
 
-                if type(url_fname) == int:
-                    url_fname = get_full_month_name(url_fname)
-
-                if type(nav_text) == int:
-                    nav_text = get_short_month_name(nav_text)
-
-                # Note. We use '/' here because it is a URL, not a OS dependent pathname
-                # need to leave home link alone, so look for it ...
-                url = url_fname
-                add_subdirs = True
-                if not (url.startswith('http:') or url.startswith('/')):
-                    add_subdirs = not any(url.endswith(ext)
-                                            for ext in _WEB_EXT)
+                    # Note. We use '/' here because it is a URL, not a OS dependent pathname
+                    # need to leave home link alone, so look for it ...
+                    url = url_fname
+                    add_subdirs = True
+                    if not (url.startswith('http:') or url.startswith('/')):
+                        add_subdirs = not any(url.endswith(ext)
+                                                for ext in _WEB_EXT)
                          
-                # whether to add subdirs or not???
-                if add_subdirs: 
-                    subdirs = ['..'] * nr_up
-                    subdirs.append(str(year)) 
-                    url = '/'.join(subdirs + [url_fname])
+                    # whether to add subdirs or not???
+                    if add_subdirs: 
+                        subdirs = ['..'] * nr_up
+                        subdirs.append(str(year)) 
+                        url = '/'.join(subdirs + [url_fname])
 
-                if not _has_webpage_extension(url):
-                    url += self.ext
+                    if not _has_webpage_extension(url):
+                        url += self.ext
 
-                # Figure out if we need <li class="CurrentSection"> or just plain <li>
-                cs = url_fname == currentsection and 'class="CurrentSection"' or ''
-                unordered += Html("li", attr = cs, inline = True) + (
+                    # Figure out if we need <li class="CurrentSection"> or just plain <li>
+                    check_cs = url_fname == currentsection and 'class = "CurrentSection"' or False
 
-                    # create hyperlink
-                    Html("a", nav_text, href = url, title = _("Main Navigation Menu Item: %s") % url_fname, inline = True)
-                    )
+                    if url == self.home_link:
+                        myTitle = _("NarrativeWeb Home")
+                    elif url_fname == 'fullyearlinked':
+                        myTitle = _('Full year at a Glance')
+                    else:
+	                 myTitle = _(url_fname)
+                    hyper = Html("a", nav_text, href = url, name = url_fname, title = myTitle)
 
-        # return monthnav to its caller
-        return section
+                    if check_cs:
+                        unordered.extend(
+                            Html("li", hyper, attr = check_cs, inline = True)
+                        )
+                    else:
+                        unordered.extend(
+                            Html("li", hyper, inline = True)
+                        )
+                container += unordered
+            navigation += container
+        return navigation
 
-# ---------------------------------------------------------------------------------------
-#                            Creates the Calendar Table
-# ---------------------------------------------------------------------------------------
     def calendar_build(self, cal, year, month):
         """
         This does the work of building the calendar
@@ -601,8 +581,8 @@ class WebCalReport(Report):
         """
 
         # define names for long and short month names
-        full_month_name = get_full_month_name(month)
-        abbr_month_name = get_short_month_name(month)
+        full_month_name = _dd.long_months[month]
+        abbr_month_name = _dd.short_months[month]
 
         # dow (day-of-week) uses Gramps numbering, sunday => 1, etc
         start_dow = self.start_dow
@@ -629,11 +609,11 @@ class WebCalReport(Report):
         def __get_previous_month_day(year, month, day_col):
 
             if month == 1:
-                prevmonth = calendar.monthcalendar(year - 1, 12)
+                prevmonth = calendar.monthcalendar((year - 1), 12)
             else:
-                prevmonth = calendar.monthcalendar(year, month-1)
+                prevmonth = calendar.monthcalendar(year, (month - 1))
             num_weeks = len(prevmonth)
-            lastweek_prevmonth = prevmonth[num_weeks - 1]
+            lastweek_prevmonth = prevmonth[(num_weeks - 1)]
             previous_month_day = lastweek_prevmonth[day_col]
 
             # return previous month day number based on day_col
@@ -643,9 +623,9 @@ class WebCalReport(Report):
         def __get_next_month_day(year, month, day_col):  
 
             if month == 12:
-                nextmonth = calendar.monthcalendar(year + 1, 1)
+                nextmonth = calendar.monthcalendar((year + 1), 1)
             else:
-                nextmonth = calendar.monthcalendar(year, month + 1)
+                nextmonth = calendar.monthcalendar(year, (month + 1))
             firstweek_nextmonth = nextmonth[0]
             next_month_day = firstweek_nextmonth[day_col]
 
@@ -659,11 +639,10 @@ class WebCalReport(Report):
         th_txt = month_name
         if cal == 'wc': # webcalendar()
             if not self.multiyear:
-                th_txt = '%s %d' % (month_name, year)
+                th_txt = '%s %04d' % (month_name, year)
 
         # begin calendar table and table head
-        with Html("table", class_ = "calendar", id = month_name) as table:
-
+        with Html("table", class_ = "calendar", id = month_name, role = "Calendar-Grid") as table:
             thead = Html("thead")
             table += thead 
 
@@ -680,8 +659,7 @@ class WebCalReport(Report):
                 dayclass = get_class_for_daycol(day_col)
                 dayname = get_name_for_daycol(day_col)
                 trow += Html("th", class_ =dayclass, inline = True) + (
-                    Html('abbr', dayname[0], title = dayname)
-                    )
+                    Html('abbr', dayname[0], title = dayname) )
 
             # begin table body
             tbody = Html("tbody")
@@ -712,10 +690,10 @@ class WebCalReport(Report):
                     # add calendar date division
                     datediv = Html("div", day, class_ = "date", inline = True)
 
-                    # a day in the previous or next month
+                    ### a day in the previous or next month ###
                     if day == 0:
 
-                        # day in previous month
+                        # day in previous/ next month
                         specday = __get_previous_month_day(year, month, day_col) if week_row == 0 \
                             else __get_next_month_day(year, month, day_col) 
 
@@ -724,10 +702,7 @@ class WebCalReport(Report):
 
                         # continue table cell, <td>, without id tag
                         tcell = Html("td", class_ = specclass, inline = True) + (
-
-                            # adds date for previous and next month days
-                            Html("div", specday, class_ = "date", inline = True)
-                            )
+                            Html("div", specday, class_ = "date", inline = True) )
 
                     # normal day number in current month
                     else: 
@@ -828,9 +803,6 @@ class WebCalReport(Report):
         # return calendar table to its callers
         return table
 
-# ---------------------------------------------------------------------------------------
-#   Creates the Web Calendars; the primary part of this plugin
-# ---------------------------------------------------------------------------------------
     def webcalendar(self, year):
         """
         This method provides information and header/ footer to the calendar month
@@ -845,11 +817,11 @@ class WebCalReport(Report):
 
         nr_up = 1                   # Number of directory levels up to get to self.html_dir / root
 
-        # generate progress pass for "WebCal"
-        self.progress.set_pass(_('Formatting months ...'), 12)
+        self._user.begin_progress(_("Web Calendar Report"),
+                                  _('Formatting months ...'), 12)
 
         for month in range(1, 13):
-            cal_fname = get_full_month_name(month)
+            cal_fname = _dd.long_months[month]
             of = self.create_file(cal_fname, str(year))
 
             # Add xml, doctype, meta and stylesheets
@@ -862,7 +834,7 @@ class WebCalReport(Report):
 
             # Create Month Navigation Menu
             # identify currentsection for proper highlighting
-            currentsection = get_full_month_name(month)
+            currentsection = _dd.long_months[month]
             body += self.month_navigation(nr_up, year, currentsection, True)
 
             # build the calendar
@@ -872,6 +844,7 @@ class WebCalReport(Report):
             content += monthly_calendar
 
             # create note section for webcalendar()
+            # One has to be minused because the array starts at zero, but January =1
             note = self.month_notes[month-1].strip()
             if note:
                 note = self.database.get_note_from_gramps_id(note)
@@ -895,12 +868,9 @@ class WebCalReport(Report):
             # and close the file
             self.XHTMLWriter(webcal, of)
 
-            # increase progress bar
-            self.progress.step()
+            self._user.step_progress()
+        self._user.end_progress()
 
-# ---------------------------------------------------------------------------------------
-#                    Creates Year At A Glance Calendar
-# ---------------------------------------------------------------------------------------
     def year_glance(self, year):
         """
         This method will create the Full Year At A Glance Page...
@@ -910,7 +880,8 @@ class WebCalReport(Report):
         nr_up = 1                       # Number of directory levels up to get to root
 
         # generate progress pass for "Year At A Glance"
-        self.progress.set_pass(_('Creating Year At A Glance calendar'), 12)
+        self._user.begin_progress(_("Web Calendar Report"),
+                                  _('Creating Year At A Glance calendar'), 12)
 
         of = self.create_file('fullyearlinked', str(year))
 
@@ -947,7 +918,7 @@ class WebCalReport(Report):
             content += monthly_calendar  
 
             # increase progress bar
-            self.progress.step()
+            self._user.step_progress()
 
         # create blank line for stylesheets
         # write footer section
@@ -957,10 +928,8 @@ class WebCalReport(Report):
         # send calendar page to web output
         # and close the file
         self.XHTMLWriter(yearglance, of)
+        self._user.end_progress()
 
-# ---------------------------------------------------------------------------------------
-#               Creates the individual days for year_glance()
-# ---------------------------------------------------------------------------------------
     def one_day(self, event_date, fname_date, day_list):
         """
         This method creates the One Day page for "Year At A Glance"
@@ -994,7 +963,7 @@ class WebCalReport(Report):
 
         # Create Month Navigation Menu
         # identify currentsection for proper highlighting
-        currentsection = get_full_month_name(month)
+        currentsection = _dd.long_months[month]
         body += self.month_navigation(nr_up, year, currentsection, True)
 
         # set date display as in user prevferences 
@@ -1017,9 +986,6 @@ class WebCalReport(Report):
         # and close the file 
         self.XHTMLWriter(oneday, od)
 
-######################################################################################
-#                  Support Functions for linking to Narratted Web Site
-######################################################################################
     def build_url_fname_html(self, fname, subdir=None, prefix=None):
         return self.build_url_fname(fname, subdir, prefix) + self.ext
 
@@ -1057,9 +1023,6 @@ class WebCalReport(Report):
             subdirs.append(fname[-2].lower())
         return subdirs
 
-# ---------------------------------------------------------------------------------------
-#                             Get person's short name
-# ---------------------------------------------------------------------------------------
     def get_name(self, person, maiden_name = None):
         """ 
         Return person's name, unless maiden_name given, unless married_name 
@@ -1090,9 +1053,6 @@ class WebCalReport(Report):
         name.set_display_as(self.name_format)
         return _nd.display_name(name)
 
-# ---------------------------------------------------------------------------------------
-#        The database slave; Gathers information for calendars
-# ---------------------------------------------------------------------------------------
     def collect_data(self, this_year):
         """
         This method runs through the data, and collects the relevant dates
@@ -1101,12 +1061,16 @@ class WebCalReport(Report):
         db = self.database
 
         people = db.iter_person_handles()
-        self.progress.set_pass(_('Applying Filter...'), db.get_number_of_people())
-        people = self.filter.apply(db, people, self.progress)
+        self._user.begin_progress(_("Web Calendar Report"),
+                                  _('Applying Filter...'), 
+                                  db.get_number_of_people())
+        people = self.filter.apply(db, people, self._user.step_progress)
+        self._user.end_progress()
 
-        self.progress.set_pass(_("Reading database..."), len(people))
+        self._user.begin_progress(_("Web Calendar Report"),
+                                  _("Reading database..."), len(people))
         for person in imap(db.get_person_from_handle, people):
-            self.progress.step()
+            self._user.step_progress()
 
             family_list = person.get_family_handle_list()
             birth_ref = person.get_birth_ref()
@@ -1204,10 +1168,8 @@ class WebCalReport(Report):
                                         'person' : short_name}
 
                                     self.add_day_item(text, year, month, day, 'Anniversary')
-
-# ---------------------------------------------------------------------------------------
-#                                Closes the Calendars; the end
-# ---------------------------------------------------------------------------------------
+        self._user.end_progress()
+        
     def write_footer(self, nr_up):
         """
         Writes the footer section of the pages
@@ -1216,7 +1178,7 @@ class WebCalReport(Report):
         """
 
         # begin calendar footer
-        with Html("div", id = "footer") as footer:
+        with Html("div", id = "footer", role = "Footer-End") as footer:
 
             # Display date as user set in preferences
             msg = _('Generated by <a href="http://gramps-project.org">'
@@ -1242,9 +1204,6 @@ class WebCalReport(Report):
         # return footer to its callers
         return footer
 
-# ---------------------------------------------------------------------------------------
-#              # Web Page Fortmatter and writer                   
-# ---------------------------------------------------------------------------------------
     def XHTMLWriter(self, page, of):
         """
         This function is simply to make the web page look pretty and readable
@@ -1258,17 +1217,10 @@ class WebCalReport(Report):
         # close the file now...
         self.close_file(of)
 
-# ---------------------------------------------------------------------------------------
-#             The work horse of this plugin; stages everything
-# ---------------------------------------------------------------------------------------
     def write_report(self):
         """
         The short method that runs through each month and creates a page. 
         """
-
-        # Create progress meter bar
-        self.progress = ProgressMeter(_("Web Calendar Report"), '')
-
         # get data from database for birthdays/ anniversaries
         self.collect_data(self.start_year)
 
@@ -1316,9 +1268,6 @@ class WebCalReport(Report):
             if self.fullyear:
                 self.year_glance(cal_year)
 
-        # Close the progress meter
-        self.progress.close()
-
 # ---------------------------------------------------------------------------------------
 #                             WebCalOptions; Creates the Menu
 #----------------------------------------------------------------------------------------
@@ -1619,9 +1568,6 @@ class WebCalOptions(MenuReportOptions):
         else:
             self.__prefix.set_available(False)
 
-# ---------------------------------------------------------------------------------------
-#                        Support Functions for this plugin
-# ---------------------------------------------------------------------------------------
 def _get_regular_surname(sex, name):
     """
     Returns a name string built from the components of the Name instance.
@@ -1638,18 +1584,6 @@ dow_gramps2iso = [ -1, calendar.SUNDAY, calendar.MONDAY, calendar.TUESDAY,
                    calendar.WEDNESDAY, calendar.THURSDAY, calendar.FRIDAY,
                    calendar.SATURDAY]
 
-# define names for full and abbreviated month names in GrampsLocale
-full_month_name = _dd.long_months
-abbr_month_name = _dd.short_months
-
-def get_full_month_name(month):
-    """ returns full or long month name """
-    return full_month_name[month]
-
-def get_short_month_name(month):
-    """ return short or abbreviated month name """
-    return abbr_month_name[month]   
-
 def get_marriage_event(db, family):
     """
     marriage_event will either be the marriage event or False
@@ -1692,9 +1626,6 @@ def _has_webpage_extension(url):
     """
     return any(url.endswith(ext) for ext in _WEB_EXT)
 
-# ---------------------------------------------------------------------------------------
-#                   Gets individual events for each day
-# ---------------------------------------------------------------------------------------
 def get_day_list(event_date, holiday_list, bday_anniv_list):
     """
     Will fill day_list and return it to its caller: calendar_build()
