@@ -19,8 +19,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: $
+# $Id: webstuff.py 18897 2012-02-16 05:18:23Z robhealey1 $
 
+#------------------------------------------------
+#    python modules
+#------------------------------------------------
 import os
 import const
 from gen.ggettext import sgettext as _
@@ -55,27 +58,27 @@ def load_on_reg(dbstate, uistate, plugin):
 
         # Basic Ash style sheet
         ["Basic-Ash",     1, _("Basic-Ash"),         
-         path_css('Web_Basic-Ash.css'),     None, [], []],
+         path_css('Web_Basic-Ash.css'),     None, [], [] ],
 
         # Basic Blue style sheet with navigation menus
         ["Basic-Blue",    1, _("Basic-Blue"),        
-         path_css('Web_Basic-Blue.css'),    "narrative-menus.css", [], []],
+         path_css('Web_Basic-Blue.css'),    "narrative-menus.css", [], [] ],
 
         # Basic Cypress style sheet
         ["Basic-Cypress", 1, _("Basic-Cypress"),     
-         path_css('Web_Basic-Cypress.css'), None, [], []],
+         path_css('Web_Basic-Cypress.css'), None, [], [] ],
 
         # basic Lilac style sheet
         ["Basic-Lilac",   1, _("Basic-Lilac"),       
-         path_css('Web_Basic-Lilac.css'),   None, [], []],
+         path_css('Web_Basic-Lilac.css'),   None, [], [] ],
 
         # basic Peach style sheet
         ["Basic-Peach",   1, _("Basic-Peach"),       
-         path_css('Web_Basic-Peach.css'),   None, [], []],
+         path_css('Web_Basic-Peach.css'),   None, [], [] ],
 
         # basic Spruce style sheet
         ["Basic-Spruce",  1, _("Basic-Spruce"),      
-         path_css('Web_Basic-Spruce.css'),  None, [], []],
+         path_css('Web_Basic-Spruce.css'),  None, [], [] ],
 
         # Mainz style sheet with its images
         ["Mainz",         1, _("Mainz"),             
@@ -83,48 +86,53 @@ def load_on_reg(dbstate, uistate, plugin):
          [path_img("Web_Mainz_Bkgd.png"), 
           path_img("Web_Mainz_Header.png"), 
           path_img("Web_Mainz_Mid.png"), 
-          path_img("Web_Mainz_MidLight.png")], []],
+          path_img("Web_Mainz_MidLight.png")], [] ],
 
         # Nebraska style sheet
         ["Nebraska",      1, _("Nebraska"),          
-         path_css('Web_Nebraska.css'),      None, [], []],
+         path_css('Web_Nebraska.css'),      None, [], [] ],
 
         # Visually Impaired style sheet with its navigation menus
         ["Visually Impaired", 1, _("Visually Impaired"), 
-         path_css('Web_Visually.css'),  "narrative-menus.css", [], []],
-
-        # no style sheet option
-        ["No style sheet",1, _("No style sheet"),    [],    None, [], []],
+         path_css('Web_Visually.css'),  "narrative-menus.css", [], [] ],
 
         # ancestor tree style sheet and its images
         ["ancestortree",  0, "ancestortree",
          path_css("ancestortree.css"), None,
          [path_img("Web_Gender_Female.png"),
-          path_img("Web_Gender_Male.png")],        []],
+          path_img("Web_Gender_Male.png")],        [] ],
 
         # media reference regions style sheet
         ["behaviour",     0, "Behaviour",            
-         path_css('behaviour.css'),         None,  [], []], 
+         path_css('behaviour.css'),         None,  [], [] ], 
 
-        # narrative-maps style sheet for NarrativeWeb place maps
+        # NarrativeMap stylesheet/ image for NarrativeWeb place maps
         ["NarrativeMaps",  0, "",
          path_css("narrative-maps.css"),      None, [], [] ],
 
         # default style sheet in the options
         ["default",       0, _("Basic-Ash"),         
-         path_css('Web_Basic-Ash.css'),     None, [], []],
+         path_css('Web_Basic-Ash.css'),     None, [], [] ],
 
         # default printer style sheet
         ["Print-Default", 0, "Print-Default",        
-         path_css('Web_Print-Default.css'), None, [], []],
+         path_css('Web_Print-Default.css'), None, [], [] ],
 
-        # vertical navigation style sheet
-        ["Navigation-Vertical", 0, "Navigation-Vertical", 
-         path_css('Web_Navigation-Vertical.css'), None, [], []],
+        # Horizontal Navigation Menus Style Sheet
+        ["Horizontal-Menus", 0, "Horizontal Menus", 
+         path_css('Web_Horizontal-Menus.css'), None, [], [] ],
 
-        # horizontal navigation style sheet
-        ["Navigation-Horizontal", 0, "Navigation-Horizontal", 
-         path_css('Web_Navigation-Horizontal.css'), None, [], []],
+        # Vertical Navigation Menus Style Sheet
+        ["Vertical-Menus", 0, "Vertical Menus", 
+         path_css('Web_Vertical-Menus.css'), None, [], [] ],
+
+        # WebKit/ Html5/ CSS3 Fade Navigation Menus Style Sheet
+        ["Fade-Menus", 0, "Fade In/ Out Menus", 
+         path_css('Web_Fade-Menus.css'), None, [], [] ],
+
+        # WebKit/ Html5/ CSS3 Drop Down Navigation Menu Style Sheet
+        ["DropDown-Menus", 0, "Drop Down Menus",
+         path_css("Web_DropDown-Menus.css"), None, [], [] ],
 
         # GeoView style sheet with its image
         ["GeoView", 0, "GeoView", 
@@ -134,44 +142,24 @@ def load_on_reg(dbstate, uistate, plugin):
           path_img("gramps-geo-birth.png"),
           path_img("gramps-geo-death.png"),
           path_img("gramps-geo-mainmap.png"),
-          path_img("gramps-geo-marriage.png")],
+          path_img("gramps-geo-marriage.png")], [] ],
 
-         [path_js("mapstraction", "mxn.core.js"),
-          path_js("mapstraction", "mxn.googlev3.core.js"),
-          path_js("mapstraction", "mxn.js"),
-          path_js("mapstraction", "mxn.openlayers.core.js")]],
+        # no style sheet option
+        ["No style sheet",1, _("No style sheet"),    [],    None, [], [] ],
 
         # all other images for use in NarrativeWeb
         ['All Images', 0, 'All Images', None, None, 
          [path_img("blank.gif"),
-          path_img("document.png")], []],
+          path_img("document.png")], [] ],
 
         # Gramps Fav icon #2
-        ["favicon2", 0, "favicon2", 
-         path_img("favicon2.ico"), None, [], []],
+        ["favicon2", 0, "FavIcon2", 
+         path_img("favicon2.ico"), None, [], [] ],
 
         # copyright image
         ['Copyright', 0, 'Copyright',
-         path_img("somerights20.gif"), None, [], []],
-
-        # document image in case the media object is not an image
-        ['Document', 0, 'Document',
-         path_img("document.png"), None, [], []],
-
-        # Google core javascript
-        ["Google Core", 0, "Google Core", 
-         path_js("mapstraction", "mxn.google.core.js"), None, [], []],
-
-        # Google Earth core javascript
-        ["Google Earth", 0, "Google Earth",
-         path_js("mapstraction", "mxn.googleearth.core.js"), None, [], []],
-
-        # Google GeoCoder javascript
-        ["Google GeoCoder", 0, "Google GeoCoder",
-         path_js("mapstraction", "mxn.google.geocoder.js"), None, [], []],
-
+         path_img("somerights20.gif"), None, [], [] ],
         ]
-
     return CSS_FILES
 
 def process_list(data):
